@@ -1,22 +1,3 @@
-/*
- *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
-
 #include <gtk/gtk.h>
 
 
@@ -30,11 +11,11 @@ on_main_window_delete_event            (GtkWidget       *widget,
                                         gpointer         user_data);
 
 void
-on_main_new_activate                   (GtkMenuItem     *menuitem,
+on_new_activate                        (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void
-on_main_open_input_activate            (GtkMenuItem     *menuitem,
+on_open_input_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void
@@ -65,10 +46,6 @@ void
 on_main_freqplots_activate             (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_main_structdata_activate            (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 main_pol_menu_activate                 (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -102,33 +79,7 @@ on_common_freq_activate                (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void
-on_main_about_activate                 (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_main_x_axis_clicked                 (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_main_y_axis_clicked                 (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_main_z_axis_clicked                 (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_main_default_view_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_main_rotate_spinbutton_value_changed
-                                        (GtkSpinButton   *spinbutton,
-                                        gpointer         user_data);
-
-void
-on_main_incline_spinbutton_value_changed
-                                        (GtkSpinButton   *spinbutton,
+on_about_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void
@@ -176,14 +127,62 @@ on_structure_drawingarea_configure_event
                                         gpointer         user_data);
 
 gboolean
-on_structure_drawingarea_motion_notify_event
-                                        (GtkWidget       *widget,
-                                        GdkEventMotion  *event,
+on_structure_drawingarea_expose_event  (GtkWidget       *widget,
+                                        GdkEventExpose  *event,
                                         gpointer         user_data);
 
 gboolean
-on_structure_drawingarea_expose_event  (GtkWidget       *widget,
-                                        GdkEventExpose  *event,
+on_structure_drawingarea_button_press_event
+                                        (GtkWidget       *widget,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_structure_drawingarea_motion_notify_event( GtkWidget       *widget,
+                                              GdkEventMotion  *event,
+                                              gpointer         user_data);
+
+void
+on_main_x_axis_clicked                 (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_main_y_axis_clicked                 (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_main_z_axis_clicked                 (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_main_default_view_clicked           (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_main_rotate_spinbutton_value_changed
+                                        (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_main_incline_spinbutton_value_changed
+                                        (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_structure_zoom_spinbutton_value_changed
+                                        (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_structure_plus_button_clicked       (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_structure_minus_button_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_structure_one_button_clicked        (GtkButton       *button,
                                         gpointer         user_data);
 
 void
@@ -213,14 +212,6 @@ void
 on_freqplots_window_destroy            (GtkObject       *object,
                                         gpointer         user_data);
 
-void
-on_new_activate                        (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_open_input_activate                 (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 void
 on_freqplots_save_activate             (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -234,7 +225,7 @@ freqplots_pol_menu_activate            (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void
-on_freqplots_about_activate            (GtkMenuItem     *menuitem,
+on_net_gain_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
 void
@@ -351,40 +342,6 @@ void
 on_near_snapshot_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_rdpattern_overlay_struct_activate   (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_rdpattern_about_activate            (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_rdpattern_x_axis_clicked            (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_rdpattern_y_axis_clicked            (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_rdpattern_z_axis_clicked            (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_rdpattern_default_view_clicked      (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_rdpattern_rotate_spinbutton_value_changed
-                                        (GtkSpinButton   *spinbutton,
-                                        gpointer         user_data);
-
-void
-on_rdpattern_incline_spinbutton_value_changed
-                                        (GtkSpinButton   *spinbutton,
-                                        gpointer         user_data);
-
 void
 on_rdpattern_gain_togglebutton_toggled (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -420,9 +377,57 @@ on_rdpattern_drawingarea_expose_event  (GtkWidget       *widget,
                                         gpointer         user_data);
 
 gboolean
-on_rdpattern_drawingarea_motion_notify_event
+on_rdpattern_drawingarea_button_press_event
                                         (GtkWidget       *widget,
-                                        GdkEventMotion  *event,
+                                        GdkEventButton  *event,
+                                        gpointer         user_data);
+
+gboolean
+on_rdpattern_drawingarea_motion_notify_event( GtkWidget       *widget,
+                                              GdkEventMotion  *event,
+                                              gpointer         user_data);
+
+void
+on_rdpattern_x_axis_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_y_axis_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_z_axis_clicked            (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_default_view_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_rotate_spinbutton_value_changed
+                                        (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_incline_spinbutton_value_changed
+                                        (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_zoom_spinbutton_value_changed
+                                        (GtkSpinButton   *spinbutton,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_plus_button_clicked       (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_minus_button_clicked      (GtkButton       *button,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_one_button_clicked        (GtkButton       *button,
                                         gpointer         user_data);
 
 void
@@ -437,18 +442,6 @@ void
 on_quit_okbutton_clicked               (GtkButton       *button,
                                         gpointer         user_data);
 
-void
-on_open_dialog_destroy                 (GtkObject       *object,
-                                        gpointer         user_data);
-
-void
-on_open_cancelbutton_clicked           (GtkButton       *button,
-                                        gpointer         user_data);
-
-void
-on_open_okbutton_clicked               (GtkButton       *button,
-                                        gpointer         user_data);
-
 gboolean
 on_error_dialog_delete_event           (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -671,7 +664,7 @@ on_patch_editor_destroy                (GtkObject       *object,
                                         gpointer         user_data);
 
 void
-on_patch_arbitary_radiobutton_toggled  (GtkToggleButton *togglebutton,
+on_patch_arbitrary_radiobutton_toggled  (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
 void
@@ -799,10 +792,6 @@ void
 on_helix_res_spinbutton_value_changed  (GtkSpinButton   *spinbutton,
                                         gpointer         user_data);
 
-void
-on_helix_linkall_radiobutton_toggled   (GtkToggleButton *togglebutton,
-                                        gpointer         user_data);
-
 void
 on_helix_linkzo_radiobutton_toggled    (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -811,6 +800,10 @@ void
 on_helix_linkzhl_radiobutton_toggled   (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
 
+void
+on_helix_linkall_radiobutton_toggled   (GtkToggleButton *togglebutton,
+                                        gpointer         user_data);
+
 void
 on_helix_lh_checkbutton_toggled        (GtkToggleButton *togglebutton,
                                         gpointer         user_data);
@@ -865,8 +858,7 @@ on_scale_editor_destroy                (GtkObject       *object,
                                         gpointer         user_data);
 
 void
-on_scale_factor_spinbutton_value_changed
-                                        (GtkSpinButton   *spinbutton,
+on_scale_spinbutton_value_changed      (GtkSpinButton   *spinbutton,
                                         gpointer         user_data);
 
 void
@@ -1273,13 +1265,37 @@ on_gend_ok_button_clicked              (GtkButton       *button,
                                         gpointer         user_data);
 
 void
-on_aboutdialog_destroy                 (GtkObject       *object,
+on_aboutdialog_close                   (GtkDialog       *dialog,
                                         gpointer         user_data);
 
 void
-on_new_activate                        (GtkMenuItem     *menuitem,
+on_aboutdialog_response                (GtkDialog       *dialog,
+                                        gint             response_id,
+                                        gpointer         user_data);
+
+gboolean
+on_structure_drawingarea_scroll_event  (GtkWidget       *widget,
+                                        GdkEvent        *event,
+                                        gpointer         user_data);
+
+gboolean
+on_rdpattern_drawingarea_scroll_event  (GtkWidget       *widget,
+                                        GdkEvent        *event,
                                         gpointer         user_data);
 
 void
-on_open_input_activate                 (GtkMenuItem     *menuitem,
+on_rdpattern_overlay_structure_activate
+                                        (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_rdpattern_save_as_gnuplot_activate  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_freqplots_save_as_gnuplot_activate  (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_struct_save_as_gnuplot_activate     (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
