@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,77 +16,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* rdpatterns.c
+/* draw_radiation.c
  *
  * Code for drawing radiation patterns
  */
 
-#include "xnec2c.h"
-#include "support.h"
-
-/* Radiation pattern, structure and
- * plots drawingarea and windows */
-extern GtkWidget *rdpattern_drawingarea;
-extern GtkWidget *structure_drawingarea;
-
-extern GtkWidget *main_window;
-extern GtkWidget *rdpattern_window;
-extern GtkWidget *freqplots_window;
-
-/* Pixmap for drawing radiation patterns */
-extern GdkPixmap *rdpattern_pixmap;
-extern int rdpattern_pixmap_width, rdpattern_pixmap_height;
-
-/* Pixmap for drawing structure */
-extern GdkPixmap *structure_pixmap;
-
-/* Plots and structure pixmap size */
-extern int freqplots_pixmap_width, freqplots_pixmap_height;
-extern int structure_pixmap_width, structure_pixmap_height;
-
-/* Parameters for projecting radiation
- * patterns and structure to Screen */
-extern projection_parameters_t rdpattern_proj_params;
-extern projection_parameters_t structure_proj_params;
-
-extern GtkWidget *animate_dialog;
-/* Animation timeout callback tag */
-extern gint anim_tag;
-
-/* Some graphics contexts */
-extern GdkGC
-  *white_gc,
-  *black_gc,
-  *plot_gc;
+#include "draw_radiation.h"
+#include "shared.h"
 
 /* For coloring rad pattern */
-static int *red = NULL, *grn = NULL, *blu = NULL;
+static double *red = NULL, *grn = NULL, *blu = NULL;
 
 /* Buffered points in 3d (xyz) space
  * forming the radiation pattern */
 static point_3d_t *point_3d = NULL;
 
-/* Segments for drawing structure */
-extern GdkSegment *structure_segs;
-
-/* Common block "data" */
-extern data_t data;
-
-/* Common block gnd */
-gnd_t gnd;
-
-/* Radiation pattern data */
-rad_pattern_t *rad_pattern = NULL;
-
-/* Near E/H field data */
-near_field_t near_field;
-
-/* Field pattern data */
-extern fpat_t fpat;
-
-/* Data needed in various calculations */
-calc_data_t calc_data;
-
 /*-----------------------------------------------------------------------*/
 
 /* Draw_Radiation()
@@ -95,35 +38,41 @@ calc_data_t calc_data;
  * Draws the radiation pattern or near E/H fields
  */
   void
-Draw_Radiation( GtkWidget *drawingarea, GdkGC *gc )
+Draw_Radiation( GtkWidget *drawingarea )
 {
   /* Abort if xnec2c may be quit by user */
   if( isFlagSet(MAIN_QUIT) || isFlagClear(ENABLE_EXCITN) )
 	return;
 
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( rdpattern_pixmap );
+
   /* Clear pixmap */
-  gdk_draw_rectangle(
-	  rdpattern_pixmap,
-	  black_gc,
-	  TRUE, 0, 0,
-	  rdpattern_proj_params.pixmap_width,
-	  rdpattern_proj_params.pixmap_height);
+  cairo_set_source_rgb( cr, BLACK );
+  cairo_rectangle(
+	  cr, 0.0, 0.0,
+	  (double)rdpattern_proj_params.pixmap_width,
+	  (double)rdpattern_proj_params.pixmap_height);
+  cairo_fill( cr );
 
   /* Draw rad pattern or E/H fields */
   if( isFlagSet(DRAW_GAIN) )
-	Draw_Radiation_Pattern( drawingarea, gc );
-  else
-	if( isFlagSet(DRAW_EHFIELD) )
-	  Draw_Near_Field( drawingarea, gc );
+	Draw_Radiation_Pattern();
+  else if( isFlagSet(DRAW_EHFIELD) )
+	  Draw_Near_Field();
 
   /* Render pixmap to screen */
   gdk_window_set_back_pixmap( drawingarea->window,
 	  rdpattern_pixmap, FALSE );
   gdk_window_clear( drawingarea->window );
 
+  /* Display frequency step */
+  Display_Fstep( rdpattern_fstep_entry, calc_data.fstep );
+
   /* Wait for GTK to complete its tasks */
   while( g_main_context_iteration(NULL, FALSE) );
 
+  cairo_destroy( cr );
 } /* Draw_Radiation() */
 
 /*-----------------------------------------------------------------------*/
@@ -135,12 +84,17 @@ Draw_Radiation( GtkWidget *drawingarea, GdkGC *gc )
  * co-ordinates theta, phi and r = gain(theta, phi)
  */
   void
-Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
+Draw_Radiation_Pattern( void )
 {
+  /* Abort if rad pattern cannot be drawn */
+  if( isFlagClear(ENABLE_RDPAT) || (calc_data.fstep < 0) )
+	return;
+
   /* Line segments to draw on Screen */
   GdkSegment segm;
 
   int
+	idx,
 	nth,     /* Theta step count */
 	nph,     /* Phi step count   */
 	col_idx, /* Index to rad pattern color buffers */
@@ -155,41 +109,40 @@ Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
   double theta, phi, r, r_min, r_range;
 
   /* theta and phi step in rads */
-  double dth = fpat.dth * TA, dph = fpat.dph * TA;
+  double dth = (double)fpat.dth * (double)TA;
+  double dph = (double)fpat.dph * (double)TA;
 
   /* Used to set text in labels */
-  gchar txt[10];
+  gchar txt[7];
 
-
-  /* Abort if rad pattern cannot be drawn */
-  if( isFlagClear(ENABLE_RDPAT) || (calc_data.fstep < 0) )
-	return;
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( rdpattern_pixmap );
 
   fstep = calc_data.fstep;
   pol   = calc_data.pol_type;
 
   /* Change drawing if newer rad pattern data */
-  if( isFlagSet(DRAW_NEWRDPAT) )
+  if( isFlagSet(DRAW_NEW_RDPAT) )
   {
-	size_t mreq = fpat.nth * fpat.nph * sizeof(point_3d_t);
-	mem_realloc( (void *)&point_3d, mreq, "in draw_radiation.c" );
-	mreq = (fpat.nth-1) * fpat.nph + (fpat.nph-1) * fpat.nth;
-	mreq *= sizeof(int);
-	mem_realloc( (void *)&red, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&grn, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&blu, mreq, "in draw_radiation.c" );
+	size_t mreq = ((size_t)(fpat.nth * fpat.nph)) * sizeof(point_3d_t);
+	mem_realloc( (void **)&point_3d, mreq, "in draw_radiation.c" );
+	mreq = (size_t)((fpat.nth-1) * fpat.nph + (fpat.nph-1) * fpat.nth);
+	mreq *= sizeof(double);
+	mem_realloc( (void **)&red, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&grn, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&blu, mreq, "in draw_radiation.c" );
 
-	ClearFlag( DRAW_NEWRDPAT );
+	ClearFlag( DRAW_NEW_RDPAT );
 
 	/* Distance of rdpattern point furthest from xyz origin */
+	idx = rad_pattern[fstep].max_gain_idx[pol];
 	rdpattern_proj_params.r_max = Scale_Gain(
-		rad_pattern[fstep].gtot[rad_pattern[fstep].max_gain_idx[pol]],
-		fstep, rad_pattern[fstep].max_gain_idx[pol]);
+		rad_pattern[fstep].gtot[idx], fstep, idx);
 
 	/* Distance of rdpattern point nearest to xyz origin */
+	idx = rad_pattern[fstep].min_gain_idx[pol];
 	r_min = Scale_Gain(
-		rad_pattern[fstep].gtot[rad_pattern[fstep].min_gain_idx[pol]],
-		fstep, rad_pattern[fstep].min_gain_idx[pol]);
+		rad_pattern[fstep].gtot[idx], fstep, idx);
 
 	/* Range of scaled rdpattern gain values */
 	r_range = rdpattern_proj_params.r_max - r_min;
@@ -203,12 +156,12 @@ Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
 	/*** Convert radiation pattern values
 	 * to points in 3d space in x,y,z axis ***/
 	pts_idx = 0;
-	phi = fpat.phis * TA; /* In rads */
+	phi = (double)(fpat.phis * TA); /* In rads */
 
 	/* Step phi angle */
 	for( nph = 0; nph < fpat.nph; nph++ )
 	{
-	  theta = fpat.thets * TA; /* In rads */
+	  theta = (double)(fpat.thets * TA); /* In rads */
 
 	  /* Step theta angle */
 	  for( nth = 0; nth < fpat.nth; nth++ )
@@ -228,14 +181,13 @@ Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
 
 		/* Step theta in rads */
 		theta += dth;
+
 		/* Step 3d points index */
 		pts_idx++;
-
 	  } /* for( nth = 0; nth < fpat.nth; nth++ ) */
 
 	  /* Step phi in rads */
 	  phi += dph;
-
 	} /* for( nph = 0; nph < fpat.nph; nph++ ) */
 
 	/* Calculate RGB value for rad pattern seg.
@@ -274,26 +226,21 @@ Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
 			 point_3d[pts_idx+fpat.nth].r)/2.0-r_min,
 			r_range );
 		col_idx++;
+
+		/* Needed because of "index look-ahead" above */
 		pts_idx += fpat.nth;
 
 	  } /* for( nth = 0; nth < fpat.nth; nth++ ) */
-
-	  /* Needed because of "index look-ahead" above */
-	  pts_idx += fpat.nth;
-
 	} /* for( nph = 1; nph < fpat.nph; nph++ ) */
 
 	/* Show max gain on color code bar */
-	sprintf( txt, "%6f", rad_pattern[fstep].max_gain[pol] );
-	txt[6] = '\0';
+	snprintf( txt, 7, "%6f", rad_pattern[fstep].max_gain[pol] );
 	gtk_label_set_text(
 		GTK_LABEL(lookup_widget(rdpattern_window,
 			"rdpattern_colorcode_maxlabel")), txt );
 
 	/* Show min gain on color code bar */
-	sprintf( txt, "%4f",
-		rad_pattern[fstep].min_gain[pol] );
-	txt[4] = '\0';
+	snprintf( txt, 5, "%4f", rad_pattern[fstep].min_gain[pol] );
 	gtk_label_set_text(
 		GTK_LABEL(lookup_widget(rdpattern_window,
 			"rdpattern_colorcode_minlabel")), txt );
@@ -303,6 +250,31 @@ Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
   /* Draw xyz axes to Screen */
   Draw_XYZ_Axes( rdpattern_pixmap, rdpattern_proj_params );
 
+  /* Overlay structure on Near Field pattern */
+  if( isFlagSet(OVERLAY_STRUCT) )
+  {
+	/* Save structure pixmap and params pointers */
+	GdkPixmap *pixmap = structure_pixmap;
+	projection_parameters_t params = structure_proj_params;
+
+	/* Divert structure drawing to rad pattern area */
+	structure_pixmap = rdpattern_pixmap;
+	structure_proj_params = rdpattern_proj_params;
+	structure_proj_params.r_max = params.r_max;
+	structure_proj_params.xy_scale =
+	  params.xy_scale1 * rdpattern_proj_params.xy_zoom;
+
+	/* Process and draw geometry if enabled */
+	Process_Wire_Segments();
+	Process_Surface_Patches();
+	Draw_Surface_Patches( structure_segs+data.n, data.m );
+	Draw_Wire_Segments( structure_segs, data.n );
+
+	/* Restore structure pixmap and params */
+	structure_pixmap = pixmap;
+	structure_proj_params = params;
+  } /* if( isFlagSet(OVERLAY_STRUCT) ) */
+
   /*** Draw rad pattern on screen ***/
   /* Draw segments along theta direction */
   col_idx = pts_idx = 0;
@@ -322,21 +294,14 @@ Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
 		  point_3d[pts_idx+1].z );
 	  pts_idx++;
 
-	  /* Set gc attributes for segment */
-	  Set_GC_Attributes(
-		  gc, red[col_idx], grn[col_idx], blu[col_idx],
-		  2, rdpattern_drawingarea );
-	  col_idx++;
-
 	  /* Draw segment */
-	  gdk_draw_line(
-		  rdpattern_pixmap, gc,
-		  segm.x1, segm.y1, segm.x2, segm.y2 );
+	  cairo_set_source_rgb( cr, red[col_idx], grn[col_idx], blu[col_idx] );
+	  Cairo_Draw_Line( cr, segm.x1, segm.y1, segm.x2, segm.y2 );
+	  col_idx++;
 
 	} /* for( nth = 1; nth < fpat.nth; nth++ ) */
 
 	pts_idx++;
-
   } /* for( nph = 0; nph < fpat.nph; nph++ ) */
 
   /* Draw segments along phi direction */
@@ -356,31 +321,25 @@ Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
 		  point_3d[pts_idx+fpat.nth].y,
 		  point_3d[pts_idx+fpat.nth].z );
 
-	  /* Set gc attributes for segment */
-	  Set_GC_Attributes(
-		  gc, red[col_idx], grn[col_idx], blu[col_idx],
-		  2, rdpattern_drawingarea );
+	  /* Draw segment */
+	  cairo_set_source_rgb( cr, red[col_idx], grn[col_idx], blu[col_idx] );
+	  Cairo_Draw_Line( cr, segm.x1, segm.y1, segm.x2, segm.y2 );
 	  col_idx++;
 
-	  /* Draw segment */
-	  gdk_draw_line(
-		  rdpattern_pixmap, gc,
-		  segm.x1, segm.y1, segm.x2, segm.y2 );
-
+	  /* Needed because drawing segments "looks ahead"
+	   * in the 3d points buffer in the above loop */
 	  pts_idx += fpat.nth;
 
 	} /* for( nph = 1; nph < fpat.nph; nph++ ) */
-
-	/* Needed because drawing segments "looks ahead"
-	 * in the 3d points buffer in the above loop */
-	pts_idx += fpat.nth;
-
   } /* for( nth = 0; nth < fpat.nth; nth++ ) */
 
   /* Show gain in direction of viewer */
-  Show_Viewer_Gain( rdpattern_window,
-	  "rdpattern_viewer_gain", rdpattern_proj_params );
+  Show_Viewer_Gain(
+	  rdpattern_window,
+	  "rdpattern_viewer_gain",
+	  rdpattern_proj_params );
 
+  cairo_destroy( cr );
 } /* Draw_Radiation_Pattern() */
 
 /*-----------------------------------------------------------------------*/
@@ -390,51 +349,64 @@ Draw_Radiation_Pattern( GtkWidget *drawingarea, GdkGC *gc )
  * Draws near E/H fields and Poynting vector
  */
   void
-Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
+Draw_Near_Field( void )
 {
   int idx, npts; /* Number of points to plot */
   double
 	fx, fy, fz,	/* Co-ordinates of "free" end of field lines */
-	dr,			/* Scale factor ref, for normalizing field strength values */
 	fscale;		/* Scale factor for equalizing field line segments */
 
+  /* Scale factor ref, for normalizing field strength values */
+  static double dr;
+
   /* Co-ordinates of Poynting vectors */
   static double *pov_x = NULL, *pov_y = NULL;
   static double *pov_z = NULL, *pov_r = NULL;
+
   /* Range of Poynting vector values,
    * its max and min and log of max/min */
   static double pov_max = 0, max;
 
   /* Used to set text in labels */
-  gchar txt[10];
+  gchar txt[9];
 
   /* Line segments to draw on Screen */
   GdkSegment segm;
 
   /* For coloring field lines */
-  int red, grn, blu;
+  double xred = 0.0, xgrn = 0.0, xblu = 0.0;
 
   /* Abort if drawing a near field pattern is not possible */
   if( isFlagClear(ENABLE_NEAREH) || !near_field.valid )
 	return;
 
-  /* Reference for scale factor used in
-   * normalizing field strength values */
-  if( fpat.near ) /* Spherical co-ordinates */
-	dr = (double)fpat.dxnr;
-  else /* Rectangular co-ordinates */
-	dr = sqrt(
-		(double)fpat.dxnr * (double)fpat.dxnr +
-		(double)fpat.dynr * (double)fpat.dynr +
-		(double)fpat.dznr * (double)fpat.dznr )/1.75;
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( rdpattern_pixmap );
 
-  /* Set radiation pattern projection parametrs */
-  /* Distance of field point furthest from xyz origin */
-  rdpattern_proj_params.r_max = near_field.r_max + dr;
-  New_Projection_Parameters(
-	  rdpattern_pixmap_width,
-	  rdpattern_pixmap_height,
-	  &rdpattern_proj_params );
+  /* Initialize projection parameters */
+  if( isFlagSet(DRAW_NEW_EHFIELD) )
+  {
+	/* Reference for scale factor used in
+	 * normalizing field strength values */
+	if( fpat.near ) /* Spherical co-ordinates */
+	  dr = (double)fpat.dxnr;
+	else /* Rectangular co-ordinates */
+	  dr = sqrt(
+		  (double)fpat.dxnr * (double)fpat.dxnr +
+		  (double)fpat.dynr * (double)fpat.dynr +
+		  (double)fpat.dznr * (double)fpat.dznr )/1.75;
+
+	/* Set radiation pattern projection parametrs */
+	/* Distance of field point furthest from xyz origin */
+	rdpattern_proj_params.r_max = near_field.r_max + dr;
+	New_Projection_Parameters(
+		rdpattern_pixmap_width,
+		rdpattern_pixmap_height,
+		&rdpattern_proj_params );
+
+	ClearFlag( DRAW_NEW_EHFIELD );
+
+  } /* if( isFlagSet( DRAW_NEW_EHFIELD ) */
 
   /* Draw xyz axes to Screen */
   Draw_XYZ_Axes( rdpattern_pixmap, rdpattern_proj_params );
@@ -453,27 +425,24 @@ Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
 	/* Process and draw geometry if enabled */
 	Process_Wire_Segments();
 	Process_Surface_Patches();
-	Draw_Surface_Patches( rdpattern_drawingarea,
-		plot_gc, structure_segs+data.n, data.m );
-	Draw_Wire_Segments( rdpattern_drawingarea,
-		plot_gc, structure_segs, data.n );
+	Draw_Surface_Patches( structure_segs+data.n, data.m );
+	Draw_Wire_Segments( structure_segs, data.n );
 
 	/* Restore structure pixmap and params */
 	structure_pixmap = pixmap;
 	structure_proj_params = params;
-  }
+  } /* if( isFlagSet(OVERLAY_STRUCT) ) */
 
   /* Step thru near field values */
   npts = fpat.nrx * fpat.nry * fpat.nrz;
   for( idx = 0; idx < npts; idx++ )
   {
 	/*** Draw Near E Field ***/
-	if( isFlagSet(DRAW_EFIELD) )
+	if( isFlagSet(DRAW_EFIELD) && (fpat.nfeh & NEAR_EFIELD) )
 	{
 	  /* Set gc attributes for segment */
-	  Value_to_Color( &red, &grn, &blu,
+	  Value_to_Color( &xred, &xgrn, &xblu,
 		  near_field.er[idx], near_field.max_er );
-	  Set_GC_Attributes( gc, red, grn, blu, 2, rdpattern_drawingarea );
 
 	  /* Scale factor for each field point, to make
 	   * near field direction lines equal-sized */
@@ -489,15 +458,13 @@ Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
 	  /* Project new line segment of
 	   * phi chain to the Screen */
 	  Set_Gdk_Segment(
-		  &segm,
-		  &rdpattern_proj_params,
+		  &segm, &rdpattern_proj_params,
 		  near_field.px[idx], near_field.py[idx], near_field.pz[idx],
 		  fx, fy, fz );
 
 	  /* Draw segment */
-	  gdk_draw_line(
-		  rdpattern_pixmap, gc,
-		  segm.x1, segm.y1, segm.x2, segm.y2 );
+	  cairo_set_source_rgb( cr, xred, xgrn, xblu );
+	  Cairo_Draw_Line( cr, segm.x1, segm.y1, segm.x2, segm.y2 );
 
 	} /* if( isFlagSet(DRAW_EFIELD) && (fpat.nfeh & NEAR_EFIELD) ) */
 
@@ -505,10 +472,8 @@ Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
 	if( isFlagSet(DRAW_HFIELD) && (fpat.nfeh & NEAR_HFIELD) )
 	{
 	  /* Set gc attributes for segment */
-	  Value_to_Color( &red, &grn, &blu,
+	  Value_to_Color( &xred, &xgrn, &xblu,
 		  near_field.hr[idx], near_field.max_hr );
-	  Set_GC_Attributes( gc, red, grn, blu, 2,
-		  rdpattern_drawingarea );
 
 	  /* Scale factor for each field point, to make
 	   * near field direction lines equal-sized */
@@ -524,15 +489,13 @@ Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
 	  /* Project new line segment of
 	   * phi chain to the Screen */
 	  Set_Gdk_Segment(
-		  &segm,
-		  &rdpattern_proj_params,
+		  &segm, &rdpattern_proj_params,
 		  near_field.px[idx], near_field.py[idx], near_field.pz[idx],
 		  fx, fy, fz );
 
 	  /* Draw segment */
-	  gdk_draw_line(
-		  rdpattern_pixmap, gc,
-		  segm.x1, segm.y1, segm.x2, segm.y2 );
+	  cairo_set_source_rgb( cr, xred, xgrn, xblu );
+	  Cairo_Draw_Line( cr, segm.x1, segm.y1, segm.x2, segm.y2 );
 
 	} /* if( isFlagSet(DRAW_HFIELD) && (fpat.nfeh & NEAR_HFIELD) ) */
 
@@ -546,11 +509,11 @@ Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
 	  /* Allocate on new near field matrix size */
 	  if( isFlagSet(ALLOC_PNTING_BUFF) )
 	  {
-		size_t mreq = npts * sizeof( double );
-		mem_realloc( (void *)&pov_x, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_y, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_z, mreq, "in draw_radiation.c" );
-		mem_realloc( (void *)&pov_r, mreq, "in draw_radiation.c" );
+		size_t mreq = (size_t)npts * sizeof( double );
+		mem_realloc( (void **)&pov_x, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_y, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_z, mreq, "in draw_radiation.c" );
+		mem_realloc( (void **)&pov_r, mreq, "in draw_radiation.c" );
 		ClearFlag( ALLOC_PNTING_BUFF );
 	  }
 
@@ -573,13 +536,10 @@ Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
 			pov_z[ipv] * pov_z[ipv] );
 		if( pov_max < pov_r[ipv] )
 		  pov_max = pov_r[ipv];
-
 	  } /* for( ipv = 0; ipv < npts; ipv++ ) */
 
 	  /* Set gc attributes for segment */
-	  Value_to_Color( &red, &grn, &blu, pov_r[idx], pov_max );
-	  Set_GC_Attributes( gc, red, grn, blu, 2,
-		  rdpattern_drawingarea );
+	  Value_to_Color( &xred, &xgrn, &xblu, pov_r[idx], pov_max );
 
 	  /* Scale factor for each field point, to make
 	   * near field direction lines equal-sized */
@@ -601,28 +561,28 @@ Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
 		  near_field.pz[idx], fx, fy, fz );
 
 	  /* Draw segment */
-	  gdk_draw_line(
-		  rdpattern_pixmap, gc,
-		  segm.x1, segm.y1, segm.x2, segm.y2 );
+	  cairo_set_source_rgb( cr, xred, xgrn, xblu );
+	  Cairo_Draw_Line( cr, segm.x1, segm.y1, segm.x2, segm.y2 );
 
 	} /* if( isFlagSet(DRAW_POYNTING) ) */
 
   } /* for( idx = 0; idx < npts; idx++ ) */
 
-  if( isFlagSet(NEAREH_ANIMATE) ) return;
+  if( isFlagSet(NEAREH_ANIMATE) )
+  {
+	cairo_destroy( cr );
+	return;
+  }
 
   /* Show max field strength on color code bar */
   if( isFlagSet(DRAW_EFIELD) )
 	max = near_field.max_er;
-  else
-	if( isFlagSet(DRAW_HFIELD) )
-	  max = near_field.max_hr;
-	else
-	  if( isFlagSet(DRAW_POYNTING) )
-		max = pov_max;
+  else if( isFlagSet(DRAW_HFIELD) )
+	max = near_field.max_hr;
+  else if( isFlagSet(DRAW_POYNTING) )
+	max = pov_max;
 
-  sprintf( txt, "%8.2E", max );
-  txt[8] = '\0';
+  snprintf( txt, sizeof(txt), "%8.2E", max );
   gtk_label_set_text(
 	  GTK_LABEL(lookup_widget(rdpattern_window,
 		  "rdpattern_colorcode_maxlabel")), txt );
@@ -632,12 +592,13 @@ Draw_Near_Field( GtkWidget *drawingarea, GdkGC *gc )
 	  GTK_LABEL(lookup_widget(rdpattern_window,
 		  "rdpattern_colorcode_minlabel")), "0" );
 
+  cairo_destroy( cr );
 } /* Draw_Near_Field() */
 
 /*-----------------------------------------------------------------------*/
 
   gboolean
-Animate_Near_Field( gpointer data )
+Animate_Near_Field( gpointer udata )
 {
   /* omega*t = 2*pi*f*t = Time-varying phase of excitation */
   static double wt = 0.0;
@@ -693,7 +654,7 @@ Animate_Near_Field( gpointer data )
   if( wt >= (double)TP )
 	wt = 0.0;
 
-  Draw_Radiation( rdpattern_drawingarea, plot_gc );
+  Draw_Radiation( rdpattern_drawingarea );
 
   return( TRUE );
 
@@ -712,38 +673,34 @@ static int gain_style = GS_LINP;
 Scale_Gain( double gain, int fstep, int idx )
 {
   /* Scaled rad pattern gain and pol factor */
-  double rad = 0.0, polf;
+  double scaled_rad = 0.0;
 
-  polf = Polarization_Factor( calc_data.pol_type, fstep, idx );
-  if ( polf< 1e-200 )
-	return( 0.0 );
-
-  gain += 10.0 * log10(polf);
+  gain += Polarization_Factor( calc_data.pol_type, fstep, idx );
 
   switch( gain_style )
   {
 	case GS_LINP:
-	  rad = pow(10.0, (gain/10.0));
+	  scaled_rad = pow(10.0, (gain/10.0));
 	  break;
 
 	case GS_LINV:
-	  rad = pow(10.0, (gain/20.0));
+	  scaled_rad = pow(10.0, (gain/20.0));
 	  break;
 
 	case GS_ARRL:
-	  rad = exp( 0.058267 * gain );
+	  scaled_rad = exp( 0.058267 * gain );
 	  break;
 
 	case GS_LOG:
-	  rad = gain;
-	  if( rad < -40 )
-		rad = 0.0;
+	  scaled_rad = gain;
+	  if( scaled_rad < -40 )
+		scaled_rad = 0.0;
 	  else
-		rad = rad /40.0 + 1.0;
+		scaled_rad = scaled_rad /40.0 + 1.0;
 
   } /* switch( gain_style ) */
 
-  return( rad );
+  return( scaled_rad );
 
 } /* Scale_Gain() */
 
@@ -752,12 +709,12 @@ Scale_Gain( double gain, int fstep, int idx )
 /* Polarization_Factor()
  *
  * Calculates polarization factor from axial
- * ratio and tilt of polarization ellepse
+ * ratio and tilt of polarization ellipse
  */
   double
 Polarization_Factor( int pol_type, int fstep, int idx )
 {
-  double axrt2, tlt, polf = 1.0;
+  double axrt, axrt2, tilt2, polf = 1.0;
 
   switch( pol_type )
   {
@@ -766,37 +723,37 @@ Polarization_Factor( int pol_type, int fstep, int idx )
 	  break;
 
 	case POL_HORIZ:
-	  axrt2 = rad_pattern[fstep].axrt[idx] *
-		rad_pattern[fstep].axrt[idx];
-	  tlt = sin( rad_pattern[fstep].tilt[idx] );
-	  polf = (axrt2 + (1.0 - axrt2) * tlt * tlt) /
-		(1.0 + axrt2);
+	  axrt2  = rad_pattern[fstep].axrt[idx];
+	  axrt2 *= axrt2;
+	  tilt2  = sin( rad_pattern[fstep].tilt[idx] );
+	  tilt2 *= tilt2;
+	  polf = (axrt2 + (1.0 - axrt2) * tilt2) / (1.0 + axrt2);
 	  break;
 
 	case POL_VERT:
-	  axrt2 = rad_pattern[fstep].axrt[idx] *
-		rad_pattern[fstep].axrt[idx];
-	  tlt = cos( rad_pattern[fstep].tilt[idx] );
-	  polf = (axrt2 + (1.0 - axrt2) * tlt * tlt) /
-		(1.0 + axrt2);
+	  axrt2  = rad_pattern[fstep].axrt[idx];
+	  axrt2 *= axrt2;
+	  tilt2  = cos( rad_pattern[fstep].tilt[idx] );
+	  tilt2 *= tilt2;
+	  polf = (axrt2 + (1.0 - axrt2) * tilt2) / (1.0 + axrt2);
 	  break;
 
 	case POL_LHCP:
-	  axrt2 = rad_pattern[fstep].axrt[idx] *
-		rad_pattern[fstep].axrt[idx];
-	  polf = (1.0 + 2.0 * rad_pattern[fstep].axrt[idx] +
-		  axrt2) / 2.0 / (1.0 + axrt2);
+	  axrt  = rad_pattern[fstep].axrt[idx];
+	  axrt2 = axrt * axrt;
+	  polf  = (1.0 + 2.0 * axrt + axrt2) / 2.0 / (1.0 + axrt2);
 	  break;
 
 	case POL_RHCP:
-	  axrt2 = rad_pattern[fstep].axrt[idx] *
-		rad_pattern[fstep].axrt[idx];
-	  polf = (1.0 - 2.0 * rad_pattern[fstep].axrt[idx] +
-		  axrt2) / 2.0 / (1.0 + axrt2);
+	  axrt  = rad_pattern[fstep].axrt[idx];
+	  axrt2 = axrt * axrt;
+	  polf  = (1.0 - 2.0 * axrt + axrt2) / 2.0 / (1.0 + axrt2);
   }
 
+  if( polf < 1.0E-200 ) polf = 1.0E-200;
+  polf = 10.0 * log10( polf );
+  
   return( polf );
-
 } /* Polarization_Factor() */
 
 /*-----------------------------------------------------------------------*/
@@ -815,7 +772,7 @@ Set_Polarization( int pol )
 
   /* Trigger a redraw of drawingareas */
   if( isFlagSet(DRAW_ENABLED) )
-	Draw_Radiation( rdpattern_drawingarea, plot_gc );
+	Draw_Radiation( rdpattern_drawingarea );
 
   if( isFlagSet(PLOT_ENABLED) )
 	Plot_Frequency_Data();
@@ -825,7 +782,7 @@ Set_Polarization( int pol )
 	  "main_gain_entry", structure_proj_params );
 
   /* Enable redraw of rad pattern */
-  SetFlag( DRAW_NEWRDPAT );
+  SetFlag( DRAW_NEW_RDPAT );
 
 } /* Set_Polarization() */
 
@@ -846,8 +803,8 @@ Set_Gain_Style( int gs )
   if( isFlagSet(DRAW_ENABLED) )
   {
 	/* Enable redraw of rad pattern */
-	SetFlag( DRAW_NEWRDPAT );
-	Draw_Radiation( rdpattern_drawingarea, plot_gc );
+	SetFlag( DRAW_NEW_RDPAT );
+	Draw_Radiation( rdpattern_drawingarea );
   }
 
 } /* Set_Gain_Style() */
@@ -863,14 +820,14 @@ Set_Gain_Style( int gs )
 New_Radiation_Projection_Angle(void)
 {
   /* sin and cos of rad pattern rotation and inclination angles */
-  rdpattern_proj_params.sin_wr = sin(rdpattern_proj_params.Wr/TD);
-  rdpattern_proj_params.cos_wr = cos(rdpattern_proj_params.Wr/TD);
-  rdpattern_proj_params.sin_wi = sin(rdpattern_proj_params.Wi/TD);
-  rdpattern_proj_params.cos_wi = cos(rdpattern_proj_params.Wi/TD);
+  rdpattern_proj_params.sin_wr = sin(rdpattern_proj_params.Wr/(double)TD);
+  rdpattern_proj_params.cos_wr = cos(rdpattern_proj_params.Wr/(double)TD);
+  rdpattern_proj_params.sin_wi = sin(rdpattern_proj_params.Wi/(double)TD);
+  rdpattern_proj_params.cos_wi = cos(rdpattern_proj_params.Wi/(double)TD);
 
   /* Trigger a redraw of radiation drawingarea */
   if( isFlagSet(DRAW_ENABLED) )
-	Draw_Radiation( rdpattern_drawingarea, plot_gc );
+	Draw_Radiation( rdpattern_drawingarea );
 
   /* Trigger a redraw of plots drawingarea if doing "viewer" gain */
   if( isFlagSet(PLOT_ENABLED) && isFlagSet(PLOT_GVIEWER) )
@@ -885,7 +842,7 @@ New_Radiation_Projection_Angle(void)
  * Refreshes radiation pattern on new frequency in spinbutton
  */
   gboolean
-Redo_Radiation_Pattern( gpointer user_data )
+Redo_Radiation_Pattern( gpointer udata )
 {
   /* Redo radiation pattern for a new frequency. Below
    * makes calcs use the extra buffer in rad_pattern */
@@ -894,7 +851,7 @@ Redo_Radiation_Pattern( gpointer user_data )
 
   /* Redraw radiation pattern on screen */
   if( isFlagSet(DRAW_ENABLED) )
-	Draw_Radiation( rdpattern_drawingarea, plot_gc );
+	Draw_Radiation( rdpattern_drawingarea );
 
   return FALSE;
 
@@ -910,39 +867,46 @@ Redo_Radiation_Pattern( gpointer user_data )
   double
 Viewer_Gain( projection_parameters_t proj_parameters, int fstep )
 {
-  double theta, phi, gain=-999;
+  double phi, gain;
   int nth, nph, idx;
-
-
+  
   /* Calculate theta step from proj params */
   phi = proj_parameters.Wr;
-  if( fpat.dth == 0.0 )	nth = 0;
+  if( fpat.dth == 0.0 ) nth = 0;
   else
   {
+	double theta;
 	theta = fabs( 90.0 - proj_parameters.Wi );
 	if( theta > 180.0 )
 	{
 	  theta = 360.0 - theta;
 	  phi  -= 180.0;
 	}
-	if( (gnd.ksymp == 2) && (theta > 90.01l) && (gnd.ifar != 1) )
-	  return( -999.0 );
-	nth = (int)( theta/fpat.dth + 0.5 );
-	if( (nth >= fpat.nth) || (nth < 0) ) nth = fpat.nth-1;
+
+	if( (gnd.ksymp == 2) &&
+		(theta > 90.01)  &&
+		(gnd.ifar != 1) )
+	  return( -999.99 );
+
+	nth = (int)( (theta - fpat.thets) / fpat.dth + 0.5 );
+	if( (nth >= fpat.nth) || (nth < 0) )
+	  nth = fpat.nth-1;
   }
 
   /* Calculate phi step from proj params */
-  if( fpat.dph == 0.0 )	nph = 0;
+  if( fpat.dph == 0.0 ) nph = 0;
   else
   {
 	while( phi < 0.0 ) phi += 360.0;
-	nph = (int)( phi/fpat.dph + 0.5 );
-	if( (nph >= fpat.nph) || (nph < 0) ) nph = fpat.nph-1;
+	nph = (int)( (phi - fpat.phis) / fpat.dph + 0.5 );
+	if( (nph >= fpat.nph) || (nph < 0) )
+	  nph = fpat.nph-1;
   }
 
-  idx = nth + nph*fpat.nth;
-  gain = rad_pattern[fstep].gtot[idx] +	10.0 *
-	log10( Polarization_Factor(calc_data.pol_type, fstep, idx) );
+  idx = nth + nph * fpat.nth;
+  gain = rad_pattern[fstep].gtot[idx] +
+		Polarization_Factor(calc_data.pol_type, fstep, idx);
+  if( gain < -999.99 ) gain = -999.99;
 
   return( gain );
 
@@ -963,7 +927,7 @@ Rdpattern_Window_Killed( void )
 	animate_dialog = NULL;
 	ClearFlag( NEAREH_ANIMATE );
 	g_source_remove( anim_tag );
-	anim_tag = -1;
+	anim_tag = 0;
   }
 
   if( isFlagSet(DRAW_ENABLED) )
@@ -992,45 +956,45 @@ Set_Window_Labels( void )
 {
   char *pol_type[NUM_POL] =
   {
-	"Total Gain",
-	"Horizontal Polarization",
-	"Vertical Polarization",
-	"RH Circular Polarization",
-	"LH Circular Polarization"
+	_("Total Gain"),
+	_("Horizontal Polarization"),
+	_("Vertical Polarization"),
+	_("RH Circular Polarization"),
+	_("LH Circular Polarization")
   };
 
   char *scale[NUM_SCALES] =
   {
-	"Linear Power",
-	"Linear Voltage",
-	"ARRL Scale",
-	"Logarithmic Scale"
+	_("Linear Power"),
+	_("Linear Voltage"),
+	_("ARRL Scale"),
+	_("Logarithmic Scale")
   };
 
   char txt[64];
+  size_t s = sizeof( txt );
 
   if( isFlagSet(DRAW_ENABLED) )
   {
 	/* Set window labels */
-	strcpy( txt, "Radiation Patterns" );
+	Strlcpy( txt, _("Radiation Patterns"), s );
 	if( isFlagSet(DRAW_GAIN) )
 	{
-	  strcpy( txt, "Radiation Pattern: - " );
-	  strcat( txt, pol_type[calc_data.pol_type] );
-	  strcat( txt, " - " );
-	  strcat( txt, scale[gain_style] );
+	  Strlcpy( txt, _("Radiation Pattern: - "), s );
+	  Strlcat( txt, pol_type[calc_data.pol_type], s );
+	  Strlcat( txt, " - ", s );
+	  Strlcat( txt, scale[gain_style], s );
+	}
+	else if( isFlagSet(DRAW_EHFIELD) )
+	{
+	  Strlcpy( txt, _("Near Fields:"), s );
+	  if( isFlagSet(DRAW_EFIELD) )
+		Strlcat( txt, _(" - E Field"), s );
+	  if( isFlagSet(DRAW_HFIELD) )
+		Strlcat( txt, _(" - H Field"), s );
+	  if( isFlagSet(DRAW_POYNTING) )
+		Strlcat( txt, _(" - Poynting Vector"), s );
 	}
-	else
-	  if( isFlagSet(DRAW_EHFIELD) )
-	  {
-		strcpy( txt, "Near Fields:" );
-		if( isFlagSet(DRAW_EFIELD) )
-		  strcat( txt, " - E Field" );
-		if( isFlagSet(DRAW_HFIELD) )
-		  strcat( txt, " - H Field" );
-		if( isFlagSet(DRAW_POYNTING) )
-		  strcat( txt, " - Poynting Vector" );
-	  }
 
 	gtk_label_set_text( GTK_LABEL(lookup_widget(
 			rdpattern_window, "rdpattern_label")), txt );
@@ -1039,8 +1003,8 @@ Set_Window_Labels( void )
 
   if( isFlagSet(PLOT_ENABLED) )
   {
-	strcpy( txt, "Frequency Data Plots - " );
-	strcat( txt, pol_type[calc_data.pol_type] );
+	Strlcpy( txt, _("Frequency Data Plots - "), s );
+	Strlcat( txt, pol_type[calc_data.pol_type], s );
 	gtk_label_set_text( GTK_LABEL(lookup_widget(
 			freqplots_window, "freqplots_label")), txt );
   }
@@ -1063,62 +1027,52 @@ Alloc_Rdpattern_Buffers( int nfrq, int nth, int nph )
   /* Free old gain buffers first */
   for( idx = 0; idx < last_nfrq; idx++ )
   {
-	free_ptr( (void *)&rad_pattern[idx].gtot );
-	free_ptr( (void *)&rad_pattern[idx].max_gain );
-	free_ptr( (void *)&rad_pattern[idx].min_gain );
-	free_ptr( (void *)&rad_pattern[idx].max_gain_tht );
-	free_ptr( (void *)&rad_pattern[idx].max_gain_phi );
-	free_ptr( (void *)&rad_pattern[idx].max_gain_idx );
-	free_ptr( (void *)&rad_pattern[idx].min_gain_idx );
-	free_ptr( (void *)&rad_pattern[idx].axrt );
-	free_ptr( (void *)&rad_pattern[idx].tilt );
-	free_ptr( (void *)&rad_pattern[idx].sens );
+	free_ptr( (void **)&rad_pattern[idx].gtot );
+	free_ptr( (void **)&rad_pattern[idx].max_gain );
+	free_ptr( (void **)&rad_pattern[idx].min_gain );
+	free_ptr( (void **)&rad_pattern[idx].max_gain_tht );
+	free_ptr( (void **)&rad_pattern[idx].max_gain_phi );
+	free_ptr( (void **)&rad_pattern[idx].max_gain_idx );
+	free_ptr( (void **)&rad_pattern[idx].min_gain_idx );
+	free_ptr( (void **)&rad_pattern[idx].axrt );
+	free_ptr( (void **)&rad_pattern[idx].tilt );
+	free_ptr( (void **)&rad_pattern[idx].sens );
   }
   last_nfrq = nfrq;
 
   /* Allocate rad pattern buffers */
-  mem_realloc( (void *)&rad_pattern,
-	  nfrq * sizeof(rad_pattern_t), "in draw_radiation.c" );
-
+  mreq = (size_t)nfrq * sizeof(rad_pattern_t);
+  mem_realloc( (void **)&rad_pattern, mreq, "in draw_radiation.c" );
   for( idx = 0; idx < nfrq; idx++ )
   {
 	/* Memory request for allocs */
-	mreq = nph * nth * sizeof(double);
+	mreq = (size_t)(nph * nth) * sizeof(double);
 	rad_pattern[idx].gtot = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].gtot, mreq,
-		"in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].gtot), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].axrt = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].axrt, mreq,
-		"in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].axrt), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].tilt = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].tilt, mreq,
-		"in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].tilt), mreq, "in draw_radiation.c" );
 
 	mreq = NUM_POL * sizeof(double);
 	rad_pattern[idx].max_gain = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].max_gain, mreq,
-		"in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].max_gain), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].min_gain = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].min_gain, mreq,
-		"in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].min_gain), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].max_gain_tht = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].max_gain_tht,
-		mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].max_gain_tht), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].max_gain_phi = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].max_gain_phi,
-		mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].max_gain_phi), mreq, "in draw_radiation.c" );
 
 	mreq = NUM_POL * sizeof(int);
 	rad_pattern[idx].max_gain_idx = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].max_gain_idx,
-		mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].max_gain_idx), mreq, "in draw_radiation.c" );
 	rad_pattern[idx].min_gain_idx = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].min_gain_idx,
-		mreq, "in draw_radiation.c" );
+	mem_alloc( (void **)&(rad_pattern[idx].min_gain_idx), mreq, "in draw_radiation.c" );
 
 	rad_pattern[idx].sens = NULL;
-	mem_alloc( (void *)&rad_pattern[idx].sens,
-		nph * nth * sizeof(int), "in draw_radiation.c" );
+	mreq = (size_t)(nph * nth) * sizeof(int);
+	mem_alloc( (void **)&(rad_pattern[idx].sens), mreq, "in draw_radiation.c" );
   }
 
 } /* Alloc_Rdpattern_Buffers() */
@@ -1138,40 +1092,40 @@ Alloc_Nearfield_Buffers( int n1, int n2, int n3 )
   ClearFlag( ALLOC_NEAREH_BUFF );
 
   /* Memory request for allocations */
-  mreq = n1 * n2 * n3 * sizeof( double );
+  mreq = (size_t)(n1 * n2 * n3) * sizeof( double );
 
   /* Allocate near field buffers */
   if( fpat.nfeh & NEAR_EFIELD )
   {
-	mem_realloc( (void *)&near_field.ex,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.ey,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.ez,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fex, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fey, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fez, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.erx, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.ery, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.erz, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.er,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.ex,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.ey,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.ez,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fex, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fey, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fez, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.erx, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.ery, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.erz, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.er,  mreq, "in draw_radiation.c" );
   }
 
   if( fpat.nfeh & NEAR_HFIELD )
   {
-	mem_realloc( (void *)&near_field.hx,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hy,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hz,  mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fhx, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fhy, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.fhz, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hrx, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hry, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hrz, mreq, "in draw_radiation.c" );
-	mem_realloc( (void *)&near_field.hr,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hx,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hy,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hz,  mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fhx, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fhy, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.fhz, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hrx, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hry, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hrz, mreq, "in draw_radiation.c" );
+	mem_realloc( (void **)&near_field.hr,  mreq, "in draw_radiation.c" );
   }
 
-  mem_realloc( (void *)&near_field.px, mreq, "in draw_radiation.c" );
-  mem_realloc( (void *)&near_field.py, mreq, "in draw_radiation.c" );
-  mem_realloc( (void *)&near_field.pz, mreq, "in draw_radiation.c" );
+  mem_realloc( (void **)&near_field.px, mreq, "in draw_radiation.c" );
+  mem_realloc( (void **)&near_field.py, mreq, "in draw_radiation.c" );
+  mem_realloc( (void **)&near_field.pz, mreq, "in draw_radiation.c" );
 
 } /* Alloc_Nearfield_Buffers() */
 
@@ -1184,10 +1138,10 @@ Alloc_Nearfield_Buffers( int n1, int n2, int n3 )
   void
 Free_Draw_Buffers( void )
 {
-  free_ptr( (void *)&point_3d );
-  free_ptr( (void *)&red );
-  free_ptr( (void *)&grn );
-  free_ptr( (void *)&blu );
+  free_ptr( (void **)&point_3d );
+  free_ptr( (void **)&red );
+  free_ptr( (void **)&grn );
+  free_ptr( (void **)&blu );
 }
 
 /*-----------------------------------------------------------------------*/
