@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,77 +22,8 @@
  *  Structure drawing routines for xnec2c
  */
 
-#ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
-#include <gtk/gtk.h>
-#include <gdk/gdk.h>
-
-#include "xnec2c.h"
-#include "support.h"
-
-/* Current data */
-extern crnt_t crnt;
-
-/* Geometry data */
-extern data_t data;
-
-/* Network data */
-extern netcx_t netcx;
-
-/* Excitation data */
-extern vsorc_t vsorc;
-
-/* Loading data */
-extern zload_t zload;
-
-/* Saved data buffer */
-extern save_t save;
-
-/* Ground data */
-extern gnd_t gnd;
-
-/* Field pattern data */
-extern fpat_t fpat;
-
-/* Data needed during prog execution */
-extern calc_data_t calc_data;
-
-/* Structure drawing area widget */
-extern GtkWidget *structure_drawingarea;
-extern GtkWidget *main_window;
-
-/* Pixmap for structure drawing */
-extern GdkPixmap *structure_pixmap;
-extern int structure_pixmap_width, structure_pixmap_height;
-
-/* Parameters for projecting structure and rad pattern to Screen */
-extern projection_parameters_t structure_proj_params;
-extern projection_parameters_t rdpattern_proj_params;
-
-/* Plots and Radiation pattern drawingareas */
-extern GtkWidget *rdpattern_window;
-
-/* Pixmap for drawing plots */
-extern GdkPixmap *freqplots_pixmap;
-extern int freqplots_pixmap_width, freqplots_pixmap_height;
-
-/* Pixmap for drawing radiation patterns */
-extern GdkPixmap *rdpattern_pixmap;
-extern int rdpattern_pixmap_width, rdpattern_pixmap_height;
-
-/* Some graphics contexts */
-extern GdkGC
-  *white_gc,
-  *black_gc,
-  *plot_gc;
-
-/* Segments for drawing structure */
-GdkSegment *structure_segs = NULL;
-
-/* Magnitude of seg/patch current/charge */
-double *cmag = NULL, *ct1m = NULL, *ct2m = NULL;
+#include "draw_structure.h"
+#include "shared.h"
 
 /*-----------------------------------------------------------------------*/
 
@@ -102,40 +32,50 @@ double *cmag = NULL, *ct1m = NULL, *ct2m = NULL;
  *  Draws xyz axes, wire segments and patches
  */
   void
-Draw_Structure( GtkWidget *drawingarea, GdkGC *gc )
+Draw_Structure( GtkWidget *drawingarea )
 {
   /* Abort if xnec2c may be quit by user */
   if( isFlagSet(MAIN_QUIT) )
 	return;
 
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( structure_pixmap );
+
   /* Clear pixmap */
-  gdk_draw_rectangle(
-	  structure_pixmap,
-	  black_gc,
-	  TRUE, 0, 0,
-	  structure_proj_params.pixmap_width,
-	  structure_proj_params.pixmap_height);
+  cairo_set_source_rgb( cr, BLACK );
+  cairo_rectangle(
+	  cr, 0.0, 0.0,
+	  (double)structure_proj_params.pixmap_width,
+	  (double)structure_proj_params.pixmap_height);
+  cairo_fill( cr );
 
   /* Process and draw geometry if available, else clear screen */
   Process_Wire_Segments();
   Process_Surface_Patches();
   Draw_XYZ_Axes( structure_pixmap, structure_proj_params );
-  Draw_Surface_Patches( drawingarea, gc, structure_segs+data.n, data.m );
-  Draw_Wire_Segments( drawingarea, gc, structure_segs, data.n );
+  Draw_Surface_Patches( structure_segs+data.n, data.m );
+  Draw_Wire_Segments( structure_segs, data.n );
 
   /* Show gain in direction of viewer */
-  Show_Viewer_Gain( main_window, "main_gain_entry", structure_proj_params );
+  Show_Viewer_Gain( main_window,
+	  "main_gain_entry", structure_proj_params );
 
   /* Render pixmap to screen */
-  gdk_window_set_back_pixmap( drawingarea->window, structure_pixmap, FALSE );
+  gdk_window_set_back_pixmap(
+	  drawingarea->window, structure_pixmap, FALSE );
   gdk_window_clear( drawingarea->window );
 
   /* Reset "new current data" flag */
   crnt.newer = 0;
 
+  /* Display frequency step */
+  Display_Fstep( structure_fstep_entry, calc_data.fstep );
+
   /* Wait for GTK to complete its tasks */
   while( g_main_context_iteration(NULL, FALSE) );
 
+  cairo_destroy( cr );
+
 } /* Draw_Structure() */
 
 /*-----------------------------------------------------------------------*/
@@ -148,16 +88,15 @@ Draw_Structure( GtkWidget *drawingarea, GdkGC *gc )
   void
 New_Wire_Data( void )
 {
+  /* Abort if no wire data */
+  if( data.n == 0 )	return;
+
   double
 	r,	   /* Distance of a point from XYZ origin */
 	r_max; /* Maximum value of above */
 
   int idx;
 
-
-  /* Abort if no wire data */
-  if( data.n == 0 )	return;
-
   /* Find segment end furthest from xyz axes origin */
   r_max = 0.0;
   for( idx = 0; idx < data.n; idx++ )
@@ -200,27 +139,26 @@ New_Wire_Data( void )
   void
 New_Patch_Data( void )
 {
+  /* Abort if no patch data */
+  if( data.m == 0 )	return;
+
   double
-	s,		/* Side/2 of a square that will represent a patch  */
+	s,			/* Side/2 of a square that will represent a patch  */
 	sx, sy, sz, /* Length of components of s in the X, Y, Z axes */
-	r,		/* Distance of points in patch from XYZ co-ordinates */
-	r_max;	/* Maximum value of above */
+	r,			/* Distance of points in patch from XYZ co-ordinates */
+	r_max;		/* Maximum value of above */
 
   int idx, i;
   size_t mreq;
 
-
-  /* Abort if no patch data */
-  if( data.m == 0 )	return;
-
   /* Allocate memory for patch line segments */
-  mreq = 2 * data.m * sizeof(double);
-  mem_realloc( (void *)&data.px1, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.py1, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.pz1, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.px2, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.py2, mreq, "in draw_structure.c" );
-  mem_realloc( (void *)&data.pz2, mreq, "in draw_structure.c" );
+  mreq = (size_t)(2 * data.m) * sizeof(double);
+  mem_realloc( (void **)&data.px1, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.py1, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.pz1, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.px2, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.py2, mreq, "in draw_structure.c" );
+  mem_realloc( (void **)&data.pz2, mreq, "in draw_structure.c" );
 
   /* Find point furthest from xyz axes origin */
   r_max = 0.0;
@@ -229,7 +167,7 @@ New_Patch_Data( void )
 	i = 2 * idx;
 
 	/* Side/2 of square representing a patch (sqrt of patch area) */
-	s = sqrt( data.pbi[idx] ) / 2.0;
+	s = (double)sqrt( data.pbi[idx] ) / 2.0;
 
 	/* Projection of s on xyz components of t1 */
 	sx = s * (double)data.t1x[idx];
@@ -370,18 +308,17 @@ Process_Surface_Patches( void )
  */
 
 void
-Draw_Wire_Segments(
-	GtkWidget *drawingarea,
-	GdkGC *gc,
-	GdkSegment *segm,
-	gint nseg )
+Draw_Wire_Segments(	GdkSegment *segm, gint nseg )
 {
-  int idx, i;
-
   /* Abort if no wire segs or new input pending */
   if( !nseg || isFlagSet(INPUT_PENDING) )
 	return;
 
+  int idx, i;
+
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( structure_pixmap );
+
   /* Draw networks */
   for( idx = 0; idx < netcx.nonet; idx++ )
   {
@@ -396,9 +333,6 @@ Draw_Wire_Segments(
 		{
 		  GdkPoint points[4];
 
-		  /* Set gc attributes for networks */
-		  Set_GC_Attributes( gc, MAGENTA, 0, drawingarea );
-
 		  /* Draw a box between segs to represent two-port network */
 		  points[0].x = segm[i1].x1 + (segm[i2].x1 - segm[i1].x1)/3;
 		  points[0].y = segm[i1].y1 + (segm[i2].y1 - segm[i1].y1)/3;
@@ -408,59 +342,43 @@ Draw_Wire_Segments(
 		  points[2].y = segm[i2].y2 + (segm[i1].y2 - segm[i2].y2)/3;
 		  points[3].x = segm[i1].x2 + (segm[i2].x2 - segm[i1].x2)/3;
 		  points[3].y = segm[i1].y2 + (segm[i2].y2 - segm[i1].y2)/3;
-		  gdk_draw_polygon( structure_pixmap, gc, TRUE, points, 4  );
 
-		  /* Draw connecting lines */
-		  gdk_draw_line(
-			  structure_pixmap, gc,
-			  segm[i1].x1,
-			  segm[i1].y1,
-			  segm[i2].x1,
-			  segm[i2].y1 );
+		  cairo_set_source_rgb( cr, MAGENTA );
+		  Cairo_Draw_Polygon( cr, points, 4 );
+		  cairo_fill( cr );
 
-		  gdk_draw_line(
-			  structure_pixmap, gc,
-			  segm[i1].x2,
-			  segm[i1].y2,
-			  segm[i2].x2,
-			  segm[i2].y2 );
-		  break;
+			/* Draw connecting lines */
+		  Cairo_Draw_Line( cr,
+			  segm[i1].x1, segm[i1].y1,
+			  segm[i2].x1, segm[i2].y1 );
+		  Cairo_Draw_Line( cr,
+			  segm[i1].x2, segm[i1].y2,
+			  segm[i2].x2, segm[i2].y2 );
 		}
+		break;
 
 	  case 2: /* Straight transmission line */
-		/* Set gc attributes for networks */
-		Set_GC_Attributes( gc, CYAN, 0, drawingarea );
-		gdk_draw_line(
-			structure_pixmap, gc,
-			segm[i1].x1,
-			segm[i1].y1,
-			segm[i2].x1,
-			segm[i2].y1 );
+		/* Set cr attributes for transmission line */
+		cairo_set_source_rgb( cr, CYAN );
 
-		gdk_draw_line(
-			structure_pixmap, gc,
-			segm[i1].x2,
-			segm[i1].y2,
-			segm[i2].x2,
-			segm[i2].y2 );
+		Cairo_Draw_Line( cr,
+			segm[i1].x1, segm[i1].y1,
+			segm[i2].x1, segm[i2].y1 );
+		Cairo_Draw_Line( cr,
+			segm[i1].x2, segm[i1].y2,
+			segm[i2].x2, segm[i2].y2 );
 		break;
 
 	  case 3: /* Crossed transmisson line */
-		/* Set gc attributes for networks */
-		Set_GC_Attributes( gc, CYAN, 0, drawingarea );
-		gdk_draw_line(
-			structure_pixmap, gc,
-			segm[i1].x1,
-			segm[i1].y1,
-			segm[i2].x2,
-			segm[i2].y2 );
+		/* Set cr attributes for transmission line */
+		cairo_set_source_rgb( cr, CYAN );
 
-		gdk_draw_line(
-			structure_pixmap, gc,
-			segm[i1].x2,
-			segm[i1].y2,
-			segm[i2].x1,
-			segm[i2].y1 );
+		Cairo_Draw_Line( cr,
+			segm[i1].x1, segm[i1].y1,
+			segm[i2].x2, segm[i2].y2 );
+		Cairo_Draw_Line( cr,
+			segm[i1].x2, segm[i1].y2,
+			segm[i2].x1, segm[i2].y1 );
 
 	} /* switch( netcx.ntyp ) */
 
@@ -475,8 +393,10 @@ Draw_Wire_Segments(
 	  crnt.valid )
   {
 	static double cmax; /* Max of seg current/charge */
-	int red, grn, blu;  /* To color structure segs   */
-	char label[20];
+	/* To color structure segs */
+	double red = 0.0, grn = 0.0, blu = 0.0;
+	char label[11];
+	size_t s = sizeof( label );
 
 	/* Loop over all wire segs, find max current/charge */
 	if( crnt.newer )
@@ -486,10 +406,10 @@ Draw_Wire_Segments(
 	  {
 		if( isFlagSet(DRAW_CURRENTS) )
 		  /* Calculate segment current magnitude */
-		  cmag[idx] = (double)cabsl( crnt.cur[idx] );
+		  cmag[idx] = (double)cabs( crnt.cur[idx] );
 		else
 		  /* Calculate segment charge density */
-		  cmag[idx] = (double)cabsl( cmplx(crnt.bii[idx], crnt.bir[idx]) );
+		  cmag[idx] = (double)cabs( cmplx(crnt.bii[idx], crnt.bir[idx]) );
 
 		/* Find max current/charge magnitude */
 		if( cmag[idx] > cmax )
@@ -498,9 +418,9 @@ Draw_Wire_Segments(
 
 	  /* Show max value in color code label */
 	  if( isFlagSet(DRAW_CURRENTS) )
-		sprintf( label, "%10.3E", cmax * (double)data.wlam );
+		snprintf( label, s, "%10.3E", cmax * (double)data.wlam );
 	  else
-		sprintf( label, "%10.3E", cmax * 1.0E-6/(double)calc_data.fmhz );
+		snprintf( label, s, "%10.3E", cmax * 1.0E-6/(double)calc_data.fmhz );
 	  gtk_label_set_text(
 		  GTK_LABEL(lookup_widget(structure_drawingarea,
 			  "main_colorcode_maxlabel")), label );
@@ -513,80 +433,84 @@ Draw_Wire_Segments(
 	  /* Calculate RGB value for seg current */
 	  Value_to_Color( &red, &grn, &blu, cmag[idx], cmax );
 
-	  /* Set gc attributes for segment */
-	  Set_GC_Attributes( gc, red, grn, blu, 2, drawingarea );
+	  /* Set cr attributes for segment */
+	  cairo_set_source_rgb( cr, red, grn, blu );
 
 	  /* Draw segment */
-	  gdk_draw_line(
-		  structure_pixmap, gc,
-		  segm[idx].x1,
-		  segm[idx].y1,
-		  segm[idx].x2,
-		  segm[idx].y2 );
-
+	  Cairo_Draw_Line( cr,
+		  segm[idx].x1, segm[idx].y1,
+		  segm[idx].x2, segm[idx].y2 );
 	} /* for( idx = 0; idx < nseg; idx++ ) */
 
+	cairo_destroy( cr );
 	return;
-
   } /* if( isFlagSet(DRAW_CURRENTS) || isFlagSet(DRAW_CHARGES) ) */
 
   /* Draw segs if not all loaded */
+  cairo_set_line_width( cr, 2.0 );
   if( zload.nldseg != nseg )
   {
 	/* Set gc attributes for segments */
-	if( isFlagSet(OVERLAY_STRUCT) && isFlagSet(DRAW_EHFIELD) )
-	  Set_GC_Attributes( gc, WHITE, 2, drawingarea );
+	if( isFlagSet(OVERLAY_STRUCT) &&
+		(structure_proj_params.type == RDPATTERN_DRAWINGAREA) )
+	  cairo_set_source_rgb( cr, WHITE );
 	else
-	  Set_GC_Attributes( gc, BLUE, 2, drawingarea );
+	  cairo_set_source_rgb( cr, BLUE );
 
 	/* Draw wire segments */
-	gdk_draw_segments( structure_pixmap, gc, segm, nseg );
+	Cairo_Draw_Segments( cr, segm, nseg );
   }
 
-  /* Draw loaded segments */
+  /* Draw lumped loaded segments */
+  cairo_set_source_rgb( cr, YELLOW );
+  cairo_set_line_width( cr, 9.0 );
   for( idx = 0; idx < zload.nldseg; idx++ )
   {
-	/* Set gc attributes for loaded segs */
-	if( zload.ldtype[idx] == 5 ) /* Finite wire resistivity */
-	  Set_GC_Attributes( gc, YELLOW, 2, drawingarea );
-	else /* Lumped loads */
-	  Set_GC_Attributes( gc, YELLOW, 4, drawingarea );
-
-	i = zload.ldsegn[idx]-1;
-	gdk_draw_line(
-		structure_pixmap, gc,
-		segm[i].x1,
-		segm[i].y1,
-		segm[i].x2,
-		segm[i].y2 );
+	if( zload.ldtype[idx] != 5 )
+	{
+	  i = zload.ldsegn[idx]-1;
+	  Cairo_Draw_Line( cr,
+		  segm[i].x1, segm[i].y1,
+		  segm[i].x2, segm[i].y2 );
+	}
   }
 
   /* Set gc attributes for excitation */
-  Set_GC_Attributes( gc, RED, 2, drawingarea );
+  cairo_set_source_rgb( cr, RED );
+  cairo_set_line_width( cr, 5.0 );
 
   /* Draw excitation sources */
   for( idx = 0; idx < vsorc.nsant; idx++ )
   {
 	i = vsorc.isant[idx]-1;
-	gdk_draw_line(
-		structure_pixmap, gc,
-		segm[i].x1,
-		segm[i].y1,
-		segm[i].x2,
-		segm[i].y2 );
+	Cairo_Draw_Line( cr,
+		segm[i].x1, segm[i].y1,
+		segm[i].x2, segm[i].y2 );
   }
 
   for( idx = 0; idx < vsorc.nvqd; idx++ )
   {
 	i = vsorc.ivqd[idx]-1;
-	gdk_draw_line(
-		structure_pixmap, gc,
-		segm[i].x1,
-		segm[i].y1,
-		segm[i].x2,
-		segm[i].y2 );
+	Cairo_Draw_Line( cr,
+		segm[i].x1, segm[i].y1,
+		segm[i].x2, segm[i].y2 );
   }
 
+  /* Draw resistivity loaded segments */
+  cairo_set_source_rgb( cr, YELLOW );
+  cairo_set_line_width( cr, 2.0 );
+  for( idx = 0; idx < zload.nldseg; idx++ )
+  {
+	if( zload.ldtype[idx] == 5 )
+	{
+	  i = zload.ldsegn[idx]-1;
+	  Cairo_Draw_Line( cr,
+		  segm[i].x1, segm[i].y1,
+		  segm[i].x2, segm[i].y2 );
+	}
+  }
+
+  cairo_destroy( cr );
 } /* Draw_Wire_Segments() */
 
 /*-----------------------------------------------------------------------*/
@@ -596,16 +520,15 @@ Draw_Wire_Segments(
  *  Draws the line segments that represent surface patches
  */
 void
-Draw_Surface_Patches(
-	GtkWidget *drawingarea,
-	GdkGC *gc,
-	GdkSegment *segm,
-	gint npatch )
+Draw_Surface_Patches( GdkSegment *segm, gint npatch )
 {
   /* Abort if no patches */
   if( ! npatch )
 	return;
 
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( structure_pixmap );
+
   /* Draw currents if enabled, return */
   if( isFlagSet(DRAW_CURRENTS) && crnt.valid )
   {
@@ -615,7 +538,9 @@ Draw_Surface_Patches(
 	/* Current along x,y,z and t1,t2 vector directions */
 	complex double cx, cy, cz, ct1, ct2;
 
-	int red, grn, blu, i, j;
+	double red = 0.0, grn = 0.0, blu = 0.0;
+
+	int i, j;
 
 	/* Find max value of patch current magnitude */
 	if( crnt.newer )
@@ -639,8 +564,8 @@ Draw_Surface_Patches(
 		  cz*(double)data.t2z[i];
 
 		/* Save current magnitudes */
-		ct1m[i] = (double)cabsl( ct1 );
-		ct2m[i] = (double)cabsl( ct2 );
+		ct1m[i] = (double)cabs( ct1 );
+		ct2m[i] = (double)cabs( ct2 );
 
 		/* Find current magnitude max */
 		if( ct1m[i] > cmax ) cmax = ct1m[i];
@@ -660,47 +585,50 @@ Draw_Surface_Patches(
 	  /* Calculate RGB value for patch t1 current */
 	  Value_to_Color( &red, &grn, &blu, ct1m[i], cmax );
 
-	  /* Set gc attributes for patch t1 */
-	  Set_GC_Attributes( gc, red, grn, blu, 2, drawingarea );
+	  /* Set cr attributes for patch t1 */
+	  cairo_set_source_rgb( cr, red, grn, blu );
 
 	  /* Draw patch t1 */
-	  gdk_draw_line(
-		  structure_pixmap, gc,
-		  segm[j].x1,
-		  segm[j].y1,
-		  segm[j].x2,
-		  segm[j].y2 );
+	  Cairo_Draw_Line( cr,
+		  segm[j].x1, segm[j].y1,
+		  segm[j].x2, segm[j].y2 );
 
 	  /* Calculate RGB value for patch t2 current */
 	  Value_to_Color( &red, &grn, &blu, ct2m[i], cmax );
 
-	  /* Set gc attributes for patch t2 */
-	  Set_GC_Attributes( gc, red, grn, blu, 2, drawingarea );
+	  /* Set cr attributes for patch t2 */
+	  cairo_set_source_rgb( cr, red, grn, blu );
 
 	  /* Draw patch t2 */
 	  j++;
-	  gdk_draw_line(
-		  structure_pixmap, gc,
-		  segm[j].x1,
-		  segm[j].y1,
-		  segm[j].x2,
-		  segm[j].y2 );
+	  Cairo_Draw_Line( cr,
+		  segm[j].x1, segm[j].y1,
+		  segm[j].x2, segm[j].y2 );
 
 	} /* for( idx = 0; idx < npatch; idx++ ) */
 
   } /* if( isFlagSet(DRAW_CURRENTS) ) */
   else
   {
+	int idx;
+
 	/* Set gc attributes for patches */
-	if( isFlagSet(OVERLAY_STRUCT) && isFlagSet(DRAW_EHFIELD) )
-	  Set_GC_Attributes( gc, WHITE, 2, drawingarea );
-	else
-	  Set_GC_Attributes( gc, BLUE, 2, drawingarea );
+	if( isFlagSet(OVERLAY_STRUCT) &&
+		(structure_proj_params.type == RDPATTERN_DRAWINGAREA) )
+	  cairo_set_source_rgb( cr, WHITE );
+	else cairo_set_source_rgb( cr, BLUE );
 
 	/* Draw patch segments */
-	gdk_draw_segments( structure_pixmap, gc, segm, 2*npatch );
+	int nsg = 2 * npatch;
+	for( idx = 0; idx < nsg; idx++ )
+	{
+	  Cairo_Draw_Line( cr,
+		  segm[idx].x1, segm[idx].y1,
+		  segm[idx].x2, segm[idx].y2 );
+	}
   }
 
+  cairo_destroy( cr );
 } /* Draw_Surface_Patches() */
 
 /*-----------------------------------------------------------------------*/
@@ -710,7 +638,7 @@ Draw_Surface_Patches(
  * Refreshes plots on new frequency in spinbutton
  */
   gboolean
-Redo_Currents( gpointer userdata )
+Redo_Currents( gpointer udata )
 {
   /* Abort if no geometry data */
   if( ((data.n == 0) && (data.m == 0)) ||
@@ -719,7 +647,7 @@ Redo_Currents( gpointer userdata )
 
   /* Makes calcs use the extra buffer in rad_pattern */
   calc_data.fstep = calc_data.nfrq;
-  save.last_freq = 0.0l;
+  save.last_freq = 0.0;
   New_Frequency();
 
   /* Display freq data in entry widgets */
@@ -729,10 +657,9 @@ Redo_Currents( gpointer userdata )
   /* Redraw structure on screen */
   if( (structure_drawingarea != NULL) &&
 	  (isFlagSet(DRAW_CURRENTS) || isFlagSet(DRAW_CHARGES)) )
-	Draw_Structure( structure_drawingarea, plot_gc );
+	Draw_Structure( structure_drawingarea );
 
   return FALSE;
-
 } /* Redo_Currents() */
 
 /*-----------------------------------------------------------------------*/
@@ -746,13 +673,14 @@ Redo_Currents( gpointer userdata )
 New_Structure_Projection_Angle(void)
 {
   /* sin and cos of structure rotation and inclination angles */
-  structure_proj_params.sin_wr = sin(structure_proj_params.Wr/TD);
-  structure_proj_params.cos_wr = cos(structure_proj_params.Wr/TD);
-  structure_proj_params.sin_wi = sin(structure_proj_params.Wi/TD);
-  structure_proj_params.cos_wi = cos(structure_proj_params.Wi/TD);
+  structure_proj_params.sin_wr = sin(structure_proj_params.Wr/(double)TD);
+  structure_proj_params.cos_wr = cos(structure_proj_params.Wr/(double)TD);
+  structure_proj_params.sin_wi = sin(structure_proj_params.Wi/(double)TD);
+  structure_proj_params.cos_wi = cos(structure_proj_params.Wi/(double)TD);
 
   /* Trigger a redraw of structure drawingarea */
-  Draw_Structure( structure_drawingarea, plot_gc );
+  if( isFlagClear(INPUT_PENDING) )
+	Draw_Structure( structure_drawingarea );
 
   /* Trigger a redraw of plots drawingarea */
   if( isFlagSet(PLOT_ENABLED) && isFlagSet(PLOT_GVIEWER) )
@@ -770,8 +698,8 @@ New_Structure_Projection_Angle(void)
 Init_Struct_Drawing( void )
 {
   /* We need n segs for wires + 2m for patces */
-  mem_realloc( (void *)&structure_segs,
-	  (data.n+2*data.m) * sizeof(GdkSegment), "in draw_structure.c" );
+  size_t mreq = (size_t)(data.n + 2*data.m) * sizeof(GdkSegment);
+  mem_realloc( (void **)&structure_segs, mreq, "in draw_structure.c" );
   New_Wire_Data();
   New_Patch_Data();
 }
@@ -782,28 +710,26 @@ Init_Struct_Drawing( void )
  *
  * Shows gain in direction of viewer
  */
-void
+  void
 Show_Viewer_Gain(
 	GtkWidget *window,
 	const char *widget,
 	projection_parameters_t proj_params )
 {
-  if( isFlagSet(DRAW_CURRENTS) ||
-	  isFlagSet(DRAW_CHARGES)  ||
-	  isFlagSet(DRAW_GAIN) )
+  if( isFlagSet(DRAW_CURRENTS)	||
+	  isFlagSet(DRAW_CHARGES)	||
+	  isFlagSet(DRAW_GAIN)		||
+	  isFlagSet(FREQ_LOOP_RUNNING) )
   {
-	char txt[10];
+	char txt[8];
 
-	if( isFlagSet(ENABLE_RDPAT) && (calc_data.fstep >=0) )
+	if( isFlagSet(ENABLE_RDPAT) && (calc_data.fstep >= 0) )
 	{
-	  sprintf( txt, "%7.2f",
+	  snprintf( txt, sizeof(txt), "%7.2f",
 		  Viewer_Gain(proj_params, calc_data.fstep) );
-	  txt[7] = '\0';
+	  gtk_entry_set_text(
+		  GTK_ENTRY(lookup_widget(window, widget)), txt );
 	}
-	else
-	  strcpy( txt, "   -----" );
-
-	gtk_entry_set_text( GTK_ENTRY(lookup_widget(window, widget)), txt );
   }
 
 } /* Show_Viewer_Gain() */
