@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,48 +16,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "xnec2c.h"
+/* fork.c
+ *
+ * Functions for forking xnec2c in multiprocessor systems
+ */
+
 #include "fork.h"
-
-/* Pointers to input/output files */
-extern FILE *input_fp;
-extern char infile[81];
-
-/* Data needed during prog execution */
-extern calc_data_t calc_data;
-
-/* common  /crnt/ */
-extern crnt_t crnt;
-
-/* common /fpat/ */
-extern fpat_t fpat;
-
-/* Network data */
-extern netcx_t netcx;
-
-/* Input impedance data */
-extern impedance_data_t impedance_data;
-
-/* Geometry data (common /data/) */
-extern data_t data;
-
-/* Near E/H field data */
-extern near_field_t near_field;
-
-/* Radiation pattern data */
-extern rad_pattern_t *rad_pattern;
-
-/* Saved data buffer */
-extern save_t save;
-
-/* Forked process data */
-extern forkpc_t **forkpc;
-
-/* Number of child process */
-extern int nchild;
-
-/* Commands between parent and child processes */
-extern char *comnd[];
+#include "shared.h"
 
 /*-----------------------------------------------------------------------*/
 
@@ -67,33 +31,40 @@ extern char *comnd[];
  * Destination of child processes, handles data
  * transfers between parent and children via pipes
  */
+void Child_Process( int num_child ) __attribute__ ((noreturn));
   void
-Child_Process( void )
+Child_Process( int num_child )
 {
-  int retval;	/* Return from select()/read() etc */
-  char cmnd[8];	/* Command string received from parent */
-  char *buff;	/* Passes address of variables to read()/write() */
-  size_t cnt;	/* Size of data buffers for read()/write() */
+  ssize_t retval;	/* Return from select()/read() etc */
+  char cmnd[8];		/* Command string received from parent */
+  char *buff;		/* Passes address of variables to read()/write() */
+  size_t cnt;		/* Size of data buffers for read()/write() */
 
   /* Close unwanted pipe ends */
-  close( forkpc[nchild]->p2ch_pipe[WRITE] );
-  close( forkpc[nchild]->ch2p_pipe[READ] );
+  close( forked_proc_data[num_child]->pnt2child_pipe[WRITE] );
+  close( forked_proc_data[num_child]->child2pnt_pipe[READ] );
 
   /* Watch read/write pipe for i/o */
-  FD_ZERO( &forkpc[nchild]->read_fds );
-  FD_SET( forkpc[nchild]->p2ch_pipe[READ], &forkpc[nchild]->read_fds );
-  FD_ZERO( &forkpc[nchild]->write_fds );
-  FD_SET( forkpc[nchild]->ch2p_pipe[WRITE], &forkpc[nchild]->write_fds );
+  FD_ZERO( &forked_proc_data[num_child]->read_fds );
 
-  /* Loop around select() waiting for commands/data */
+  FD_SET( forked_proc_data[num_child]->pnt2child_pipe[READ],
+	  &forked_proc_data[num_child]->read_fds );
+
+  FD_ZERO( &forked_proc_data[num_child]->write_fds );
+
+  FD_SET( forked_proc_data[num_child]->child2pnt_pipe[WRITE],
+	  &forked_proc_data[num_child]->write_fds );
+
+  /* Loop around select() in Read_Pipe() waiting for commands/data */
   while( TRUE )
   {
-	retval = Read_Pipe( nchild, cmnd, 7, TRUE );
+	retval = Read_Pipe( num_child, cmnd, 7, TRUE );
 	cmnd[retval]='\0';
+
 	switch( Fork_Command(cmnd) )
 	{
 	  case INFILE: /* Read input file */
-		retval = Read_Pipe( nchild, infile, 80, FALSE );
+		retval = Read_Pipe( num_child, infile, 80, FALSE );
 		infile[retval] = '\0';
 		Child_Input_File();
 		break;
@@ -101,15 +72,15 @@ Child_Process( void )
 	  case FRQDATA: /* Calculate currents and pass on */
 		/* Get new frequency */
 		buff = (char *)&calc_data.fmhz;
-		cnt = sizeof( long double );
-		Read_Pipe( nchild, buff, cnt, TRUE );
+		cnt = sizeof( double );
+		Read_Pipe( num_child, buff, (ssize_t)cnt, TRUE );
 
 		/* Frequency buffers in children
 		 * are for current frequency only */
 		calc_data.fstep = 0;
 
 		/* Clear "last-used-frequency" buffer */
-		save.last_freq = 0.0l;
+		save.last_freq = 0.0;
 
 		/* Set flags */
 		SetFlag( FREQ_LOOP_RUNNING );
@@ -126,24 +97,24 @@ Child_Process( void )
 
 		  /* Set near field flags */
 		  cnt = sizeof( flag );
-		  Read_Pipe( nchild, &flag, cnt, TRUE );
+		  Read_Pipe( num_child, &flag, (ssize_t)cnt, TRUE );
 
-		  if( flag & 0x01 )
+		  if( flag & E_HFIELD )
 			SetFlag( DRAW_EHFIELD );
 		  else
 			ClearFlag( DRAW_EHFIELD );
 
-		  if( flag & 0x02 )
+		  if( flag & SNAPSHOT )
 			SetFlag( NEAREH_SNAPSHOT );
 		  else
 			ClearFlag( NEAREH_SNAPSHOT );
 
-		  if( flag & 0x04 )
+		  if( flag & EFIELD )
 			SetFlag( DRAW_EFIELD );
 		  else
 			ClearFlag( DRAW_EFIELD );
 
-		  if( flag & 0x08 )
+		  if( flag & HFIELD )
 			SetFlag( DRAW_HFIELD );
 		  else
 			ClearFlag( DRAW_HFIELD );
@@ -155,17 +126,17 @@ Child_Process( void )
 
 } /* Child_Process() */
 
-  /*-----------------------------------------------------------------------*/
+/*-----------------------------------------------------------------------*/
 
-  /* Child_Input_File()
-   *
-   * Opens NEC2 input file for child processes
-   */
+/* Child_Input_File()
+ *
+ * Opens NEC2 input file for child processes
+ */
   void
-	Child_Input_File( void )
-	{
-	  /* Close open files if any */
-	  Close_File( &input_fp );
+Child_Input_File( void )
+{
+  /* Close open files if any */
+  Close_File( &input_fp );
 
   /* Open NEC2 input file */
   Open_File( &input_fp, infile, "r" );
@@ -179,7 +150,7 @@ Child_Process( void )
   ClearFlag( INPUT_PENDING );
 
   /* Initialize xnec2c child */
-  save.last_freq = 0.0l;
+  save.last_freq = 0.0;
   crnt.newer = crnt.valid = 0;
 
 } /* Child_Input_FIle() */
@@ -196,7 +167,7 @@ Fork_Command( const char *cdstr )
   int idx;
 
   for( idx = 0; idx < NUM_FKCMNDS; idx++ )
-	if( strcmp(comnd[idx], cdstr) == 0 )
+	if( strcmp(fork_commands[idx], cdstr) == 0 )
 	  break;
 
   return( idx );
@@ -209,27 +180,30 @@ Fork_Command( const char *cdstr )
  *
  * Reads data from a pipe (child and parent processes)
  */
-  int
-Read_Pipe( int idx, char *str, size_t len, gboolean err )
+  ssize_t
+Read_Pipe( int idx, char *str, ssize_t len, gboolean err )
 {
-  int retval, pipefd;
+  ssize_t retval;
+  int pipefd;
 
   if(CHILD)
-	pipefd = forkpc[idx]->p2ch_pipe[READ];
+	pipefd = forked_proc_data[idx]->pnt2child_pipe[READ];
   else
-	pipefd = forkpc[idx]->ch2p_pipe[READ];
+	pipefd = forked_proc_data[idx]->child2pnt_pipe[READ];
 
-  retval = select( 1024, &forkpc[idx]->read_fds, NULL, NULL, NULL );
+  retval = select( 1024, &forked_proc_data[idx]->read_fds, NULL, NULL, NULL );
   if( retval == -1 )
   {
 	perror( "xnec2c: select()" );
 	_exit(0);
   }
 
-  retval = read( pipefd, str, len );
+  retval = read( pipefd, str, (size_t)len );
   if( (retval == -1) || ((retval != len) && err ) )
   {
-	perror( "xnec2c: read()" );
+	perror( "xnec2c: Read_Pipe(): read()" );
+	fprintf( stderr, "xnec2c: Read_Pipe(): child %d  length %d  return %d\n",
+		idx, (int)len, (int)retval );
 	_exit(0);
   }
   return( retval );
@@ -242,24 +216,25 @@ Read_Pipe( int idx, char *str, size_t len, gboolean err )
  *
  * Writes data to a pipe (child and parent processes)
  */
-  int
-Write_Pipe( int idx, char *str, size_t len, gboolean err )
+  ssize_t
+Write_Pipe( int idx, char *str, ssize_t len, gboolean err )
 {
-  int retval, pipefd;
+  ssize_t retval;
+  int pipefd;
 
   if( CHILD )
-	pipefd = forkpc[idx]->ch2p_pipe[WRITE];
+	pipefd = forked_proc_data[idx]->child2pnt_pipe[WRITE];
   else
-	pipefd = forkpc[idx]->p2ch_pipe[WRITE];
+	pipefd = forked_proc_data[idx]->pnt2child_pipe[WRITE];
 
-  retval = select( 1024, NULL, &forkpc[idx]->write_fds, NULL, NULL );
+  retval = select( 1024, NULL, &forked_proc_data[idx]->write_fds, NULL, NULL );
   if( retval == -1 )
   {
 	perror( "xnec2c: select()" );
 	_exit(0);
   }
 
-  retval = write( pipefd, str, len );
+  retval = write( pipefd, str, (size_t)len );
   if( (retval == -1) || ((retval != len) && err) )
   {
 	perror( "xnec2c: write()" );
@@ -277,15 +252,15 @@ Write_Pipe( int idx, char *str, size_t len, gboolean err )
  *
  * Reads data from a pipe (used by parent process)
  */
-  int
-PRead_Pipe( int idx, char *str, size_t len, gboolean err )
+  ssize_t
+PRead_Pipe( int idx, char *str, ssize_t len, gboolean err )
 {
-  int retval;
+  ssize_t retval;
 
-  retval = read( forkpc[idx]->ch2p_pipe[READ], str, len );
+  retval = read( forked_proc_data[idx]->child2pnt_pipe[READ], str, (size_t)len );
   if( (retval == -1) || ((retval != len) && err ) )
   {
-	perror( "xnec2c: read()" );
+	perror( "xnec2c: PRead_Pipe(): read()" );
 	_exit(0);
   }
   return( retval );
@@ -303,33 +278,33 @@ PRead_Pipe( int idx, char *str, size_t len, gboolean err )
 Pass_Freq_Data( void )
 {
   char *buff = NULL, flag;
-  size_t cnt, bsize;
+  size_t cnt, buff_size;
 
   /*** Total of bytes to read/write thru pipe ***/
-  bsize =
-	/* Current & charge data (a, b, c ir & ii) */
-	6 * data.npm * sizeof( long double ) +
+  buff_size =
+	/* Current & charge data (a, b, c, ir & ii) */
+	(size_t)(6 * data.npm) * sizeof( double ) +
 	/* Complex current (crnt.cur) */
-	data.np3m * sizeof( complex long double ) +
+	(size_t)data.np3m * sizeof( complex double ) +
 	/* newer and valid flags */
 	2 * sizeof(char) +
 	/* Impedance data */
 	4 * sizeof(double) +
 	/* Network data */
-	sizeof(complex long double);
+	sizeof(complex double);
 
   /* Radiation pattern data if enabled */
   if( isFlagSet(ENABLE_RDPAT) )
   {
-	bsize +=
+	buff_size +=
 	  /* Gain total, tilt, axial ratio */
-	  3 * fpat.nph * fpat.nth * sizeof(double) +
+	  (size_t)(3 * fpat.nph * fpat.nth) * sizeof(double) +
 	  /* max & min gain, tht & phi angles */
-	  4 * NUM_POL * sizeof(double) +
+	  (size_t)(4 * NUM_POL) * sizeof(double) +
 	  /* max and min gain index */
-	  2 * NUM_POL * sizeof(int) +
+	  (size_t)(2 * NUM_POL) * sizeof(int) +
 	  /* Polarization sens */
-	  fpat.nph * fpat.nth * sizeof(int) +
+	  (size_t)(fpat.nph * fpat.nth) * sizeof(int) +
 	  /* New pattern flag */
 	  sizeof( char );
   }
@@ -338,34 +313,33 @@ Pass_Freq_Data( void )
   if( isFlagSet(DRAW_EHFIELD) )
   {
 	/* Notify parent to read near field data */
-	Write_Pipe( nchild, "nfeh", 4, TRUE );
+	Write_Pipe( num_child_procs, "nfeh", 4, TRUE );
 
 	/* Near E field data */
 	if( fpat.nfeh & NEAR_EFIELD )
-	  bsize +=
-		( 10 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double);
+	  buff_size +=
+		(size_t)( 10 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double);
 	/* Near H field data */
 	if( fpat.nfeh & NEAR_HFIELD )
-	  bsize +=
-		( 10 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double);
+	  buff_size +=
+		(size_t)( 10 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double);
 	/* Co-ordinates of field points */
-	bsize +=
-	  ( 3 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double) +
+	buff_size +=
+	  (size_t)( 3 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double) +
 	  /* newer & valid flags */
 	  2 * sizeof(char);
   }
-  else
-	/* Notify parent not to read near field data */
-	Write_Pipe( nchild, "noeh", 4, TRUE );
+  else /* Notify parent not to read near field data */
+	Write_Pipe( num_child_procs, "noeh", 4, TRUE );
 
   /* Allocate data buffers */
-  mem_alloc( (void *)&buff, bsize, "in fork.c" );
+  mem_alloc( (void **)&buff, buff_size, "in fork.c" );
 
   /* Clear buffer index in this function */
   Mem_Copy( buff, buff, 0, WRITE );
 
   /* Pass on current and charge data */
-  cnt =  data.npm * sizeof( long double );
+  cnt =  (size_t)data.npm * sizeof( double );
   Mem_Copy( buff, (char *)crnt.air, cnt, WRITE );
   Mem_Copy( buff, (char *)crnt.aii, cnt, WRITE );
   Mem_Copy( buff, (char *)crnt.bir, cnt, WRITE );
@@ -373,7 +347,7 @@ Pass_Freq_Data( void )
   Mem_Copy( buff, (char *)crnt.cir, cnt, WRITE );
   Mem_Copy( buff, (char *)crnt.cii, cnt, WRITE );
 
-  cnt = data.np3m * sizeof( complex long double );
+  cnt = (size_t)data.np3m * sizeof( complex double );
   Mem_Copy( buff, (char *)crnt.cur, cnt, WRITE );
 
   cnt = sizeof( char );
@@ -388,31 +362,31 @@ Pass_Freq_Data( void )
   Mem_Copy( buff, (char *)&impedance_data.zphase[0], cnt, WRITE );
 
   /* Network data */
-  cnt = sizeof(complex long double);
+  cnt = sizeof(complex double);
   Mem_Copy( buff, (char *)&netcx.zped, cnt, WRITE );
 
   /* Pass on radiation pattern data if enabled */
   if( isFlagSet(ENABLE_RDPAT) )
   {
-	cnt = fpat.nph * fpat.nth * sizeof(double);
+	cnt = (size_t)(fpat.nph * fpat.nth) * sizeof(double);
 	Mem_Copy( buff, (char *)rad_pattern[0].gtot, cnt, WRITE );
 	Mem_Copy( buff, (char *)rad_pattern[0].tilt, cnt, WRITE );
 	Mem_Copy( buff, (char *)rad_pattern[0].axrt, cnt, WRITE );
 
-	cnt = NUM_POL * sizeof(double);
+	cnt = (size_t)NUM_POL * sizeof(double);
 	Mem_Copy( buff, (char *)rad_pattern[0].max_gain, cnt, WRITE );
 	Mem_Copy( buff, (char *)rad_pattern[0].min_gain, cnt, WRITE );
 	Mem_Copy( buff, (char *)rad_pattern[0].max_gain_tht, cnt, WRITE );
 	Mem_Copy( buff, (char *)rad_pattern[0].max_gain_phi, cnt, WRITE );
 
-	cnt = NUM_POL * sizeof(int);
+	cnt = (size_t)NUM_POL * sizeof(int);
 	Mem_Copy( buff, (char *)rad_pattern[0].max_gain_idx, cnt, WRITE );
 	Mem_Copy( buff, (char *)rad_pattern[0].min_gain_idx, cnt, WRITE );
 
-	cnt = fpat.nph * fpat.nth * sizeof(int);
+	cnt = (size_t)(fpat.nph * fpat.nth) * sizeof(int);
 	Mem_Copy( buff, (char *)rad_pattern[0].sens, cnt, WRITE );
 
-	if( isFlagSet(DRAW_NEWRDPAT) )
+	if( isFlagSet(DRAW_NEW_RDPAT) )
 	  flag = 1;
 	else
 	  flag = 0;
@@ -426,7 +400,7 @@ Pass_Freq_Data( void )
 	/* Magnitude and phase of E field */
 	if( fpat.nfeh & NEAR_EFIELD )
 	{
-	  cnt = fpat.nrx * fpat.nry * fpat.nrz * sizeof(double);
+	  cnt = (size_t)(fpat.nrx * fpat.nry * fpat.nrz) * sizeof(double);
 	  Mem_Copy( buff, (char *)near_field.ex, cnt, WRITE );
 	  Mem_Copy( buff, (char *)near_field.ey, cnt, WRITE );
 	  Mem_Copy( buff, (char *)near_field.ez, cnt, WRITE );
@@ -444,7 +418,7 @@ Pass_Freq_Data( void )
 	/* Magnitude and phase of H fields */
 	if( fpat.nfeh & NEAR_HFIELD )
 	{
-	  cnt = fpat.nrx * fpat.nry * fpat.nrz * sizeof(double);
+	  cnt = (size_t)(fpat.nrx * fpat.nry * fpat.nrz) * sizeof(double);
 	  Mem_Copy( buff, (char *)near_field.hx, cnt, WRITE );
 	  Mem_Copy( buff, (char *)near_field.hy, cnt, WRITE );
 	  Mem_Copy( buff, (char *)near_field.hz, cnt, WRITE );
@@ -460,7 +434,7 @@ Pass_Freq_Data( void )
 	}
 
 	/* Co-ordinates of field points */
-	cnt = fpat.nrx * fpat.nry * fpat.nrz * sizeof(double);
+	cnt = (size_t)(fpat.nrx * fpat.nry * fpat.nrz) * sizeof(double);
 	Mem_Copy( buff, (char *)near_field.px, cnt, WRITE );
 	Mem_Copy( buff, (char *)near_field.py, cnt, WRITE );
 	Mem_Copy( buff, (char *)near_field.pz, cnt, WRITE );
@@ -474,9 +448,9 @@ Pass_Freq_Data( void )
   } /* if( isFlagSet(DRAW_EHFIELD) ) */
 
   /* Pass data accumulated in buffer if child */
-  Write_Pipe( nchild, buff, bsize, TRUE );
+  Write_Pipe( num_child_procs, buff, (ssize_t)buff_size, TRUE );
 
-  free_ptr( (void *)&buff );
+  free_ptr( (void **)&buff );
 
 } /* Pass_Freq_Data() */
 
@@ -492,33 +466,33 @@ Get_Freq_Data( int idx, int fstep )
 {
   char *buff = NULL, flag;
   char nfeh[5];
-  size_t cnt, bsize;
+  size_t cnt, buff_size;
 
   /*** Total of bytes to read/write thru pipe ***/
-  bsize =
+  buff_size =
 	/* Current & charge data (a, b, c ir & ii) */
-	6 * data.npm * sizeof( long double ) +
+	(size_t)(6 * data.npm) * sizeof( double ) +
 	/* Complex current (crnt.cur) */
-	data.np3m * sizeof( complex long double ) +
+	(size_t)data.np3m * sizeof( complex double ) +
 	/* newer and valid flags */
 	2 * sizeof(char) +
 	/* Impedance data */
 	4 * sizeof(double) +
 	/* Network data */
-	sizeof(complex long double);
+	sizeof(complex double);
 
   /* Radiation pattern data if enabled */
   if( isFlagSet(ENABLE_RDPAT) )
   {
-	bsize +=
+	buff_size +=
 	  /* Gain total, tilt, axial ratio */
-	  3 * fpat.nph * fpat.nth * sizeof(double) +
+	  (size_t)(3 * fpat.nph * fpat.nth) * sizeof(double) +
 	  /* max & min gain, tht & phi angles */
-	  4 * NUM_POL * sizeof(double) +
+	  (size_t)(4 * NUM_POL) * sizeof(double) +
 	  /* max and min gain index */
-	  2 * NUM_POL * sizeof(int) +
+	  (size_t)(2 * NUM_POL) * sizeof(int) +
 	  /* Polarization sens */
-	  fpat.nph * fpat.nth * sizeof(int) +
+	  (size_t)(fpat.nph * fpat.nth) * sizeof(int) +
 	  /* New pattern flag */
 	  sizeof( char );
   }
@@ -532,30 +506,30 @@ Get_Freq_Data( int idx, int fstep )
   {
 	/* Near E field data */
 	if( fpat.nfeh & NEAR_EFIELD )
-	  bsize +=
-		( 10 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double);
+	  buff_size +=
+		(size_t)( 10 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double);
 	/* Near H field data */
 	if( fpat.nfeh & NEAR_HFIELD )
-	  bsize +=
-		( 10 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double);
+	  buff_size +=
+		(size_t)( 10 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double);
 	/* Co-ordinates of field points */
-	bsize +=
-	  ( 3 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double) +
+	buff_size +=
+	  (size_t)( 3 * fpat.nrx * fpat.nry * fpat.nrz + 1 ) * sizeof(double) +
 	  /* newer & valid flags */
 	  2 * sizeof(char);
   }
 
   /* Allocate data buffer */
-  mem_alloc( (void *)&buff, bsize, "in fork.c" );
+  mem_alloc( (void **)&buff, buff_size, "in fork.c" );
 
   /* Clear buffer index in this function */
   Mem_Copy( buff, buff, 0, READ );
 
   /* Get data accumulated in buffer if child */
-  PRead_Pipe( idx, buff, bsize, TRUE );
+  PRead_Pipe( idx, buff, (ssize_t)buff_size, TRUE );
 
   /* Get current and charge data */
-  cnt =  data.npm * sizeof( long double );
+  cnt =  (size_t)data.npm * sizeof( double );
   Mem_Copy( buff, (char *)crnt.air, cnt, READ );
   Mem_Copy( buff, (char *)crnt.aii, cnt, READ );
   Mem_Copy( buff, (char *)crnt.bir, cnt, READ );
@@ -563,7 +537,7 @@ Get_Freq_Data( int idx, int fstep )
   Mem_Copy( buff, (char *)crnt.cir, cnt, READ );
   Mem_Copy( buff, (char *)crnt.cii, cnt, READ );
 
-  cnt = data.np3m * sizeof( complex long double );
+  cnt = (size_t)data.np3m * sizeof( complex double );
   Mem_Copy( buff, (char *)crnt.cur, cnt, READ );
 
   cnt = sizeof( char );
@@ -578,32 +552,32 @@ Get_Freq_Data( int idx, int fstep )
   Mem_Copy( buff, (char *)&impedance_data.zphase[fstep], cnt, READ );
 
   /* Get network data */
-  cnt = sizeof(complex long double);
+  cnt = sizeof(complex double);
   Mem_Copy( buff, (char *)&netcx.zped, cnt, READ );
 
   /* Get radiation pattern data if enabled */
   if( isFlagSet(ENABLE_RDPAT) )
   {
-	cnt = fpat.nph * fpat.nth * sizeof(double);
+	cnt = (size_t)(fpat.nph * fpat.nth) * sizeof(double);
 	Mem_Copy( buff, (char *)rad_pattern[fstep].gtot, cnt, READ );
 	Mem_Copy( buff, (char *)rad_pattern[fstep].tilt, cnt, READ );
 	Mem_Copy( buff, (char *)rad_pattern[fstep].axrt, cnt, READ );
 
-	cnt = NUM_POL * sizeof(double);
+	cnt = (size_t)NUM_POL * sizeof(double);
 	Mem_Copy( buff, (char *)rad_pattern[fstep].max_gain, cnt, READ );
 	Mem_Copy( buff, (char *)rad_pattern[fstep].min_gain, cnt, READ );
 	Mem_Copy( buff, (char *)rad_pattern[fstep].max_gain_tht, cnt, READ );
 	Mem_Copy( buff, (char *)rad_pattern[fstep].max_gain_phi, cnt, READ );
 
-	cnt = NUM_POL * sizeof(int);
+	cnt = (size_t)NUM_POL * sizeof(int);
 	Mem_Copy( buff, (char *)rad_pattern[fstep].max_gain_idx, cnt, READ );
 	Mem_Copy( buff, (char *)rad_pattern[fstep].min_gain_idx, cnt, READ );
 
-	cnt = fpat.nph * fpat.nth * sizeof(int);
+	cnt = (size_t)(fpat.nph * fpat.nth) * sizeof(int);
 	Mem_Copy( buff, (char *)rad_pattern[fstep].sens, cnt, READ );
 
 	Mem_Copy( buff, &flag, sizeof(flag), READ );
-	if( flag ) SetFlag( DRAW_NEWRDPAT );
+	if( flag ) SetFlag( DRAW_NEW_RDPAT );
   }
 
   /* Get near field data if signaled by child */
@@ -612,7 +586,7 @@ Get_Freq_Data( int idx, int fstep )
 	/* Magnitude and phase of E field */
 	if( fpat.nfeh & NEAR_EFIELD )
 	{
-	  cnt = fpat.nrx * fpat.nry * fpat.nrz * sizeof(double);
+	  cnt = (size_t)(fpat.nrx * fpat.nry * fpat.nrz) * sizeof(double);
 	  Mem_Copy( buff, (char *)near_field.ex, cnt, READ );
 	  Mem_Copy( buff, (char *)near_field.ey, cnt, READ );
 	  Mem_Copy( buff, (char *)near_field.ez, cnt, READ );
@@ -630,7 +604,7 @@ Get_Freq_Data( int idx, int fstep )
 	/* Magnitude and phase of H fields */
 	if( fpat.nfeh & NEAR_HFIELD )
 	{
-	  cnt = fpat.nrx * fpat.nry * fpat.nrz * sizeof(double);
+	  cnt = (size_t)(fpat.nrx * fpat.nry * fpat.nrz) * sizeof(double);
 	  Mem_Copy( buff, (char *)near_field.hx, cnt, READ );
 	  Mem_Copy( buff, (char *)near_field.hy, cnt, READ );
 	  Mem_Copy( buff, (char *)near_field.hz, cnt, READ );
@@ -646,7 +620,7 @@ Get_Freq_Data( int idx, int fstep )
 	}
 
 	/* Co-ordinates of field points */
-	cnt = fpat.nrx * fpat.nry * fpat.nrz * sizeof(double);
+	cnt = (size_t)(fpat.nrx * fpat.nry * fpat.nrz) * sizeof(double);
 	Mem_Copy( buff, (char *)near_field.px, cnt, READ );
 	Mem_Copy( buff, (char *)near_field.py, cnt, READ );
 	Mem_Copy( buff, (char *)near_field.pz, cnt, READ );
@@ -659,7 +633,7 @@ Get_Freq_Data( int idx, int fstep )
 
   } /*if( isFlagSet(DRAW_EHFIELD) ) */
 
-  free_ptr( (void *)&buff );
+  free_ptr( (void **)&buff );
 
 } /* Get_Freq_Data() */
 
