@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,13 +16,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* fork.h */
+#ifndef	FORK_H
+#define	FORK_H		1
+
+#include "common.h"
 
 /* Parent/child commands */
 #define FORK_CMNDS { "inpfile", "frqdata", "nearehf" }
 
 /* Indices for parent/child commands */
-enum
+enum P2CH_COMND
 {
   INFILE = 0,
   FRQDATA,
@@ -31,3 +33,10 @@ enum
   NUM_FKCMNDS
 };
 
+/* Near Field select flags */
+#define E_HFIELD	0x01
+#define SNAPSHOT	0x02
+#define EFIELD		0x04
+#define HFIELD		0x08
+
+#endif
