@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,43 +41,17 @@
 
  ***********************************************************************/
 
-#include "xnec2c.h"
-
-/* common  /data/ */
-extern data_t data;
-
-/* common  /dataj/ */
-extern dataj_t dataj;
-
-/* common  /matpar/ */
-matpar_t matpar;
-
-/* common  /segj/ */
-segj_t segj;
-
-/* common  /zload/ */
-extern zload_t zload;
-
-/* common  /smat/ */
-smat_t smat;
-
-/* common  /gnd/ */
-extern gnd_t gnd;
-
-/* common  /vsorc/ */
-extern vsorc_t vsorc;
-
-/* pointers to input */
-extern FILE *input_fp;
+#include "matrix.h"
+#include "shared.h"
 
 /*-------------------------------------------------------------------*/
 
 /* cmset sets up the complex structure matrix in the array cm */
-void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
+void cmset( int nrow, complex double *cmx, double rkhx, int iexkx )
 {
-  int mp2, neq, npeq, iout, it, i, j, i1, i2, in2, im1;
+  int mp2, neq, npeq, it, i, j, i1, i2, in2, im1;
   int im2, ist, ij, ipr, jss, jm1, jm2, jst, k, ka, kk;
-  complex long double zaj, deter, *scm = NULL;
+  complex double zaj, deter, *scm = NULL;
 
   mp2=2* data.mp;
   npeq= data.np+ mp2;
@@ -87,12 +60,11 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 
   dataj.rkh= rkhx;
   dataj.iexk= iexkx;
-  iout=2* matpar.npblk* nrow;
   it= matpar.nlast;
 
   for( i = 0; i < nrow; i++ )
 	for( j = 0; j < it; j++ )
-	  cm[i+j*nrow]= CPLX_00;
+	  cmx[i+j*nrow]= CPLX_00;
 
   i1= 1;
   i2= it;
@@ -124,10 +96,10 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 	  }
 
 	  if( i1 <= in2)
-		cmww( j, i1, in2, cm, nrow, cm, nrow,1);
+		cmww( j, i1, in2, cmx, nrow, cmx, nrow,1);
 
 	  if( im1 <= im2)
-		cmws( j, im1, im2, &cm[(ist-1)*nrow], nrow, cm, nrow, 1);
+		cmws( j, im1, im2, &cmx[(ist-1)*nrow], nrow, cmx, 1);
 
 	  /* matrix elements modified by loading */
 	  if( zload.nload == 0)
@@ -145,7 +117,7 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 	  for( i = 0; i < segj.jsno; i++ )
 	  {
 		jss= segj.jco[i];
-		cm[(jss-1)+(ipr-1)*nrow] -=
+		cmx[(jss-1)+(ipr-1)*nrow] -=
 		  ( segj.ax[i]+ segj.cx[i])* zaj;
 	  }
 
@@ -168,11 +140,11 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 
 	  if( i1 <= in2)
 		cmsw( jm1, jm2, i1, in2,
-			&cm[(jst-1)], cm, 0, nrow, 1);
+			&cmx[(jst-1)], cmx, 0, nrow, 1);
 
 	  if( im1 <= im2)
 		cmss( jm1, jm2, im1, im2,
-			&cm[(jst-1)+(ist-1)*nrow], nrow, 1);
+			&cmx[(jst-1)+(ist-1)*nrow], nrow, 1);
 	}
 
   } /* if( m != 0) */
@@ -181,8 +153,8 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 	return;
 
   /* Allocate to scratch memory */
-  mem_alloc( (void *)&scm,
-	  data.np2m * sizeof(complex long double), "in matrix.c");
+  size_t mreq = (size_t)data.np2m * sizeof(complex double);
+  mem_alloc( (void **)&scm, mreq, "in matrix.c");
 
   /* combine elements for symmetry modes */
   for( i = 0; i < it; i++ )
@@ -192,7 +164,7 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 	  for( k = 0; k < smat.nop; k++ )
 	  {
 		ka= j+ k*npeq;
-		scm[k]= cm[ka+i*nrow];
+		scm[k]= cmx[ka+i*nrow];
 	  }
 
 	  deter= scm[0];
@@ -200,7 +172,7 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 	  for( kk = 1; kk < smat.nop; kk++ )
 		deter += scm[kk];
 
-	  cm[j+i*nrow]= deter;
+	  cmx[j+i*nrow]= deter;
 
 	  for( k = 1; k < smat.nop; k++ )
 	  {
@@ -210,7 +182,7 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 		for( kk = 1; kk < smat.nop; kk++ )
 		{
 		  deter += scm[kk]* smat.ssx[k+kk*smat.nop];
-		  cm[ka+i*nrow]= deter;
+		  cmx[ka+i*nrow]= deter;
 		}
 
 	  } /* for( k = 1; k < smat.nop; k++ ) */
@@ -219,7 +191,7 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 
   } /* for( i = 0; i < it; i++ ) */
 
-  free_ptr( (void *)&scm );
+  free_ptr( (void **)&scm );
 
   return;
 }
@@ -228,11 +200,11 @@ void cmset( int nrow, complex long double *cm, long double rkhx, int iexkx )
 
 /* cmss computes matrix elements for surface-surface interactions. */
 void cmss( int j1, int j2, int im1, int im2,
-	complex long double *cm, int nrow, int itrp )
+	complex double *cmx, int nrow, int itrp )
 {
   int i1, i2, icomp, ii1, i, il, ii2, jj1, j, jl, jj2;
-  long double t1xi, t1yi, t1zi, t2xi, t2yi, t2zi, xi, yi, zi;
-  complex long double g11, g12, g21, g22;
+  double t1xi, t1yi, t1zi, t2xi, t2yi, t2zi, xi, yi, zi;
+  complex double g11, g12, g21, g22;
 
   i1=( im1+1)/2;
   i2=( im2+1)/2;
@@ -288,8 +260,8 @@ void cmss( int j1, int j2, int im1, int im2,
 
 	  if( i == j )
 	  {
-		g11 -= .5l;
-		g22 += .5l;
+		g11 -= .5;
+		g22 += .5;
 	  }
 
 	  /* normal fill */
@@ -297,15 +269,15 @@ void cmss( int j1, int j2, int im1, int im2,
 	  {
 		if( icomp >= im1 )
 		{
-		  cm[ii1+jj1*nrow]= g11;
-		  cm[ii1+jj2*nrow]= g12;
+		  cmx[ii1+jj1*nrow]= g11;
+		  cmx[ii1+jj2*nrow]= g12;
 		}
 
 		if( icomp >= im2 )
 		  continue;
 
-		cm[ii2+jj1*nrow]= g21;
-		cm[ii2+jj2*nrow]= g22;
+		cmx[ii2+jj1*nrow]= g21;
+		cmx[ii2+jj2*nrow]= g22;
 		continue;
 
 	  } /* if( itrp == 0) */
@@ -313,15 +285,15 @@ void cmss( int j1, int j2, int im1, int im2,
 	  /* transposed fill */
 	  if( icomp >= im1 )
 	  {
-		cm[jj1+ii1*nrow]= g11;
-		cm[jj2+ii1*nrow]= g12;
+		cmx[jj1+ii1*nrow]= g11;
+		cmx[jj2+ii1*nrow]= g12;
 	  }
 
 	  if( icomp >= im2 )
 		continue;
 
-	  cm[jj1+ii2*nrow]= g21;
-	  cm[jj2+ii2*nrow]= g22;
+	  cmx[jj1+ii2*nrow]= g21;
+	  cmx[jj2+ii2*nrow]= g22;
 
 	} /* for( j = j1; j <= j2; j++ ) */
 
@@ -333,22 +305,22 @@ void cmss( int j1, int j2, int im1, int im2,
 /*-----------------------------------------------------------------------*/
 
 /* computes matrix elements for e along wires due to patch current */
-void cmsw( int j1, int j2, int i1, int i2, complex long double *cm,
-	complex long double *cw, int ncw, int nrow, int itrp )
+void cmsw( int j1, int j2, int i1, int i2, complex double *cmx,
+	complex double *cw, int ncw, int nrow, int itrp )
 {
-  int neqs, k, icgo, i, ipch, jl, j, js, il, ip;
   int jsnox; /* -1 offset to "jsno" for array indexing */
-  long double xi, yi, zi, cabi, sabi, salpi, fsign=1.0l, pyl, pxl;
-  static complex long double *emel = NULL;
+  static complex double *emel = NULL;
 
-  mem_alloc( (void *)&emel,
-	  9*sizeof(complex long double), "in matrix.c");
+  size_t mreq = 9 * sizeof(complex double);
+  mem_alloc( (void **)&emel, mreq, "in matrix.c");
 
-  neqs= data.np2m;
   jsnox = segj.jsno-1;
 
   if( itrp >= 0)
   {
+	int k, icgo, i, ipch, jl, j, js, il, ip;
+	double xi, yi, zi, cabi, sabi, salpi, fsign=1.0, pyl, pxl;
+
 	k=-1;
 	icgo=0;
 
@@ -367,13 +339,13 @@ void cmsw( int j1, int j2, int i1, int i2, complex long double *cm,
 	  if( data.icon1[i] >= PCHCON)
 	  {
 		ipch= data.icon1[i]-PCHCON;
-		fsign=-1.0l;
+		fsign=-1.0;
 	  }
 
 	  if( data.icon2[i] >= PCHCON)
 	  {
 		ipch= data.icon2[i]-PCHCON;
-		fsign=1.0l;
+		fsign=1.0;
 	  }
 
 	  /* source loop */
@@ -405,8 +377,8 @@ void cmsw( int j1, int j2, int i1, int i2, complex long double *cm,
 			  pcint( xi, yi, zi, cabi, sabi, salpi, emel);
 
 			  pyl= PI* data.si[i]* fsign;
-			  pxl= sinl( pyl);
-			  pyl= cosl( pyl);
+			  pxl= sin( pyl);
+			  pyl= cos( pyl);
 			  dataj.exc= emel[8]* fsign;
 
 			  trio(i+1);
@@ -428,13 +400,13 @@ void cmsw( int j1, int j2, int i1, int i2, complex long double *cm,
 
 			if( itrp == 0)
 			{
-			  cm[k+(jl-1)*nrow]= emel[icgo];
-			  cm[k+jl*nrow]    = emel[icgo+4];
+			  cmx[k+(jl-1)*nrow]= emel[icgo];
+			  cmx[k+jl*nrow]    = emel[icgo+4];
 			}
 			else
 			{
-			  cm[(jl-1)+k*nrow]= emel[icgo];
-			  cm[jl+k*nrow]    = emel[icgo+4];
+			  cmx[(jl-1)+k*nrow]= emel[icgo];
+			  cmx[jl+k*nrow]    = emel[icgo+4];
 			}
 
 			icgo++;
@@ -450,17 +422,17 @@ void cmsw( int j1, int j2, int i1, int i2, complex long double *cm,
 		  /* normal fill */
 		  if( itrp == 0)
 		  {
-			cm[k+(jl-1)*nrow] +=
+			cmx[k+(jl-1)*nrow] +=
 			  dataj.exk* cabi+ dataj.eyk* sabi+ dataj.ezk* salpi;
-			cm[k+jl*nrow]     +=
+			cmx[k+jl*nrow]     +=
 			  dataj.exs* cabi+ dataj.eys* sabi+ dataj.ezs* salpi;
 			continue;
 		  }
 
 		  /* transposed fill */
-		  cm[(jl-1)+k*nrow] +=
+		  cmx[(jl-1)+k*nrow] +=
 			dataj.exk* cabi+ dataj.eyk* sabi+ dataj.ezk* salpi;
-		  cm[jl+k*nrow]     +=
+		  cmx[jl+k*nrow]     +=
 			dataj.exs* cabi+ dataj.eys* sabi+ dataj.ezs* salpi;
 
 		} /* for( ip = 1; ip <= gnd.ksymp; ip++ ) */
@@ -477,12 +449,12 @@ void cmsw( int j1, int j2, int i1, int i2, complex long double *cm,
 /*-----------------------------------------------------------------------*/
 
 /* cmws computes matrix elements for wire-surface interactions */
-void cmws( int j, int i1, int i2, complex long double *cm,
-	int nr, complex long double *cw, int nw, int itrp )
+void cmws( int j, int i1, int i2, complex double *cmx,
+	int nr, complex double *cw, int itrp )
 {
   int ipr, i, ipatch, ik, js=0, ij, jx;
-  long double xi, yi, zi, tx, ty, tz;
-  complex long double etk, ets, etc;
+  double xi, yi, zi, tx, ty, tz;
+  complex double etk, ets, etc;
 
   j--;
   dataj.s= data.si[j];
@@ -508,7 +480,7 @@ void cmws( int j, int i1, int i2, complex long double *cm,
 	  xi= data.px[js];
 	  yi= data.py[js];
 	  zi= data.pz[js];
-	  hsfld( xi, yi, zi, 0.0l);
+	  hsfld( xi, yi, zi, 0.0);
 
 	  if( ik != 0 )
 	  {
@@ -548,7 +520,7 @@ void cmws( int j, int i1, int i2, complex long double *cm,
 	  for( ij = 0; ij < segj.jsno; ij++ )
 	  {
 		jx= segj.jco[ij]-1;
-		cm[ipr+jx*nr] += etk* segj.ax[ij] +
+		cmx[ipr+jx*nr] += etk* segj.ax[ij] +
 		  ets* segj.bx[ij]+ etc* segj.cx[ij];
 	  }
 
@@ -561,7 +533,7 @@ void cmws( int j, int i1, int i2, complex long double *cm,
 	  for( ij = 0; ij < segj.jsno; ij++ )
 	  {
 		jx= segj.jco[ij]-1;
-		cm[jx+ipr*nr] += etk* segj.ax[ij] +
+		cmx[jx+ipr*nr] += etk* segj.ax[ij] +
 		  ets* segj.bx[ij]+ etc* segj.cx[ij];
 	  }
 
@@ -573,7 +545,7 @@ void cmws( int j, int i1, int i2, complex long double *cm,
 	{
 	  jx= segj.jco[ij]-1;
 	  if( jx < nr)
-		cm[jx+ipr*nr] += etk* segj.ax[ij] +
+		cmx[jx+ipr*nr] += etk* segj.ax[ij] +
 		  ets* segj.bx[ij]+ etc* segj.cx[ij];
 	  else
 	  {
@@ -591,12 +563,12 @@ void cmws( int j, int i1, int i2, complex long double *cm,
 /*-----------------------------------------------------------------------*/
 
 /* cmww computes matrix elements for wire-wire interactions */
-void cmww( int j, int i1, int i2, complex long double *cm,
-	int nr, complex long double *cw, int nw, int itrp)
+void cmww( int j, int i1, int i2, complex double *cmx,
+	int nr, complex double *cw, int nw, int itrp)
 {
   int ipr, iprx, i, ij, jx;
-  long double xi, yi, zi, ai, cabi, sabi, salpi;
-  complex long double etk, ets, etc;
+  double xi, yi, zi, ai, cabi, sabi, salpi;
+  complex double etk, ets, etc;
 
   /* set source segment parameters */
   jx = j;
@@ -624,10 +596,10 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 		dataj.ind1=2;
 	  else
 	  {
-		xi= fabsl( dataj.cabj* data.cab[iprx]+ dataj.sabj*
+		xi= fabs( dataj.cabj* data.cab[iprx]+ dataj.sabj*
 			data.sab[iprx]+ dataj.salpj* data.salp[iprx]);
-		if( (xi < 0.999999l) ||
-			(fabsl(data.bi[iprx]/dataj.b-1.0l) > 1.0e-6l) )
+		if( (xi < 0.999999) ||
+			(fabs(data.bi[iprx]/dataj.b-1.0) > 1.0e-6) )
 		  dataj.ind1=2;
 		else
 		  dataj.ind1=0;
@@ -648,10 +620,10 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 			dataj.ind1=2;
 		  else
 		  {
-			xi= fabsl( dataj.cabj* data.cab[iprx]+ dataj.sabj*
+			xi= fabs( dataj.cabj* data.cab[iprx]+ dataj.sabj*
 				data.sab[iprx]+ dataj.salpj* data.salp[iprx]);
-			if( (xi < 0.999999l) ||
-				(fabsl(data.bi[iprx]/dataj.b-1.0l) > 1.0e-6l) )
+			if( (xi < 0.999999) ||
+				(fabs(data.bi[iprx]/dataj.b-1.0) > 1.0e-6) )
 			  dataj.ind1=2;
 			else
 			  dataj.ind1=0;
@@ -659,12 +631,11 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 		  } /* if( data.icon2[iprx] != jx ) */
 
 		} /* if( ipr != jx ) */
+		else if( (dataj.cabj* dataj.cabj +
+			  dataj.sabj* dataj.sabj) > 1.0e-8)
+		  dataj.ind1=2;
 		else
-		  if( (dataj.cabj* dataj.cabj +
-				dataj.sabj* dataj.sabj) > 1.0e-8l)
-			dataj.ind1=2;
-		  else
-			dataj.ind1=0;
+		  dataj.ind1=0;
 
 	  } /* if( ipr == 0 ) */
 
@@ -680,10 +651,10 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 		dataj.ind2=2;
 	  else
 	  {
-		xi= fabsl( dataj.cabj* data.cab[iprx]+ dataj.sabj*
+		xi= fabs( dataj.cabj* data.cab[iprx]+ dataj.sabj*
 			data.sab[iprx]+ dataj.salpj* data.salp[iprx]);
-		if( (xi < 0.99999l) ||
-			(fabsl(data.bi[iprx]/dataj.b-1.0l) > 1.0e-6l) )
+		if( (xi < 0.99999) ||
+			(fabs(data.bi[iprx]/dataj.b-1.0) > 1.0e-6) )
 		  dataj.ind2=2;
 		else
 		  dataj.ind2=0;
@@ -704,10 +675,10 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 			dataj.ind2=2;
 		  else
 		  {
-			xi= fabsl( dataj.cabj* data.cab[iprx]+ dataj.sabj*
+			xi= fabs( dataj.cabj* data.cab[iprx]+ dataj.sabj*
 				data.sab[iprx]+ dataj.salpj* data.salp[iprx]);
-			if( (xi < 0.999999l) ||
-				(fabsl(data.bi[iprx]/dataj.b-1.0l) > 1.0e-6l) )
+			if( (xi < 0.999999) ||
+				(fabs(data.bi[iprx]/dataj.b-1.0) > 1.0e-6) )
 			  dataj.ind2=2;
 			else
 			  dataj.ind2=0;
@@ -715,12 +686,11 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 		  } /* if( data.icon2[iprx] != jx ) */
 
 		} /* if( ipr != jx ) */
+		else if( (dataj.cabj* dataj.cabj +
+			  dataj.sabj* dataj.sabj) > 1.0e-8)
+		  dataj.ind2=2;
 		else
-		  if( (dataj.cabj* dataj.cabj +
-				dataj.sabj* dataj.sabj) > 1.0e-8l)
-			dataj.ind2=2;
-		  else
-			dataj.ind2=0;
+		  dataj.ind2=0;
 
 	  } /* if( ipr == 0 ) */
 
@@ -760,7 +730,7 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 	  for( ij = 0; ij < segj.jsno; ij++ )
 	  {
 		jx = segj.jco[ij]-1;
-		cm[ipr+jx*nr] += etk* segj.ax[ij] +
+		cmx[ipr+jx*nr] += etk* segj.ax[ij] +
 		  ets* segj.bx[ij]+ etc* segj.cx[ij];
 	  }
 	  continue;
@@ -772,7 +742,7 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 	  for( ij = 0; ij < segj.jsno; ij++ )
 	  {
 		jx= segj.jco[ij]-1;
-		cm[jx+ipr*nr] += etk* segj.ax[ij] +
+		cmx[jx+ipr*nr] += etk* segj.ax[ij] +
 		  ets* segj.bx[ij]+ etc* segj.cx[ij];
 	  }
 	  continue;
@@ -783,7 +753,7 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 	{
 	  jx= segj.jco[ij]-1;
 	  if( jx < nr)
-		cm[jx+ipr*nr] += etk* segj.ax[ij] +
+		cmx[jx+ipr*nr] += etk* segj.ax[ij] +
 		  ets* segj.bx[ij]+ etc* segj.cx[ij];
 	  else
 	  {
@@ -804,14 +774,14 @@ void cmww( int j, int i1, int i2, complex long double *cm,
 /* etmns fills the array e with the negative of the */
 /* electric field incident on the structure. e is the */
 /* right hand side of the matrix equation. */
-void etmns( long double p1, long double p2, long double p3, long double p4,
-	long double p5, long double p6, int ipr, complex long double *e )
+void etmns( double p1, double p2, double p3, double p4,
+	double p5, double p6, int ipr, complex double *e )
 {
   int i, is, i1, i2=0, neq;
-  long double cth, sth, cph, sph, cet, set, pxl, pyl, pzl, wx;
-  long double wy, wz, qx, qy, qz, arg, ds, dsh, rs, r;
-  complex long double cx, cy, cz, er, et, ezh;
-  complex long double erh, rrv=CPLX_00, rrh=CPLX_00, tt1, tt2;
+  double cth, sth, cph, sph, cet, set, pxl, pyl, pzl, wx;
+  double wy, wz, qx, qy, qz, arg, ds, dsh, rs, r;
+  complex double cx, cy, cz, er, et, ezh;
+  complex double erh, rrv=CPLX_00, rrh=CPLX_00, tt1, tt2;
 
   neq= data.n+2*data.m;
   vsorc.nqds=0;
@@ -846,18 +816,18 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
   /* incident plane wave, linearly polarized. */
   if( ipr <= 3)
   {
-	cth= cosl( p1);
-	sth= sinl( p1);
-	cph= cosl( p2);
-	sph= sinl( p2);
-	cet= cosl( p3);
-	set= sinl( p3);
+	cth= cos( p1);
+	sth= sin( p1);
+	cph= cos( p2);
+	sph= sin( p2);
+	cet= cos( p3);
+	set= sin( p3);
 	pxl= cth* cph* cet- sph* set;
 	pyl= cth* sph* cet+ cph* set;
-	pzl=- sth* cet;
-	wx=- sth* cph;
-	wy=- sth* sph;
-	wz=- cth;
+	pzl= -sth* cet;
+	wx= -sth* cph;
+	wy= -sth* sph;
+	wz= -cth;
 	qx= wy* pzl- wz* pyl;
 	qy= wz* pxl- wx* pzl;
 	qz= wx* pyl- wy* pxl;
@@ -866,7 +836,7 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 	{
 	  if( gnd.iperf != 1)
 	  {
-		rrv= csqrtl(1.0l- gnd.zrati* gnd.zrati* sth* sth);
+		rrv= csqrt(1.0- gnd.zrati* gnd.zrati* sth* sth);
 		rrh= gnd.zrati* cth;
 		rrh=( rrh- rrv)/( rrh+ rrv);
 		rrv= gnd.zrati* rrv;
@@ -886,9 +856,9 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 	  {
 		for( i = 0; i < data.n; i++ )
 		{
-		  arg=- TP*( wx* data.x[i]+ wy* data.y[i]+ wz* data.z[i]);
+		  arg= -TP*( wx* data.x[i]+ wy* data.y[i]+ wz* data.z[i]);
 		  e[i]=-( pxl* data.cab[i]+ pyl* data.sab[i]+ pzl*
-			  data.salp[i])* cmplx( cosl( arg), sinl( arg));
+			  data.salp[i])* cmplx( cos( arg), sin( arg));
 		}
 
 		if( gnd.ksymp != 1)
@@ -896,13 +866,13 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 		  tt1=( pyl* cph- pxl* sph)*( rrh- rrv);
 		  cx= rrv* pxl- tt1* sph;
 		  cy= rrv* pyl+ tt1* cph;
-		  cz=- rrv* pzl;
+		  cz= -rrv* pzl;
 
 		  for( i = 0; i < data.n; i++ )
 		  {
-			arg=- TP*( wx* data.x[i]+ wy* data.y[i]- wz* data.z[i]);
+			arg= -TP*( wx* data.x[i]+ wy* data.y[i]- wz* data.z[i]);
 			e[i]= e[i]-( cx* data.cab[i]+ cy* data.sab[i]+
-				cz* data.salp[i])* cmplx(cosl( arg), sinl( arg));
+				cz* data.salp[i])* cmplx(cos( arg), sin( arg));
 		  }
 
 		} /* if( gnd.ksymp != 1) */
@@ -919,9 +889,9 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 		i++;
 		i1 += 2;
 		i2 = i1+1;
-		arg=- TP*( wx* data.px[i] +
+		arg= -TP*( wx* data.px[i] +
 			wy* data.py[i]+ wz* data.pz[i]);
-		tt1= cmplx( cosl( arg), sinl( arg)) *
+		tt1= cmplx( cos( arg), sin( arg)) *
 		  data.psalp[i]* RETA;
 		e[i2]=( qx* data.t1x[i]+ qy* data.t1y[i] +
 			qz* data.t1z[i])* tt1;
@@ -944,9 +914,9 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 		i++;
 		i1 += 2;
 		i2 = i1+1;
-		arg=- TP*( wx* data.px[i] +
+		arg= -TP*( wx* data.px[i] +
 			wy* data.py[i]- wz* data.pz[i]);
-		tt1= cmplx( cosl( arg), sinl( arg)) *
+		tt1= cmplx( cos( arg), sin( arg)) *
 		  data.psalp[i]* RETA;
 		e[i2]= e[i2]+( cx* data.t1x[i]+ cy *
 			data.t1y[i]+ cz* data.t1z[i])* tt1;
@@ -960,7 +930,7 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 	/* incident plane wave, elliptic polarization. */
 	tt1=-(CPLX_01)* p6;
 	if( ipr == 3)
-	  tt1=- tt1;
+	  tt1= -tt1;
 
 	if( data.n != 0)
 	{
@@ -970,9 +940,9 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 
 	  for( i = 0; i < data.n; i++ )
 	  {
-		arg=- TP*( wx* data.x[i]+ wy* data.y[i] + wz* data.z[i]);
+		arg= -TP*( wx* data.x[i]+ wy* data.y[i] + wz* data.z[i]);
 		e[i]=-( cx* data.cab[i]+ cy* data.sab[i] +
-			cz * data.salp[i])* cmplx( cosl( arg), sinl( arg));
+			cz * data.salp[i])* cmplx( cos( arg), sin( arg));
 	  }
 
 	  if( gnd.ksymp != 1)
@@ -980,13 +950,13 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 		tt2=( cy* cph- cx* sph)*( rrh- rrv);
 		cx= rrv* cx- tt2* sph;
 		cy= rrv* cy+ tt2* cph;
-		cz=- rrv* cz;
+		cz= -rrv* cz;
 
 		for( i = 0; i < data.n; i++ )
 		{
-		  arg=- TP*( wx* data.x[i]+ wy* data.y[i]- wz* data.z[i]);
+		  arg= -TP*( wx* data.x[i]+ wy* data.y[i]- wz* data.z[i]);
 		  e[i]= e[i]-( cx* data.cab[i]+ cy* data.sab[i]+
-			  cz* data.salp[i])* cmplx(cosl( arg), sinl( arg));
+			  cz* data.salp[i])* cmplx(cos( arg), sin( arg));
 		}
 
 	  } /* if( gnd.ksymp != 1) */
@@ -1007,10 +977,10 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 	  i++;
 	  i1 += 2;
 	  i2 = i1+1;
-	  arg=- TP*( wx* data.px[i] +
+	  arg= -TP*( wx* data.px[i] +
 		  wy* data.py[i]+ wz* data.pz[i]);
-	  tt2= cmplx( cosl( arg),
-		  sinl( arg)) * data.psalp[i] * RETA;
+	  tt2= cmplx( cos( arg),
+		  sin( arg)) * data.psalp[i] * RETA;
 	  e[i2]=( cx* data.t1x[i] +
 		  cy* data.t1y[i]+ cz* data.t1z[i])* tt2;
 	  e[i1]=( cx* data.t2x[i] +
@@ -1032,9 +1002,9 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 	  i++;
 	  i1 += 2;
 	  i2 = i1+1;
-	  arg=- TP*( wx* data.px[i] +
+	  arg= -TP*( wx* data.px[i] +
 		  wy* data.py[i]- wz* data.pz[i]);
-	  tt1= cmplx( cosl( arg), sinl( arg)) *
+	  tt1= cmplx( cos( arg), sin( arg)) *
 		data.psalp[i]* RETA;
 	  e[i2]= e[i2]+( cx* data.t1x[i]+ cy *
 		  data.t1y[i]+ cz* data.t1z[i])* tt1;
@@ -1047,12 +1017,12 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
   } /* if( ipr <= 3) */
 
   /* incident field of an elementary current source. */
-  wz= cosl( p4);
-  wx= wz* cosl( p5);
-  wy= wz* sinl( p5);
-  wz= sinl( p4);
-  ds= p6*59.9580l;
-  dsh= p6/(2.0l* TP);
+  wz= cos( p4);
+  wx= wz* cos( p5);
+  wy= wz* sin( p5);
+  wz= sin( p4);
+  ds= p6*59.9580;
+  dsh= p6/(2.0* TP);
 
   is= 0;
   i1= data.n-2;
@@ -1074,21 +1044,21 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 	}
 
 	rs= pxl* pxl+ pyl* pyl+ pzl* pzl;
-	if( rs < 1.0e-30l)
+	if( rs < 1.0e-30)
 	  continue;
 
-	r= sqrtl( rs);
+	r= sqrt( rs);
 	pxl= pxl/ r;
 	pyl= pyl/ r;
 	pzl= pzl/ r;
 	cth= pxl* wx+ pyl* wy+ pzl* wz;
-	sth= sqrtl(1.0l- cth* cth);
+	sth= sqrt(1.0- cth* cth);
 	qx= pxl- wx* cth;
 	qy= pyl- wy* cth;
 	qz= pzl- wz* cth;
 
-	arg= sqrtl( qx* qx+ qy* qy+ qz* qz);
-	if( arg >= 1.0e-30l)
+	arg= sqrt( qx* qx+ qy* qy+ qz* qz);
+	if( arg >= 1.0e-30)
 	{
 	  qx= qx/ arg;
 	  qy= qy/ arg;
@@ -1096,20 +1066,20 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 	}
 	else
 	{
-	  qx=1.0l;
-	  qy=0.0l;
-	  qz=0.0l;
+	  qx=1.0;
+	  qy=0.0;
+	  qz=0.0;
 
-	} /* if( arg >= 1.0e-30l) */
+	} /* if( arg >= 1.0e-30) */
 
-	arg=- TP* r;
-	tt1= cmplx( cosl( arg), sinl( arg));
+	arg= -TP* r;
+	tt1= cmplx( cos( arg), sin( arg));
 
 	if( i < data.n )
 	{
-	  tt2= cmplx(1.0l,-1.0l/( r* TP))/ rs;
+	  tt2= cmplx(1.0,-1.0/( r* TP))/ rs;
 	  er= ds* tt1* tt2* cth;
-	  et=.5l* ds* tt1*((CPLX_01)* TP/ r+ tt2)* sth;
+	  et=.5* ds* tt1*((CPLX_01)* TP/ r+ tt2)* sth;
 	  ezh= er* cth- et* sth;
 	  erh= er* sth+ et* cth;
 	  cx= ezh* wx+ erh* qx;
@@ -1123,7 +1093,7 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 	  pxl= wy* qz- wz* qy;
 	  pyl= wz* qx- wx* qz;
 	  pzl= wx* qy- wy* qx;
-	  tt2= dsh* tt1* cmplx(1.0l/ r, TP) /
+	  tt2= dsh* tt1* cmplx(1.0/ r, TP) /
 		r* sth* data.psalp[is];
 	  cx= tt2* pxl;
 	  cy= tt2* pyl;
@@ -1148,15 +1118,15 @@ void etmns( long double p1, long double p2, long double p3, long double p4,
 /* numerical analysis.  comments below refer to comments in ralstons */
 /* text.    (matrix transposed.) */
 
-void factr( int n, complex long double *a, int *ip, int ndim)
+void factr( int n, complex double *a, int *ip, int ndim)
 {
   int r, rm1, rp1, pj, pr, iflg, k, j, jp1, i;
-  long double dmax, elmag;
-  complex long double arj, *scm = NULL;
+  double dmax, elmag;
+  complex double arj, *scm = NULL;
 
   /* Allocate to scratch memory */
-  mem_alloc( (void *)&scm,
-	  data.np2m * sizeof(complex long double), "in matrix.c");
+  size_t mreq = (size_t)data.np2m * sizeof(complex double);
+  mem_alloc( (void **)&scm, mreq, "in matrix.c");
 
   /* Un-transpose the matrix for Gauss elimination */
   for( i = 1; i < n; i++ )
@@ -1191,10 +1161,10 @@ void factr( int n, complex long double *a, int *ip, int ndim)
 
 	  } /* for( j = 0; j < rm1; j++ ) */
 
-	} /* if( rm1 >= 0.0l) */
+	} /* if( rm1 >= 0.0) */
 
 	/* step 4 */
-	dmax= creal( scm[r]*conjl(scm[r]) );
+	dmax= creal( scm[r]*conj(scm[r]) );
 
 	rp1= r+1;
 	ip[r]= rp1;
@@ -1202,7 +1172,7 @@ void factr( int n, complex long double *a, int *ip, int ndim)
 	{
 	  for( i = rp1; i < n; i++ )
 	  {
-		elmag= creal( scm[i]* conjl(scm[i]) );
+		elmag= creal( scm[i]* conj(scm[i]) );
 		if( elmag >= dmax)
 		{
 		  dmax= elmag;
@@ -1211,7 +1181,7 @@ void factr( int n, complex long double *a, int *ip, int ndim)
 	  }
 	} /* if( rp1 < n) */
 
-	if( dmax < 1.0e-10l)
+	if( dmax < 1.0e-10)
 	  iflg=TRUE;
 
 	pr= ip[r]-1;
@@ -1221,7 +1191,7 @@ void factr( int n, complex long double *a, int *ip, int ndim)
 	/* step 5 */
 	if( rp1 < n)
 	{
-	  arj=1.0l/ a[r+r*ndim];
+	  arj=1.0/ a[r+r*ndim];
 
 	  for( i = rp1; i < n; i++ )
 		a[i+r*ndim]= scm[i]* arj;
@@ -1230,13 +1200,13 @@ void factr( int n, complex long double *a, int *ip, int ndim)
 	if( iflg == TRUE )
 	{
 	  fprintf( stderr,
-		  "xnec2c: pivot(%d)= %16.8LE\n", r, dmax );
+		  "xnec2c: pivot(%d)= %16.8E\n", r, dmax );
 	  iflg=FALSE;
 	}
 
   } /* for( r=0; r < n; r++ ) */
 
-  free_ptr( (void *)&scm );
+  free_ptr( (void **)&scm );
 
   return;
 }
@@ -1247,7 +1217,7 @@ void factr( int n, complex long double *a, int *ip, int ndim)
 /* matricies of the symmetric modes and calls routine to factor */
 /* matricies.  if no symmetry, the routine is called to factor the */
 /* complete matrix. */
-void factrs( int np, int nrow, complex long double *a, int *ip )
+void factrs( int np, int nrow, complex double *a, int *ip )
 {
   int kk, ka;
 
@@ -1264,12 +1234,12 @@ void factrs( int np, int nrow, complex long double *a, int *ip )
 
 /* fblock sets parameters for out-of-core */
 /* solution for the primary matrix (a) */
-  int
+  void
 fblock( int nrow, int ncol, int imax, int ipsym )
 {
   int i, j, k, ka, kk;
-  long double phaz, arg;
-  complex long double deter;
+  double phaz, arg;
+  complex double deter;
 
   if( nrow*ncol <= imax)
   {
@@ -1280,10 +1250,9 @@ fblock( int nrow, int ncol, int imax, int ipsym )
 	if( nrow == ncol)
 	{
 	  matpar.icase=1;
-	  return(0);
+	  return;
 	}
-	else
-	  matpar.icase=2;
+	else matpar.icase=2;
 
   } /* if( nrow*ncol <= imax) */
 
@@ -1291,8 +1260,8 @@ fblock( int nrow, int ncol, int imax, int ipsym )
   if( smat.nop*nrow != ncol)
   {
 	fprintf( stderr,
-		"xnec2c: symmetry error - nrow:%d ncol:%d\n",nrow, ncol );
-	stop( "fblock(): symmetry error", 1 );
+		"xnec2c: fblock(): symmetry error - nrow:%d ncol:%d\n",nrow, ncol );
+	stop( _("fblock(): Symmetry error"), ERR_STOP );
   }
 
   /* set up smat.ssx matrix for rotational symmetry. */
@@ -1304,12 +1273,12 @@ fblock( int nrow, int ncol, int imax, int ipsym )
 	{
 	  for( j= i; j < smat.nop; j++ )
 	  {
-		arg= phaz* (long double)i * (long double)j;
-		smat.ssx[i+j*smat.nop]= cmplx( cosl( arg), sinl( arg));
+		arg= phaz* (double)i * (double)j;
+		smat.ssx[i+j*smat.nop]= cmplx( cos( arg), sin( arg));
 		smat.ssx[j+i*smat.nop]= smat.ssx[i+j*smat.nop];
 	  }
 	}
-	return(0);
+	return;
 
   } /* if( ipsym <= 0) */
 
@@ -1329,7 +1298,7 @@ fblock( int nrow, int ncol, int imax, int ipsym )
 	  {
 		deter= smat.ssx[i+j*smat.nop];
 		smat.ssx[i+(j+kk)*smat.nop]= deter;
-		smat.ssx[i+kk+(j+kk)*smat.nop]=- deter;
+		smat.ssx[i+kk+(j+kk)*smat.nop]= -deter;
 		smat.ssx[i+kk+j*smat.nop]= deter;
 	  }
 	}
@@ -1337,7 +1306,7 @@ fblock( int nrow, int ncol, int imax, int ipsym )
 
   } /* for( k = 0; k < ka; k++ ) */
 
-  return(0);
+  return;
 }
 
 /*-----------------------------------------------------------------------*/
@@ -1347,15 +1316,16 @@ fblock( int nrow, int ncol, int imax, int ipsym )
 /* lower triangular matrix and u is an upper triangular matrix both */
 /* of which are stored in a.  the rhs vector b is input and the */
 /* solution is returned through vector b.   (matrix transposed) */
-void solve( int n, complex long double *a, int *ip,
-	complex long double *b, int ndim )
+  void
+solve( int n, complex double *a, int *ip,
+	complex double *b, int ndim )
 {
   int i, ip1, j, k, pia;
-  complex long double sum, *scm = NULL;
+  complex double sum, *scm = NULL;
 
   /* Allocate to scratch memory */
-  mem_alloc( (void *)&scm,
-	  data.np2m*sizeof(complex long double), "in matrix.c");
+  size_t mreq = (size_t)data.np2m * sizeof(complex double);
+  mem_alloc( (void **)&scm, mreq, "in matrix.c");
 
   /* forward substitution */
   for( i = 0; i < n; i++ )
@@ -1384,7 +1354,7 @@ void solve( int n, complex long double *a, int *ip,
 	b[i]=( scm[i]- sum)/ a[i+i*ndim];
   }
 
-  free_ptr( (void *)&scm );
+  free_ptr( (void **)&scm );
 
   return;
 }
@@ -1394,23 +1364,24 @@ void solve( int n, complex long double *a, int *ip,
 /* subroutine solves, for symmetric structures, handles the */
 /* transformation of the right hand side vector and solution */
 /* of the matrix eq. */
-void solves( complex long double *a, int *ip,
-	complex long double *b,	int neq, int nrh,
+  void
+solves( complex double *a, int *ip,
+	complex double *b,	int neq, int nrh,
 	int np, int n, int mp, int m)
 {
   int npeq, nrow, ic, i, kk, ia, ib, j, k;
-  long double fnop, fnorm;
-  complex long double  sum, *scm = NULL;
+  double fnop, fnorm;
+  complex double  sum, *scm = NULL;
 
   npeq= np+ 2*mp;
   smat.nop = neq/npeq;
   fnop= smat.nop;
-  fnorm=1.0l/ fnop;
+  fnorm=1.0/ fnop;
   nrow= neq;
 
   /* Allocate to scratch memory */
-  mem_alloc( (void *)&scm,
-	  data.np2m*sizeof(complex long double), "in matrix.c");
+  size_t mreq = (size_t)data.np2m * sizeof(complex double);
+  mem_alloc( (void **)&scm, mreq, "in matrix.c");
 
   if( smat.nop != 1)
   {
@@ -1474,7 +1445,7 @@ void solves( complex long double *a, int *ip,
 		  sum= scm[0];
 
 		  for( j = 1; j < smat.nop; j++ )
-			sum += scm[j]* conjl( smat.ssx[k+j*smat.nop]);
+			sum += scm[j]* conj( smat.ssx[k+j*smat.nop]);
 
 		  b[ia+ic*neq]= sum* fnorm;
 		}
@@ -1498,7 +1469,7 @@ void solves( complex long double *a, int *ip,
 
   if( smat.nop == 1)
   {
-	free_ptr( (void *)&scm );
+	free_ptr( (void **)&scm );
 	return;
   }
 
@@ -1569,7 +1540,7 @@ void solves( complex long double *a, int *ip,
 
   } /* for( ic = 0; ic < nrh; ic++ ) */
 
-  free_ptr( (void *)&scm );
+  free_ptr( (void **)&scm );
 
   return;
 }
