@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis@mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,19 +16,20 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* nec2_model.h
- *
- * Header file for nec2_model.c
- */
-
 #ifndef	NEC2_MODEL_H
-#define	NEC2_MODEL_H 1
+#define	NEC2_MODEL_H	1
 
-enum
+#include "common.h"
+#include "interface.h"
+#include "support.h"
+#include "editors.h"
+
+/* Commands for the NEC2 file editor */
+enum NEC2_CMND
 {
   NEC2_EDITOR_NEW = 0,
   NEC2_EDITOR_REVERT,
-  NEC2_EDITOR_SAVE
+  NEC2_EDITOR_RELOAD
 };
 
 #endif
