@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,84 +41,61 @@
 
  ***********************************************************************/
 
-#include "xnec2c.h"
-
-/* common  /crnt/ */
-crnt_t crnt;
-
-/* common  /netcx/ */
-netcx_t netcx;
-
-/* common  /vsorc/ */
-vsorc_t vsorc;
-
-/* common  /data/ */
-extern data_t data;
-
-/* common  /smat/ */
-extern smat_t smat;
-
-/* common  /zload/ */
-zload_t zload;
-
-/* pointers to input */
-extern FILE *input_fp;
+#include "network.h"
+#include "shared.h"
 
 /*-------------------------------------------------------------------*/
 
 /* subroutine netwk solves for structure currents for a given */
 /* excitation including the effect of non-radiating networks if */
 /* present. */
-void netwk( complex long double *cm, int *ip, complex long double *einc )
+void netwk( complex double *cmx, int *ip, complex double *einc )
 {
   int *ipnt = NULL, *nteqa = NULL, *ntsca = NULL;
-  int jump1, jump2, nteq=0, ntsc=0, nseg2, irow2=0, j, ndimn;
-  int neqz2, neqt, irow1=0, i, nseg1, isc1=0, isc2=0;
-  long double asmx, pwr, y11r, y11i, y12r, y12i, y22r, y22i;
-  complex long double *vsrc = NULL, *rhs = NULL, *cmn = NULL;
-  complex long double *rhnt = NULL, *rhnx = NULL, ymit, vlt, cux;
+  int nteq=0, ntsc=0, j, ndimn;
+  int neqt, irow1=0, i, isc1=0;
+  double pwr;
+  complex double *vsrc = NULL, *rhs = NULL, *cmn = NULL;
+  complex double *rhnt = NULL, *rhnx = NULL, ymit, vlt, cux;
   size_t mreq;
 
-  neqz2= netcx.neq2;
-  if( neqz2 == 0)
-	neqz2=1;
-
-  netcx.pin=0.0l;
-  netcx.pnls=0.0l;
+  netcx.pin=0.0;
+  netcx.pnls=0.0;
   neqt= netcx.neq+ netcx.neq2;
   ndimn = j = (2*netcx.nonet + vsorc.nsant);
 
   /* Allocate network buffers */
   if( netcx.nonet > 0 )
   {
-	mem_alloc( (void *)&rhs, data.np3m *
-		sizeof(complex long double), "in network.c");
+	mreq = (size_t)data.np3m * sizeof(complex double);
+	mem_alloc( (void **)&rhs, mreq, "in network.c");
 
-	mreq = j * sizeof(complex long double);
-	mem_alloc( (void *)&rhnt, mreq, "in network.c");
-	mem_alloc( (void *)&rhnx, mreq, "in network.c");
-	mem_alloc( (void *)&cmn,  mreq * j, "in network.c");
+	mreq = (size_t)j * sizeof(complex double);
+	mem_alloc( (void **)&rhnt, mreq, "in network.c");
+	mem_alloc( (void **)&rhnx, mreq, "in network.c");
+	mem_alloc( (void **)&cmn,  mreq * (size_t)j, "in network.c");
 
-	mreq = j * sizeof(int);
-	mem_alloc( (void *)&ntsca, mreq, "in network.c");
-	mem_alloc( (void *)&nteqa, mreq, "in network.c");
-	mem_alloc( (void *)&ipnt,  mreq, "in network.c");
+	mreq = (size_t)j * sizeof(int);
+	mem_alloc( (void **)&ntsca, mreq, "in network.c");
+	mem_alloc( (void **)&nteqa, mreq, "in network.c");
+	mem_alloc( (void **)&ipnt,  mreq, "in network.c");
 
-	mem_alloc( (void *)&vsrc, vsorc.nsant *
-		sizeof(complex long double), "in network.c");
+	mreq = (size_t)vsorc.nsant * sizeof(complex double);
+	mem_alloc( (void **)&vsrc, mreq, "in network.c");
+  }
+  else if( netcx.masym != 0)
+  {
+	mreq = (size_t)j * sizeof(int);
+	mem_alloc( (void **)&ipnt,  mreq, "in network.c");
   }
-  else
-	if( netcx.masym != 0)
-	{
-	  mreq = j * sizeof(int);
-	  mem_alloc( (void *)&ipnt,  mreq, "in network.c");
-	}
 
   /* Signal new and valid current data */
   crnt.newer = crnt.valid = 1;
 
   if( netcx.ntsol == 0)
   {
+	int nseg1;
+
 	/* compute relative matrix asymmetry */
 	if( netcx.masym != 0)
 	{
@@ -185,6 +161,8 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 
 	  if( irow1 >= 2)
 	  {
+		double asmx;
+
 		for( i = 0; i < irow1; i++ )
 		{
 		  isc1= ipnt[i]-1;
@@ -194,7 +172,7 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 			rhs[j] = CPLX_00;
 
 		  rhs[isc1] = CPLX_10;
-		  solves( cm, ip, rhs, netcx.neq, 1,
+		  solves( cmx, ip, rhs, netcx.neq, 1,
 			  data.np, data.n, data.mp, data.m);
 		  cabc( rhs);
 
@@ -206,7 +184,7 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 
 		} /* for( i = 0; i < irow1; i++ ) */
 
-		asmx=0.0l;
+		asmx=0.0;
 
 		for( i = 1; i < irow1; i++ )
 		{
@@ -214,7 +192,7 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 		  for( j = 0; j < isc1; j++ )
 		  {
 			cux= cmn[i+j*ndimn];
-			pwr= cabsl(( cux- cmn[j+i*ndimn])/ cux);
+			pwr= cabs(( cux- cmn[j+i*ndimn])/ cux);
 
 			if( pwr < asmx)
 			  continue;
@@ -232,7 +210,7 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 	} /* if( netcx.masym != 0) */
 
 	/* solution of network equations */
-	if( netcx.nonet != 0)
+	if( netcx.nonet > 0)
 	{
 	  for( i = 0; i < ndimn; i++ )
 	  {
@@ -248,6 +226,9 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 
 	  for( j = 0; j < netcx.nonet; j++ )
 	  {
+		int  jump1, jump2, nseg2, isc2=0, irow2=0;
+		double y11r, y11i, y12r, y12i, y22r, y22i;
+
 		nseg1= netcx.iseg1[j];
 		nseg2= netcx.iseg2[j];
 
@@ -263,18 +244,18 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 		else
 		{
 		  y22r= TP* netcx.x11i[j]/ data.wlam;
-		  y12r=0.0l;
-		  y12i=1.0l/( netcx.x11r[j]* sinl( y22r));
+		  y12r=0.0;
+		  y12i=1.0/( netcx.x11r[j]* sin( y22r));
 		  y11r= netcx.x12r[j];
-		  y11i=- y12i* cosl( y22r);
+		  y11i= -y12i* cos( y22r);
 		  y22r= netcx.x22r[j];
 		  y22i= y11i+ netcx.x22i[j];
 		  y11i= y11i+ netcx.x12i[j];
 
 		  if( netcx.ntyp[j] != 2)
 		  {
-			y12r=- y12r;
-			y12i=- y12i;
+			y12r= -y12r;
+			y12i= -y12i;
 		  }
 
 		} /* if( netcx.ntyp[j] <= 1) */
@@ -449,7 +430,7 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 
 		irow1= nteqa[i]-1;
 		rhs[irow1]=CPLX_10;
-		solves( cm, ip, rhs, netcx.neq, 1,
+		solves( cmx, ip, rhs, netcx.neq, 1,
 			data.np, data.n, data.mp, data.m);
 		cabc( rhs);
 
@@ -468,14 +449,14 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 
   } /* if( netcx.ntsol != 0) */
 
-  if( netcx.nonet != 0)
+  if( netcx.nonet > 0)
   {
 	/* add to network equation right hand side */
 	/* the terms due to element interactions */
 	for( i = 0; i < neqt; i++ )
 	  rhs[i]= einc[i];
 
-	solves( cm, ip, rhs, netcx.neq, 1,
+	solves( cmx, ip, rhs, netcx.neq, 1,
 		data.np, data.n, data.mp, data.m);
 	cabc( rhs);
 
@@ -496,7 +477,7 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 	  einc[irow1] -= rhnt[i];
 	}
 
-	solves( cm, ip, einc, netcx.neq, 1,
+	solves( cmx, ip, einc, netcx.neq, 1,
 		data.np, data.n, data.mp, data.m);
 	cabc( einc);
 
@@ -505,10 +486,8 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 	  irow1= nteqa[i]-1;
 	  vlt= rhnt[i]* data.si[irow1]* data.wlam;
 	  cux= einc[irow1]* data.wlam;
-	  ymit= cux/ vlt;
 	  netcx.zped= vlt/ cux;
-	  irow2= data.itag[irow1];
-	  pwr=.5l* creall( vlt* conjl( cux));
+	  pwr=.5* creal( vlt* conj( cux));
 	  netcx.pnls= netcx.pnls- pwr;
 	}
 
@@ -519,10 +498,8 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 		irow1= ntsca[i]-1;
 		vlt= vsrc[i];
 		cux= einc[irow1]* data.wlam;
-		ymit= cux/ vlt;
 		netcx.zped= vlt/ cux;
-		irow2= data.itag[irow1];
-		pwr=.5l* creall( vlt* conjl( cux));
+		pwr=.5* creal( vlt* conj( cux));
 		netcx.pnls= netcx.pnls- pwr;
 	  } /* for( i = 0; i < ntsc; i++ ) */
 
@@ -532,7 +509,7 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
   else
   {
 	/* solve for currents when no networks are present */
-	solves( cm, ip, einc, netcx.neq, 1,
+	solves( cmx, ip, einc, netcx.neq, 1,
 		data.np, data.n, data.mp, data.m);
 	cabc( einc);
 	ntsc=0;
@@ -541,14 +518,14 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
   if( (vsorc.nsant+vsorc.nvqd) == 0)
   {
 	/* Free network buffers */
-	free_ptr( (void *)&ipnt );
-	free_ptr( (void *)&nteqa );
-	free_ptr( (void *)&ntsca );
-	free_ptr( (void *)&vsrc );
-	free_ptr( (void *)&rhs );
-	free_ptr( (void *)&cmn );
-	free_ptr( (void *)&rhnt );
-	free_ptr( (void *)&rhnx );
+	free_ptr( (void **)&ipnt );
+	free_ptr( (void **)&nteqa );
+	free_ptr( (void **)&ntsca );
+	free_ptr( (void **)&vsrc );
+	free_ptr( (void **)&rhs );
+	free_ptr( (void **)&cmn );
+	free_ptr( (void **)&rhnt );
+	free_ptr( (void **)&rhnx );
 	return;
   }
 
@@ -579,15 +556,12 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 
 	  } /* if( ntsc == 0) */
 
-	  ymit= cux/ vlt;
 	  netcx.zped= vlt/ cux;
-	  pwr=.5l* creall( vlt* conjl( cux));
+	  pwr=.5* creal( vlt* conj( cux));
 	  netcx.pin= netcx.pin+ pwr;
 
 	  if( irow1 != 0)
 		netcx.pnls= netcx.pnls+ pwr;
-
-	  irow2= data.itag[isc1];
 	} /* for( i = 0; i < vsorc.nsant; i++ ) */
 
   } /* if( vsorc.nsant != 0) */
@@ -600,25 +574,23 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 	  cux= cmplx( crnt.air[isc1], crnt.aii[isc1]);
 	  ymit= cmplx( crnt.bir[isc1], crnt.bii[isc1]);
 	  netcx.zped= cmplx( crnt.cir[isc1], crnt.cii[isc1]);
-	  pwr= data.si[isc1]* TP*.5l;
-	  cux=( cux- ymit* sinl( pwr) +
-		  netcx.zped* cosl( pwr))* data.wlam;
-	  ymit= cux/ vlt;
+	  pwr= data.si[isc1]* TP*.5;
+	  cux=( cux- ymit* sin( pwr) +
+		  netcx.zped* cos( pwr))* data.wlam;
 	  netcx.zped= vlt/ cux;
-	  pwr=.5l* creall( vlt* conjl( cux));
+	  pwr=.5* creal( vlt* conj( cux));
 	  netcx.pin= netcx.pin+ pwr;
-	  irow2= data.itag[isc1];
 	} /* for( i = 0; i < vsorc.nvqd; i++ ) */
 
   /* Free network buffers */
-  free_ptr( (void *)&ipnt );
-  free_ptr( (void *)&nteqa );
-  free_ptr( (void *)&ntsca );
-  free_ptr( (void *)&vsrc );
-  free_ptr( (void *)&rhs );
-  free_ptr( (void *)&cmn );
-  free_ptr( (void *)&rhnt );
-  free_ptr( (void *)&rhnx );
+  free_ptr( (void **)&ipnt );
+  free_ptr( (void **)&nteqa );
+  free_ptr( (void **)&ntsca );
+  free_ptr( (void **)&vsrc );
+  free_ptr( (void **)&rhs );
+  free_ptr( (void **)&cmn );
+  free_ptr( (void **)&rhnt );
+  free_ptr( (void **)&rhnx );
 
   return;
 }
@@ -627,21 +599,20 @@ void netwk( complex long double *cm, int *ip, complex long double *einc )
 
 /* load calculates the impedance of specified */
 /* segments for various types of loading */
-  int
+  void
 load( int *ldtyp, int *ldtag, int *ldtagf, int *ldtagt,
-	long double *zlr, long double *zli, long double *zlc )
+	double *zlr, double *zli, double *zlc )
 {
-  int i, iwarn, istep, istepx, l1, l2, ldtags, jump, ichk;
-  complex long double zt=CPLX_00, tpcj;
+  int i, istep, istepx, l1, l2, ldtags, jump, ichk;
+  complex double zt=CPLX_00, tpcj;
 
-  tpcj = (0.0l+1.883698955e+9lj);
+  tpcj = (0.0+I*1.883698955e+9);
 
   /* initialize d array, used for temporary */
   /* storage of loading information. */
   for( i = 0; i < data.n; i++ )
 	zload.zarray[i]=CPLX_00;
 
-  iwarn=FALSE;
   istep=0;
 
   /* cycle over loading cards */
@@ -653,13 +624,12 @@ load( int *ldtyp, int *ldtag, int *ldtagf, int *ldtagt,
 	if( istep > zload.nload)
 	{
 	  smat.nop = data.n/data.np;
-	  if( smat.nop == 1)
-		return(0);
+	  if( smat.nop == 1) return;
 
 	  for( i = 0; i < data.np; i++ )
 	  {
-		zt= zload.zarray[i];
-		l1= i;
+		zt = zload.zarray[i];
+		l1 = i;
 
 		for( l2 = 1; l2 < smat.nop; l2++ )
 		{
@@ -667,16 +637,16 @@ load( int *ldtyp, int *ldtag, int *ldtagf, int *ldtagt,
 		  zload.zarray[l1]= zt;
 		}
 	  }
-	  return(0);
 
+	  return;
 	} /* if( istep > zload.nload) */
 
 	if( ldtyp[istepx] > 5 )
 	{
 	  fprintf( stderr,
-		  "xnec2c: improper load type chosen,"
+		  "xnec2c: load(): improper load type chosen,"
 		  " requested type is %d\n", ldtyp[istepx] );
-	  stop( "Improper load type chosen", 1 );
+	  stop( _("load(): Improper load type chose"), ERR_STOP );
 	}
 
 	/* search segments for proper itags */
@@ -710,12 +680,10 @@ load( int *ldtyp, int *ldtag, int *ldtagf, int *ldtagt,
 		  if( (ichk < ldtagf[istepx]) || (ichk > ldtagt[istepx]) )
 			continue;
 		}
-		else
-		  ichk=1;
+		else ichk=1;
 
 	  } /* if( ldtags != 0) */
-	  else
-		ichk=1;
+	  else ichk=1;
 
 	  /* calculation of lamda*imped. per unit length, */
 	  /* jump to appropriate section for loading type */
@@ -724,32 +692,32 @@ load( int *ldtyp, int *ldtag, int *ldtagf, int *ldtagt,
 		case 1:
 		  zt= zlr[istepx]/ data.si[i] +
 			tpcj* zli[istepx]/( data.si[i]* data.wlam);
-		  if( fabsl( zlc[istepx]) > 1.0e-20l)
+		  if( fabs( zlc[istepx]) > 1.0e-20)
 			zt += data.wlam/( tpcj* data.si[i]* zlc[istepx]);
 		  break;
 
 		case 2:
 		  zt= tpcj* data.si[i]* zlc[istepx]/ data.wlam;
-		  if( fabsl( zli[istepx]) > 1.0e-20l)
+		  if( fabs( zli[istepx]) > 1.0e-20)
 			zt += data.si[i]* data.wlam/( tpcj* zli[istepx]);
-		  if( fabsl( zlr[istepx]) > 1.0e-20l)
+		  if( fabs( zlr[istepx]) > 1.0e-20)
 			zt += data.si[i]/ zlr[istepx];
-		  zt=1.0l/ zt;
+		  zt=1.0/ zt;
 		  break;
 
 		case 3:
 		  zt= zlr[istepx]* data.wlam+ tpcj* zli[istepx];
-		  if( fabsl( zlc[istepx]) > 1.0e-20l)
-			zt += 1.0l/( tpcj* data.si[i]* data.si[i]* zlc[istepx]);
+		  if( fabs( zlc[istepx]) > 1.0e-20)
+			zt += 1.0/( tpcj* data.si[i]* data.si[i]* zlc[istepx]);
 		  break;
 
 		case 4:
 		  zt= tpcj* data.si[i]* data.si[i]* zlc[istepx];
-		  if( fabsl( zli[istepx]) > 1.0e-20l)
-			zt += 1.0l/( tpcj* zli[istepx]);
-		  if( fabsl( zlr[istepx]) > 1.0e-20l)
-			zt += 1.0l/( zlr[istepx]* data.wlam);
-		  zt=1.0l/ zt;
+		  if( fabs( zli[istepx]) > 1.0e-20)
+			zt += 1.0/( tpcj* zli[istepx]);
+		  if( fabs( zlr[istepx]) > 1.0e-20)
+			zt += 1.0/( zlr[istepx]* data.wlam);
+		  zt=1.0/ zt;
 		  break;
 
 		case 5:
@@ -761,25 +729,20 @@ load( int *ldtyp, int *ldtag, int *ldtagf, int *ldtagt,
 
 	  } /* switch( jump ) */
 
-	  if( (fabsl(creall(zload.zarray[i])) +
-			fabsl(cimagl(zload.zarray[i]))) > 1.0e-20l)
-		iwarn=TRUE;
 	  zload.zarray[i] += zt;
-
 	} /* for( i = l1-1; i < l2; i++ ) */
 
 	if( ichk == 0 )
 	{
 	  fprintf( stderr,
-		  "xnec2c: loading data card error,"
+		  "xnec2c: load(): loading data card error,"
 		  " no segment has an itag = %d\n", ldtags );
-	  stop( "Loading data card\n"
-		  "Tag number mismatch error", 1 );
+	  stop( _("load(): Loading data card\n"\
+			"Tag number mismatch error"), ERR_STOP );
 	}
 
   } /* while( TRUE ) */
 
-  return(0);
 }
 
 /*-----------------------------------------------------------------------*/
