@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +16,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-/* frqdata_plots.c
+/* plot_freqdata.c
  *
  * Code for plotting graphs of structure
  * data (VSWR, impedance, gain etc)
@@ -30,33 +29,12 @@
  *      NetGain = RawGain+10*log(Feed-pointGain)
  *      where Feed-point Gain = 4*Zr*Zo/((Zr+Zo)^2+Zi^2)
  *   http://www.avsforum.com/avs-vb/showthread.php?p=14086104#post14086104
- *      NetGain = RawGain+10*log(4*Zr*Zo/((Zr+Zo)^2+Zi^2)    
+ *      NetGain = RawGain+10*log(4*Zr*Zo/((Zr+Zo)^2+Zi^2)
  *   Where log is log10.
  */
 
-#include "xnec2c.h"
-#include "support.h"
-
-/* Plots drawingarea */
-extern GtkWidget *freqplots_drawingarea;
-extern GtkWidget *freqplots_window;
-
-/* Antenna drawing area widget */
-extern GtkWidget *main_window;
-extern GtkWidget *rdpattern_window;
-
-/* Pixmap for drawing plots */
-extern GdkPixmap *freqplots_pixmap;
-extern int freqplots_pixmap_width, freqplots_pixmap_height;
-
-/* Parameters for projecting structure to Screen */
-extern projection_parameters_t structure_proj_params;
-
-/* Some graphics contexts */
-extern GdkGC
-  *white_gc,
-  *black_gc,
-  *plot_gc;
+#include "plot_freqdata.h"
+#include "shared.h"
 
 /* Graph plot bounding rectangle */
 static GdkRectangle plot_rect;
@@ -65,22 +43,6 @@ static GdkRectangle plot_rect;
 static double max_fscale, min_fscale;
 static int nval_fscale;
 
-/* Radiation pattern freq spinbutton */
-extern GtkSpinButton *rdpattern_frequency;
-
-/* Main window freq spinbutton */
-extern GtkSpinButton *mainwin_frequency;
-
-/* Needed data */
-impedance_data_t impedance_data;
-extern save_t save;
-extern calc_data_t calc_data;
-extern fpat_t fpat;
-extern netcx_t netcx;
-
-/* Radiation pattern data */
-extern rad_pattern_t *rad_pattern;
-
 /*-----------------------------------------------------------------------*/
 
 /* Plot_Frequency_Data()
@@ -89,6 +51,14 @@ extern rad_pattern_t *rad_pattern;
   void
 Plot_Frequency_Data( void )
 {
+  /* Abort plotting if main window is to be closed
+   * or when plots drawing area not available */
+  if(
+	  isFlagSet(MAIN_QUIT) ||
+	  isFlagClear(PLOT_ENABLED) ||
+	  isFlagClear(ENABLE_EXCITN) )
+	return;
+
   /* Titles for plots */
   char *titles[3];
 
@@ -99,9 +69,8 @@ Plot_Frequency_Data( void )
 
   static double
 	*gmax     = NULL, /* Max gain buffer */
-	*netgmax  = NULL, /* Net Max gain buffer */
 	*vgain    = NULL, /* Viewer direction gain buffer */
-	*netgain = NULL, /* Viewer direction net gain buffer */
+	*netgain  = NULL, /* Viewer direction net gain buffer */
 	*gdir_tht = NULL, /* Direction in theta of gain */
 	*gdir_phi = NULL, /* Direction in phi of gain */
 	*fbratio  = NULL; /* Front to back ratio */
@@ -109,21 +78,16 @@ Plot_Frequency_Data( void )
   /* Used to calculate net gain */
   double Zr, Zo, Zi;
 
-  /* Abort plotting if main window is to be closed
-   * or when plots drawing area not available */
-  if(
-	  isFlagSet(MAIN_QUIT) ||
-	  isFlagClear(PLOT_ENABLED) ||
-	  isFlagClear(ENABLE_EXCITN) )
-	return;
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( freqplots_pixmap );
 
   /* Clear pixmap */
-  gdk_draw_rectangle(
-	  freqplots_pixmap,
-	  black_gc,
-	  TRUE, 0, 0,
-	  freqplots_pixmap_width,
-	  freqplots_pixmap_height);
+  cairo_set_source_rgb( cr, BLACK );
+  cairo_rectangle(
+	  cr, 0.0, 0.0,
+	  (double)freqplots_pixmap_width,
+	  (double)freqplots_pixmap_height );
+  cairo_fill( cr );
 
   /* Abort if plotting is not possible */
   if( (calc_data.fstep < 1)				||
@@ -139,56 +103,53 @@ Plot_Frequency_Data( void )
 	gdk_window_set_back_pixmap(
 		freqplots_drawingarea->window, freqplots_pixmap, FALSE );
 	gdk_window_clear( freqplots_drawingarea->window );
+	cairo_destroy( cr );
 	return;
   }
 
   /* Fit frequency range to scale */
-  min_fscale = (double)save.freq[0];
-  nval_fscale = freqplots_pixmap_width / 75;
+  min_fscale  = (double)save.freq[0];
   if( isFlagSet(FREQ_LOOP_RUNNING) )
 	max_fscale = (double)save.freq[calc_data.fstep];
   else
 	max_fscale = (double)save.freq[calc_data.lastf];
+  nval_fscale = freqplots_pixmap_width / 75;
   Fit_to_Scale( &max_fscale, &min_fscale, &nval_fscale );
 
   /* Graph position */
   posn = 0;
 
   /* Limit freq stepping to last freq step */
-  fstep = calc_data.lastf+1;
+  fstep = calc_data.lastf + 1;
 
   /* Plot max gain vs frequency, if possible */
   if( isFlagSet(PLOT_GMAX) && isFlagSet(ENABLE_RDPAT) )
   {
-	int nth, nph;
+	int nth, nph, pol;
 	gboolean no_fbr;
 
 	/* Allocate max gmax and directions */
-	mem_realloc( (void *)&gmax,
-		fstep * sizeof(double), "in plot_freqdata.c" );
-	mem_realloc( (void *)&gdir_tht,
-		fstep * sizeof(double), "in plot_freqdata.c" );
-	mem_realloc( (void *)&gdir_phi,
-		fstep * sizeof(double), "in plot_freqdata.c" );
-	mem_realloc( (void *)&fbratio,
-		fstep * sizeof(double), "in plot_freqdata.c" );
+	size_t mreq = (size_t)fstep * sizeof(double);
+	mem_realloc( (void **)&gmax,     mreq, "in plot_freqdata.c" );
+	mem_realloc( (void **)&gdir_tht, mreq, "in plot_freqdata.c" );
+	mem_realloc( (void **)&gdir_phi, mreq, "in plot_freqdata.c" );
+	mem_realloc( (void **)&fbratio,  mreq, "in plot_freqdata.c" );
 
 	if( isFlagSet(PLOT_NETGAIN) )
-	  mem_realloc( (void *)&netgain,
-		  fstep * sizeof(double), "in plot_freqdata.c" );
+	  mem_realloc( (void **)&netgain, mreq, "in plot_freqdata.c" );
 
 	/* Find max gain and direction, F/B ratio */
 	no_fbr = FALSE;
 
-	/* When freq loop is done, calcs are done for all freq steps */
+	/* Polarization type and impedance */
+	pol = calc_data.pol_type;
 	Zo = calc_data.zo;
+
+	/* When freq loop is done, calcs are done for all freq steps */
 	for( idx = 0; idx < fstep; idx++ )
 	{
 	  double fbdir;
-	  int pol, fbidx, mgidx;
-
-	  /* Polarization type */
-	  pol = calc_data.pol_type;
+	  int fbidx, mgidx;
 
 	  /* Index to gtot buffer where max gain
 	   * occurs for given polarization type */
@@ -196,7 +157,7 @@ Plot_Frequency_Data( void )
 
 	  /* Max gain for given polarization type */
 	  gmax[idx] = rad_pattern[idx].gtot[mgidx] +
-		10.0 * log10( Polarization_Factor(pol, idx, mgidx) );
+		Polarization_Factor(pol, idx, mgidx);
 
 	  /* Net gain if selected */
 	  if( isFlagSet(PLOT_NETGAIN) )
@@ -222,16 +183,22 @@ Plot_Frequency_Data( void )
 	  else
 		nth = (int)( fbdir/fpat.dth + 0.5 );
 
-	  /* No F/B calc. possible if no theta step at +180 from max gain */
+	  /* If the antenna is modelled over ground, then use the same
+	   * theta as the max gain direction, relying on phi alone to
+	   * take us to the back. Patch supplied by Rik van Riel AB1KW
+	   */
 	  if( (nth >= fpat.nth) || (nth < 0) )
 	  {
-		no_fbr = TRUE;
-		continue;
+		fbdir = rad_pattern[idx].max_gain_tht[pol];
+		if( fpat.dth == 0.0 )
+		  nth = 0;
+		else
+		  nth = (int)( fbdir/fpat.dth + 0.5 );
 	  }
 
 	  /* Find F/B direction in phi */
 	  fbdir = gdir_phi[idx] + 180.0;
-	  if( fbdir >= 360.0 ) fbdir -= 180.0;
+	  if( fbdir >= 360.0 ) fbdir -= 360.0;
 	  nph = (int)( fbdir/fpat.dph + 0.5 );
 
 	  /* No F/B calc. possible if no phi step at +180 from max gain */
@@ -247,8 +214,8 @@ Plot_Frequency_Data( void )
 	  /* Front to back ratio */
 	  fbratio[idx]  = pow( 10.0, gmax[idx] / 10.0 );
 	  fbratio[idx] /= pow( 10.0,
-		  rad_pattern[idx].gtot[fbidx] / 10.0 +
-		  log10(Polarization_Factor(pol, idx, fbidx)) );
+		  (rad_pattern[idx].gtot[fbidx] +
+		   Polarization_Factor(pol, idx, fbidx)) / 10.0 );
 	  fbratio[idx] = 10.0 * log10( fbratio[idx] );
 
 	} /* for( idx = 0; idx < fstep; idx++ ) */
@@ -257,18 +224,18 @@ Plot_Frequency_Data( void )
 	if( no_fbr || isFlagSet(PLOT_NETGAIN) )
 	{
 	  /* Plotting frame titles */
-	  titles[0] = "Raw Gain dbi";
+	  titles[0] = _("Raw Gain dbi");
 	  if( isFlagSet(PLOT_NETGAIN) )
 	  {
-		titles[1] = "Max Gain & Net Gain vs Frequency";
-		titles[2] = "Net Gain dbi";
+		titles[1] = _("Max Gain & Net Gain vs Frequency");
+		titles[2] = _("Net Gain dbi");
 		if( fstep > 1 )
 		  Plot_Graph2( gmax, netgain, save.freq, fstep,
 			  titles, calc_data.ngraph, ++posn );
 	  }
 	  else
 	  {
-		titles[1] = "Max Gain & F/B Ratio vs Frequency";
+		titles[1] = _("Max Gain & F/B Ratio vs Frequency");
 		titles[2] = "        ";
 		if( fstep > 1 )
 		  Plot_Graph( gmax, save.freq, fstep,
@@ -278,9 +245,9 @@ Plot_Frequency_Data( void )
 	else
 	{
 	  /* Plotting frame titles */
-	  titles[0] = "Raw Gain dbi";
-	  titles[1] = "Max Gain & F/B Ratio vs Frequency";
-	  titles[2] = "F/B Ratio db";
+	  titles[0] = _("Raw Gain dbi");
+	  titles[1] = _("Max Gain & F/B Ratio vs Frequency");
+	  titles[2] = _("F/B Ratio db");
 	  if( fstep > 1 )
 		Plot_Graph2( gmax, fbratio, save.freq, fstep,
 			titles, calc_data.ngraph, ++posn );
@@ -290,9 +257,9 @@ Plot_Frequency_Data( void )
 	if( isFlagSet(PLOT_GAIN_DIR) )
 	{
 	  /* Plotting frame titles */
-	  titles[0] = "Rad Angle - deg";
-	  titles[1] = "Max Gain Direction vs Frequency";
-	  titles[2] = "Phi - deg";
+	  titles[0] = _("Rad Angle - deg");
+	  titles[1] = _("Max Gain Direction vs Frequency");
+	  titles[2] = _("Phi - deg");
 	  if( fstep > 1 )
 		Plot_Graph2( gdir_tht, gdir_phi, save.freq, fstep,
 			titles, calc_data.ngraph, ++posn );
@@ -304,12 +271,12 @@ Plot_Frequency_Data( void )
   if( isFlagSet(PLOT_GVIEWER) && isFlagSet(ENABLE_RDPAT) )
   {
 	/* Plotting frame titles */
-	titles[0] = "Raw Gain dbi";
-	titles[1] = "Gain in Viewer Direction vs Frequency";
+	titles[0] = _("Raw Gain dbi");
+	titles[1] = _("Gain in Viewer Direction vs Frequency");
 
 	/* Allocate viewer gain buffer */
-	mem_realloc( (void *)&vgain,
-		fstep * sizeof(double), "in plot_freqdata.c" );
+	size_t mreq = (size_t)fstep * sizeof(double);
+	mem_realloc( (void **)&vgain, mreq, "in plot_freqdata.c" );
 
 	/* Calcs are done for all freq steps */
 	for( idx = 0; idx < fstep; idx++ )
@@ -318,8 +285,8 @@ Plot_Frequency_Data( void )
 	/* Plot net gain if selected */
 	if( isFlagSet(PLOT_NETGAIN) )
 	{
-	  mem_realloc( (void *)&netgain,
-		  fstep * sizeof(double), "in plot_freqdata.c" );
+	  mreq = (size_t)fstep * sizeof(double);
+	  mem_realloc( (void **)&netgain, mreq, "in plot_freqdata.c" );
 
 	  Zo = calc_data.zo;
 	  for( idx = 0; idx < fstep; idx++ )
@@ -331,7 +298,7 @@ Plot_Frequency_Data( void )
 	  }
 
 	  /* Plot net gain if selected */
-	  titles[2] = "Net gain dbi";
+	  titles[2] = _("Net gain dbi");
 	  if( fstep > 1 )
 		Plot_Graph2( vgain, netgain, save.freq, fstep,
 			titles, calc_data.ngraph, ++posn );
@@ -348,14 +315,25 @@ Plot_Frequency_Data( void )
   /* Plot VSWR vs freq */
   if( isFlagSet(PLOT_VSWR) )
   {
-	double vswr[calc_data.nfrq], gamma;
+	double *vswr = NULL, gamma;
 	double zrpro2, zrmro2, zimag2;
 
 	/* Plotting frame titles */
-	titles[0] = "VSWR";
-	titles[1] = "VSWR vs Frequency";
+	titles[0] = _("VSWR");
+	titles[1] = _("VSWR vs Frequency");
 
 	/* Calculate VSWR */
+	mem_alloc( (void **)&vswr,
+		(size_t)calc_data.nfrq * sizeof(double),
+		"in Plot_Frequency_Data()" );
+	if( vswr == NULL )
+	{
+	  fprintf( stderr, "xnec2c: Plot_Frequency_Data():"
+		  "memory allocation for vswr failed\n" );
+	  stop( _("Plot_Frequency_Data():"
+			"Memory allocation for vswr failed"), ERR_OK );
+	  return;
+	}
 	for(idx = 0; idx < fstep; idx++ )
 	{
 	  zrpro2 = impedance_data.zreal[idx] + calc_data.zo;
@@ -368,48 +346,21 @@ Plot_Frequency_Data( void )
 	  if( vswr[idx] > 10.0 ) vswr[idx] = 10.0;
 	}
 
-	/* Plot net gain if selected */
-	if( isFlagSet(PLOT_NETGAIN) )
-	{
-	  int mgidx, pol;
-	  double max_gain;
-
-	  mem_realloc( (void *)&netgmax,
-		  fstep * sizeof(double), "in plot_freqdata.c" );
-
-	  Zo = calc_data.zo;
-	  for(idx = 0; idx < fstep; idx++ )
-	  {
-		Zr = impedance_data.zreal[idx];
-		Zi = impedance_data.zimag[idx];
-		pol = calc_data.pol_type;
-		mgidx = rad_pattern[idx].max_gain_idx[pol];
-		/* Max gain for given polarization type */
-		max_gain = rad_pattern[idx].gtot[mgidx] +
-		  10.0 * log10( Polarization_Factor(pol, idx, mgidx) );
-		netgmax[idx] = max_gain + 10*log10(4*Zr*Zo/(pow(Zr+Zo,2)+pow(Zi,2)));
-	  }
-
-	  titles[2] = "Net Gain dbi";
-	  Plot_Graph2( vswr, netgmax, save.freq, fstep,
+	titles[2] = "        ";
+	if( fstep > 1 )
+	  Plot_Graph( vswr, save.freq, fstep,
 		  titles, calc_data.ngraph, ++posn );
-	} /* if( isFlagSet(PLOT_NETGAIN) ) */
-	else
-	{
-	  titles[2] = "        ";
-	  if( fstep > 1 )
-		Plot_Graph( vswr, save.freq, fstep,
-			titles, calc_data.ngraph, ++posn );
-	}
+
+	free_ptr( (void **)&vswr );
   } /* if( isFlagSet(PLOT_VSWR) ) */
 
   /* Plot z-real and z-imag */
   if( isFlagSet(PLOT_ZREAL_ZIMAG) )
   {
 	/* Plotting frame titles */
-	titles[0] = "Z-real";
-	titles[1] = "Impedance vs Frequency";
-	titles[2] = "Z-imag";
+	titles[0] = _("Z-real");
+	titles[1] = _("Impedance vs Frequency");
+	titles[2] = _("Z-imag");
 	if( fstep > 1 )
 	  Plot_Graph2(
 		  impedance_data.zreal, impedance_data.zimag, save.freq,
@@ -421,9 +372,9 @@ Plot_Frequency_Data( void )
   if( isFlagSet(PLOT_ZMAG_ZPHASE) )
   {
 	/* Plotting frame titles */
-	titles[0] = "Z-magn";
-	titles[1] = "Impedance vs Frequency";
-	titles[2] = "Z-phase";
+	titles[0] = _("Z-magn");
+	titles[1] = _("Impedance vs Frequency");
+	titles[2] = _("Z-phase");
 	if( fstep > 1 )
 	  Plot_Graph2( impedance_data.zmagn, impedance_data.zphase,
 		  save.freq, fstep, titles, calc_data.ngraph, ++posn );
@@ -441,6 +392,7 @@ Plot_Frequency_Data( void )
   /* Wait for GTK to complete its tasks */
   while( g_main_context_iteration(NULL, FALSE) );
 
+  cairo_destroy( cr );
 } /* Plot_Frequency_Data() */
 
 /*-----------------------------------------------------------------------*/
@@ -453,8 +405,8 @@ Plot_Frequency_Data( void )
   void
 Display_Frequency_Data( void )
 {
-  int pol, mgidx, fstep;
-  double gmax, vswr, gamma;
+  int pol, fstep;
+  double vswr, gamma;
   double zrpro2, zrmro2, zimag2;
   char txt[11];
 
@@ -473,9 +425,9 @@ Display_Frequency_Data( void )
   if( isFlagSet(ENABLE_RDPAT) )
   {
 	/* Max gain for given polarization type */
-	mgidx = rad_pattern[fstep].max_gain_idx[pol];
-	gmax = rad_pattern[fstep].gtot[mgidx] +
-	  10.0 * log10( Polarization_Factor(pol, fstep, mgidx) );
+	int mgidx = rad_pattern[fstep].max_gain_idx[pol];
+	double gmax = rad_pattern[fstep].gtot[mgidx] +
+	  Polarization_Factor(pol, fstep, mgidx);
 
 	/* Display max gain */
 	snprintf( txt, 6, "%5f", gmax );
@@ -490,11 +442,11 @@ Display_Frequency_Data( void )
 		  freqplots_window, "freqplots_fmhz_entry")), txt );
 
   /* Calculate VSWR */
-  zrpro2 = (double)creall( netcx.zped ) + calc_data.zo;
+  zrpro2 = (double)creal( netcx.zped ) + calc_data.zo;
   zrpro2 *= zrpro2;
-  zrmro2 = (double)creall( netcx.zped ) - calc_data.zo;
+  zrmro2 = (double)creal( netcx.zped ) - calc_data.zo;
   zrmro2 *= zrmro2;
-  zimag2 = (double)cimagl( netcx.zped );
+  zimag2 = (double)cimag( netcx.zped );
   zimag2 *= zimag2;
   gamma = sqrt( (zrmro2 + zimag2)/(zrpro2 + zimag2) );
   vswr = (1+gamma)/(1-gamma);
@@ -507,12 +459,12 @@ Display_Frequency_Data( void )
 		  freqplots_window, "freqplots_vswr_entry")), txt );
 
   /* Display Z real */
-  snprintf( txt, 6, "%5f", (double)creall( netcx.zped ) );
+  snprintf( txt, 6, "%5f", (double)creal( netcx.zped ) );
   gtk_entry_set_text( GTK_ENTRY(lookup_widget(
 		  freqplots_window, "freqplots_zreal_entry")), txt );
 
   /* Display Z imaginary */
-  snprintf( txt, 6, "%5f", (double)cimagl( netcx.zped ) );
+  snprintf( txt, 6, "%5f", (double)cimag( netcx.zped ) );
   gtk_entry_set_text( GTK_ENTRY(lookup_widget(
 		  freqplots_window, "freqplots_zimag_entry")), txt );
 
@@ -535,26 +487,30 @@ Draw_Plotting_Frame(
   PangoLayout *layout;
   int width0, width1, width2, height; /* Layout size */
 
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( freqplots_pixmap );
+
   /* Draw titles (left scale, center and right scale) */
-  Set_GC_Attributes( plot_gc, MAGENTA, 0, freqplots_drawingarea );
+  cairo_set_source_rgb( cr, MAGENTA );
   layout = gtk_widget_create_pango_layout(
 	  freqplots_drawingarea, title[0] );
   pango_layout_get_pixel_size( layout, &width0, &height);
-  gdk_draw_layout( freqplots_pixmap,
-	  plot_gc, rect->x, rect->y, layout );
+  cairo_move_to( cr, rect->x, rect->y );
+  pango_cairo_show_layout( cr, layout );
 
-  Set_GC_Attributes( plot_gc, CYAN, 0, freqplots_drawingarea );
+  cairo_set_source_rgb( cr, CYAN );
   pango_layout_set_text( layout, title[2], -1 );
   pango_layout_get_pixel_size( layout, &width2, &height);
   xpw = rect->x + rect->width - width2;
-  gdk_draw_layout( freqplots_pixmap, plot_gc, xpw, rect->y, layout );
+  cairo_move_to( cr, xpw, rect->y );
+  pango_cairo_show_layout( cr, layout );
 
-  Set_GC_Attributes( plot_gc, YELLOW, 0, freqplots_drawingarea );
+  cairo_set_source_rgb( cr, YELLOW );
   pango_layout_set_text( layout, title[1], -1 );
   pango_layout_get_pixel_size( layout, &width1, &height);
   xpw = rect->x + width0/2 + (rect->width-width1-width2)/2;
-  gdk_draw_layout( freqplots_pixmap,
-	  plot_gc, xpw, rect->y, layout );
+  cairo_move_to( cr, xpw, rect->y );
+  pango_cairo_show_layout( cr, layout );
 
   /* Move to plot box and divisions */
   rect->y += height;
@@ -562,16 +518,12 @@ Draw_Plotting_Frame(
   yph = rect->y + rect->height;
 
   /* Draw vertical divisions */
-  Set_GC_Attributes( plot_gc, GREY, 0, freqplots_drawingarea );
+  cairo_set_source_rgb( cr, GREY );
   nvert--;
   for( idx = 1; idx <= nvert; idx++ )
   {
 	xps = rect->x + (idx * rect->width) / nvert;
-	gdk_draw_line(
-		freqplots_pixmap,
-		plot_gc,
-		xps, rect->y,
-		xps, yph );
+	Cairo_Draw_Line( cr, xps, rect->y, xps, yph );
   }
 
   /* Draw horizontal divisions */
@@ -579,19 +531,13 @@ Draw_Plotting_Frame(
   for( idx = 1; idx <= nhor; idx++ )
   {
 	yps = rect->y + (idx * rect->height) / nhor;
-	gdk_draw_line(
-		freqplots_pixmap,
-		plot_gc,
-		rect->x, yps,
-		xpw, yps );
+	Cairo_Draw_Line( cr, rect->x, yps, xpw, yps );
   }
 
   /* Draw outer box */
-  gdk_draw_rectangle(
-	  freqplots_pixmap,
-	  white_gc, FALSE,
-	  rect->x, rect->y,
-	  rect->width, rect->height );
+  cairo_rectangle(
+	  cr, rect->x, rect->y, rect->width, rect->height );
+  cairo_stroke( cr );
 
   /* Draw a vertical line to show current freq if it was
    * changed by a user click on the plots drawingarea */
@@ -603,16 +549,12 @@ Draw_Plotting_Frame(
 	  (max_fscale - min_fscale);
 	fr = fr * (double)rect->width + 0.5;
 
-	Set_GC_Attributes( plot_gc, GREEN, 0, freqplots_drawingarea );
-	gdk_draw_line(
-		freqplots_pixmap,
-		plot_gc,
-		rect->x+(int)fr, rect->y,
-		rect->x+(int)fr, yph );
+	cairo_set_source_rgb( cr, GREEN );
+	Cairo_Draw_Line( cr, rect->x+(int)fr, rect->y, rect->x+(int)fr, yph );
   }
 
   g_object_unref( layout );
-
+  cairo_destroy( cr );
 } /* Draw_Plotting_Frame() */
 
 /*-----------------------------------------------------------------------*/
@@ -624,7 +566,7 @@ Draw_Plotting_Frame(
  */
 void
 Plot_Vertical_Scale(
-	GdkGC *gc,
+	double red, double grn, double blu,
 	int x, int y, int height,
 	double max, double min,
 	int nval )
@@ -636,27 +578,36 @@ Plot_Vertical_Scale(
   PangoLayout *layout;
   int pl_width, pl_height; /* Layout size */
 
+  /* Abort if not enough values to plot */
+  if( nval <= 1 ) return;
+
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( freqplots_pixmap );
+  cairo_set_source_rgb( cr, red, grn, blu );
+
   /* Calculate step between scale values */
-  if( nval > 1 )
-	vstep = (max-min) / (double)(nval-1);
+  vstep = (max-min) / (double)(nval-1);
 
   /* Determine format for scale values */
   /* Find order of magnitude of min and max values */
-  if( min != 0 )
-	min_order = (int)log10( abs(min) );
+  if( min != 0.0 )
+  {
+	double mo = log10( fabs(min) );
+	min_order = (int)mo;
+  }
   else
 	min_order = 0;
-  if( max != 0 )
-	max_order = (int)log10( abs(max) );
-  else
-	max_order = 0;
+  if( max != 0.0 )
+  {
+	double mo = log10( fabs(max) );
+	max_order = (int)mo;
+  }
+  else max_order = 0;
 
   /* Use highest order for format */
   order = ( max_order > min_order ? max_order : min_order );
-  if( order > 3 )
-	order = 3;
-  if( order < 0 )
-	order = 0;
+  if( order > 3 ) order = 3;
+  if( order < 0 ) order = 0;
   snprintf( format, 6, "%%6.%df", (3-order) );
 
   /* Create a pango layout */
@@ -670,14 +621,15 @@ Plot_Vertical_Scale(
   for( idx = 0; idx < nval; idx++ )
   {
 	yps = y + (idx * height) / (nval-1);
-	snprintf( value, 16, format, max );
+	snprintf( value, 16, (const char *)format, max );
 	pango_layout_set_text( layout, value, -1 );
-	gdk_draw_layout( freqplots_pixmap, gc, x, yps, layout );
+	cairo_move_to( cr, x, yps );
+	pango_cairo_show_layout( cr, layout );
 	max -= vstep;
   }
 
   g_object_unref( layout );
-
+  cairo_destroy( cr );
 } /* Plot_Vertical_Scale() */
 
 /*-----------------------------------------------------------------------*/
@@ -689,40 +641,34 @@ Plot_Vertical_Scale(
  */
 void
 Plot_Horizontal_Scale(
-	GdkGC *gc,
+	double red, double grn, double blu,
 	int x, int y, int width,
 	double max, double min,
 	int nval )
 {
-  int idx, xps;
-  int min_order, max_order, order;
-  double vstep = 1.0;
+  int idx, xps, order;
+  double hstep = 1.0;
   char value[16], format[6];
   PangoLayout *layout;
   int pl_width, pl_height; /* Layout size */
 
+  /* Abort if not enough values to plot */
+  if( nval <= 1 ) return;
+
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( freqplots_pixmap );
+  cairo_set_source_rgb( cr, red, grn, blu );
+
   /* Calculate step between scale values */
-  if( nval > 1 )
-	vstep = (max-min) / (nval-1);
+  hstep = (max-min) / (nval-1);
 
   /* Determine format for scale values */
-  /* Find order of magnitude of min and max values */
-  if( min != 0 )
-	min_order = (int)log10( abs(min) );
-  else
-	min_order = 0;
-  if( max != 0 )
-	max_order = (int)log10( abs(max) );
-  else
-	max_order = 0;
-
-  /* Use highest order for format */
-  order = ( max_order > min_order ? max_order : min_order );
-  if( order > 3 )
-	order = 3;
-  if( order < 0 )
-	order = 0;
-  snprintf( format, 6, "%%6.%df", (3-order) );
+  /* Use order of horizontal step to determine format of print */
+  double ord = log10( fabs(hstep + 0.0000001) );
+  order = (int)ord;
+  if( order > 0 )  order = 0;
+  if( order < -9 ) order = -9;
+  snprintf( format, 6, "%%6.%df", 1-order );
 
   /* Create a pango layout */
   layout = gtk_widget_create_pango_layout(
@@ -735,14 +681,15 @@ Plot_Horizontal_Scale(
   for( idx = 0; idx < nval; idx++ )
   {
 	xps = x + (idx * width) / (nval-1);
-	snprintf( value, 16, format, min );
+	snprintf( value, sizeof(value), (const char *)format, min );
 	pango_layout_set_text( layout, value, -1 );
-	gdk_draw_layout( freqplots_pixmap, gc, xps, y, layout );
-	min += vstep;
+	cairo_move_to( cr, xps, y );
+	pango_cairo_show_layout( cr, layout );
+	min += hstep;
   }
 
   g_object_unref( layout );
-
+  cairo_destroy( cr );
 } /* Plot_Horizontal_Scale() */
 
 /*-----------------------------------------------------------------------*/
@@ -753,7 +700,7 @@ Plot_Horizontal_Scale(
  */
 void
 Draw_Graph(
-	GdkGC *gc,
+	double red, double grn, double blu,
 	GdkRectangle *rect,
 	double *a, double *b,
 	double amax, double amin,
@@ -762,13 +709,28 @@ Draw_Graph(
 {
   double ra, rb;
   int idx;
-  GdkPoint points[nval], polygn[4];
+  GdkPoint *points = NULL, polygn[4];
+
+  /* Cairo context */
+  cairo_t *cr = gdk_cairo_create( freqplots_pixmap );
+  cairo_set_source_rgb( cr, red, grn, blu );
 
   /* Range of values to plot */
   ra = amax - amin;
   rb = bmax - bmin;
 
   /* Calculate points to plot */
+  mem_alloc( (void **)&points,
+	  (size_t)calc_data.nfrq * sizeof(GdkPoint),
+	  "in Plot_Frequency_Data()" );
+  if( points == NULL )
+  {
+	fprintf( stderr, "xnec2c: Draw_Graph():"
+		"memory allocation for points failed\n" );
+	stop( _("Draw_Graph():"
+		  "Memory allocation for points failed"), ERR_OK );
+	return;
+  }
   for( idx = 0; idx < nval; idx++ )
   {
 	points[idx].x = rect->x + (int)( (double)rect->width  *
@@ -778,22 +740,28 @@ Draw_Graph(
 
 	/* Plot a small rectangle (left scale) or polygon (right scale) at point */
 	if( side == LEFT )
-	  gdk_draw_rectangle(
-		  freqplots_pixmap, gc, FALSE,
-		  points[idx].x-3, points[idx].y-3, 6, 6 );
+	{
+	  cairo_rectangle( cr,
+		  (double)(points[idx].x-3), (double)(points[idx].y-3),
+		  6.0, 6.0 );
+	  cairo_fill( cr );
+	}
 	else
 	{
 	  polygn[0].x = points[idx].x-4; polygn[0].y = points[idx].y;
 	  polygn[1].x = points[idx].x;   polygn[1].y = points[idx].y+4;
 	  polygn[2].x = points[idx].x+4; polygn[2].y = points[idx].y;
 	  polygn[3].x = points[idx].x;   polygn[3].y = points[idx].y-4;
-	  gdk_draw_polygon( freqplots_pixmap, gc, FALSE, polygn, 4 );
+	  Cairo_Draw_Polygon( cr, polygn, 4 );
+	  cairo_fill( cr );
 	}
   }
 
   /* Draw the graph */
-  gdk_draw_lines( freqplots_pixmap, gc, points, nval );
+  Cairo_Draw_Lines( cr, points, nval );
 
+  free_ptr( (void **)&points );
+  cairo_destroy( cr );
 } /* Draw_Graph() */
 
 /*-----------------------------------------------------------------------*/
@@ -826,7 +794,7 @@ Fit_to_Scale( double *max, double *min, int *nval )
   /* Acceptable scale values (10/10, 10/5, 10/4, 10/2) */
   /* Intermediate values are geometric mean of pairs */
   double scale_val[] =
-  {1.0, 1.4142, 2.0, 2.2360, 2.5, 3.5355, 5.0, 7.0710, 10.0, 14.142};
+  { 1.0, 1.4142, 2.0, 2.2360, 2.5, 3.5355, 5.0, 7.0710, 10.0, 14.142 };
   double subdiv_val, subdiv_order;
   int idx;
 
@@ -838,17 +806,16 @@ Fit_to_Scale( double *max, double *min, int *nval )
 	  *max =  1.0;
 	  *min = -1.0;
 	}
+	else if( *max > 0.0 )
+	{
+	  *max *= 1.5;
+	  *min /= 2.0;
+	}
 	else
-	  if( *max > 0.0 )
-	  {
-		*max *= 1.5;
-		*min /= 2.0;
-	  }
-	  else
-	  {
-		*max /= 2.0;
-		*min *= 1.5;
-	  }
+	{
+	  *max /= 2.0;
+	  *min *= 1.5;
+	}
   }
 
   /* Find subdivision's lower order of magnitude */
@@ -863,11 +830,12 @@ Fit_to_Scale( double *max, double *min, int *nval )
   subdiv_val /= subdiv_order;
 
   /* Find nearest prefered subdiv value */
-  idx = 1;
-  while( (scale_val[idx] < subdiv_val) && (idx < 10) )
-	idx += 2;
+  for( idx = 1; idx <= 9; idx += 2 )
+	if( scale_val[idx] >= subdiv_val )
+	  break;
 
   /* Scale prefered subdiv value */
+  if( idx > 9 ) idx = 9;
   subdiv_val = scale_val[idx-1] * subdiv_order;
 
   /* Recalculate new max and min value */
@@ -906,17 +874,16 @@ Fit_to_Scale2( double *max1, double *min1,
 	  *max1 =  1.0;
 	  *min1 = -1.0;
 	}
+	else if( *max1 > 0.0 )
+	{
+	  *max1 *= 1.5;
+	  *min1 /= 2.0;
+	}
 	else
-	  if( *max1 > 0.0 )
-	  {
-		*max1 *= 1.5;
-		*min1 /= 2.0;
-	  }
-	  else
-	  {
-		*max1 /= 2.0;
-		*min1 *= 1.5;
-	  }
+	{
+	  *max1 /= 2.0;
+	  *min1 *= 1.5;
+	}
   }
 
   if( *max2 == *min2 )
@@ -926,17 +893,16 @@ Fit_to_Scale2( double *max1, double *min1,
 	  *max2 =  1.0;
 	  *min2 = -1.0;
 	}
+	else if( *max2 > 0.0 )
+	{
+	  *max2 *= 1.5;
+	  *min2 /= 2.0;
+	}
 	else
-	  if( *max2 > 0.0 )
-	  {
-		*max2 *= 1.5;
-		*min2 /= 2.0;
-	  }
-	  else
-	  {
-		*max2 /= 2.0;
-		*min2 *= 1.5;
-	  }
+	{
+	  *max2 /= 2.0;
+	  *min2 *= 1.5;
+	}
   }
 
   /* For each scale */
@@ -1013,7 +979,7 @@ Fit_to_Scale2( double *max1, double *min1,
 	  New_Max_Min( &max_2, &min_2, subdiv_val2, &nval2 );
 
 	  /* This is a lucky case */
-	  if( (nval1 == nval2) )
+	  if( nval1 == nval2 )
 	  {
 		*max1 = max_1; *min1 = min_1;
 		*max2 = max_2; *min2 = min_2;
@@ -1070,10 +1036,13 @@ Fit_to_Scale2( double *max1, double *min1,
 New_Max_Min( double *max, double *min, double sval, int *nval )
 {
   int ix;
+  double i;
 
-  ix = (int) ceil(*max / sval - 0.000001);
+  i = ceil(*max / sval - 0.000001);
+  ix = (int)i;
   *max = (double)ix * sval;
-  ix = (int)floor(*min / sval + 0.000001);
+  i = floor(*min / sval + 0.000001);
+  ix = (int)i;
   *min = (double)ix * sval;
   *nval = (int)((*max - *min) / sval + 0.5) + 1;
 
@@ -1116,15 +1085,13 @@ Plot_Graph2(
   /* Plot box rectangle */
   Set_Rectangle(
 	  &plot_rect,
-	  layout_width + 4, plot_posn+2,
+	  layout_width+4, plot_posn+2,
 	  freqplots_pixmap_width-8 - 2*layout_width,
 	  plot_height-8 - 2*layout_height );
 
   /*** Draw horizontal (freq) scale ***/
-  Set_GC_Attributes( plot_gc, YELLOW, 0,
-	  freqplots_drawingarea );
   Plot_Horizontal_Scale(
-	  plot_gc,
+	  YELLOW,
 	  layout_width+2,
 	  plot_posn+plot_height-2 - layout_height,
 	  plot_rect.width,
@@ -1156,17 +1123,15 @@ Plot_Graph2(
   Fit_to_Scale2( &max_fa, &min_fa, &max_fb, &min_fb, &nval_ab );
 
   /* Draw left scale */
-  Set_GC_Attributes( plot_gc, MAGENTA, 0, freqplots_drawingarea );
   Plot_Vertical_Scale(
-	  plot_gc,
+	  MAGENTA,
 	  2, plot_posn+2,
 	  plot_rect.height,
 	  max_fa, min_fa, nval_ab );
 
   /* Draw right scale */
-  Set_GC_Attributes( plot_gc, CYAN, 0, freqplots_drawingarea );
   Plot_Vertical_Scale(
-	  plot_gc,
+	  CYAN,
 	  freqplots_pixmap_width-2 - layout_width, plot_posn+2,
 	  plot_rect.height,
 	  max_fb, min_fb, nval_ab );
@@ -1175,18 +1140,16 @@ Plot_Graph2(
   Draw_Plotting_Frame( titles, &plot_rect, nval_ab, nval_fscale );
 
   /* Draw graph */
-  Set_GC_Attributes( plot_gc, MAGENTA, 0, freqplots_drawingarea );
   Draw_Graph(
-	  plot_gc, &plot_rect,
-	  fa, fc,
+	  MAGENTA,
+	  &plot_rect, fa, fc,
 	  max_fa, min_fa,
 	  max_fscale, min_fscale,
 	  nc, LEFT );
 
   /* Draw graph */
-  Set_GC_Attributes( plot_gc, CYAN, 0, freqplots_drawingarea );
   Draw_Graph(
-	  plot_gc, &plot_rect,
+	  CYAN, &plot_rect,
 	  fb, fc,
 	  max_fb, min_fb,
 	  max_fscale, min_fscale,
@@ -1237,9 +1200,8 @@ Plot_Graph(
 	  plot_height-8 - 2*layout_height );
 
   /*** Draw horizontal (freq) scale ***/
-  Set_GC_Attributes( plot_gc, YELLOW, 0, freqplots_drawingarea );
   Plot_Horizontal_Scale(
-	  plot_gc,
+	  YELLOW,
 	  layout_width+2,
 	  plot_posn+plot_height-2 - layout_height,
 	  plot_rect.width,
@@ -1261,9 +1223,8 @@ Plot_Graph(
   Fit_to_Scale( &max_fa, &min_fa, &nval_fa );
 
   /* Draw left scale */
-  Set_GC_Attributes( plot_gc, MAGENTA, 0, freqplots_drawingarea );
   Plot_Vertical_Scale(
-	  plot_gc,
+	  MAGENTA,
 	  2, plot_posn+2,
 	  plot_rect.height,
 	  max_fa, min_fa, nval_fa );
@@ -1272,10 +1233,9 @@ Plot_Graph(
   Draw_Plotting_Frame( titles, &plot_rect, nval_fa, nval_fscale );
 
   /* Draw graph */
-  Set_GC_Attributes( plot_gc, MAGENTA, 0, freqplots_drawingarea );
   Draw_Graph(
-	  plot_gc, &plot_rect,
-	  fa, fb,
+	  MAGENTA,
+	  &plot_rect, fa, fb,
 	  max_fa, min_fa,
 	  max_fscale, min_fscale,
 	  nb, LEFT );
@@ -1311,9 +1271,10 @@ Plots_Window_Killed(void)
  * Sets the current freq after click by user on plots drawingarea
  */
   void
-Set_Frequency_On_Click( GtkWidget *widget, GdkEventButton *event )
+Set_Frequency_On_Click( GdkEventButton *event )
 {
-  gdouble fmhz = 0.0, x, w;
+  gdouble fmhz = 0.0;
+  gdouble x, w;
   int idx;
 
 
@@ -1325,54 +1286,57 @@ Set_Frequency_On_Click( GtkWidget *widget, GdkEventButton *event )
 
   /* 'x' posn of click refered to plot bounding rectangle's 'x' */
   x = event->x - (double)plot_rect.x;
-  if( x < 0.0 )
-	x = 0.0;
-  else
-	if( x > w )
-	  x = w;
+  if( x < 0.0 ) x = 0.0;
+  else if( x > w ) x = w;
 
   /* Set freq corresponding to click 'x', to freq spinbuttons */
   idx = calc_data.lastf;
   switch( event->button )
   {
-	case 1:
-	  /* Calculate frequency corresponding to mouse position in plot */
-	  fmhz = max_fscale - min_fscale;
-	  fmhz = min_fscale + fmhz * x/w;
+	case 1: /* Calculate frequency corresponding to mouse position in plot */
 	  /* Enable drawing of freq line */
 	  SetFlag( PLOT_FREQ_LINE );
+
+	  fmhz = max_fscale - min_fscale;
+	  fmhz = min_fscale + fmhz * x/w;
 	  break;
 
-	case 2:
-	  /* Disable drawing of freq line */
+	case 2: /* Disable drawing of freq line */
 	  ClearFlag( PLOT_FREQ_LINE );
 	  Plot_Frequency_Data();
 	  return;
 
-	case 3:
-	  /* Calculate frequency corresponding to mouse position in plot */
-	  fmhz = max_fscale - min_fscale;
-	  fmhz = min_fscale + fmhz * x/w;
-	  /* Find nearest freq step */
-	  idx = (int)(
-		  (double)idx*(fmhz-save.freq[0]) /
-		  (save.freq[idx]-save.freq[0])+0.5);
-	  if( idx > calc_data.lastf )
-		idx = calc_data.lastf;
-	  else
-		if( idx < 0 )
-		  idx = 0;
-	  fmhz = save.freq[idx];
+	case 3: /* Calculate frequency corresponding to mouse position in plot */
 	  /* Enable drawing of freq line */
 	  SetFlag( PLOT_FREQ_LINE );
 
+	  fmhz = max_fscale - min_fscale;
+	  fmhz = min_fscale + fmhz * x/w;
+
+	  /* Find nearest freq step */
+	  idx = (int)( (double)idx * (fmhz - save.freq[0]) /
+		  (save.freq[idx] - save.freq[0]) + 0.5 );
+
+	  if( idx > calc_data.lastf )
+		idx = calc_data.lastf;
+	  else if( idx < 0 ) idx = 0;
+
+	  fmhz = save.freq[idx];
+
   } /* switch( event->button ) */
 
-  /* Set frequency spinbuttons */
-  gtk_spin_button_set_value( mainwin_frequency, fmhz );
-  if( isFlagSet(DRAW_ENABLED) )
-	gtk_spin_button_set_value( rdpattern_frequency, fmhz );
-  calc_data.fmhz = (long double)fmhz;
+  /* Set frequency spinbuttons on new freq */
+  if( fmhz != gtk_spin_button_get_value(mainwin_frequency) )
+  {
+	gtk_spin_button_set_value( mainwin_frequency, fmhz );
+	if( isFlagSet(DRAW_ENABLED) )
+	  gtk_spin_button_set_value( rdpattern_frequency, fmhz );
+  }
+  else /* Replot data */
+  {
+	calc_data.fmhz = (double)fmhz;
+	g_idle_add( Redo_Currents, NULL );
+  }
 
 } /* Set_Freq_On_Click() */
 
