@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,71 +41,36 @@
 
  ***********************************************************************/
 
-#include "xnec2c.h"
-
-/* common  /crnt/ */
-extern crnt_t crnt;
-
-/* common  /data/ */
-extern data_t data;
-
-/* Data need for command execution */
-extern calc_data_t calc_data;
-
-/* common  /gnd/ */
-extern gnd_t gnd;
-
-/* common  /gwav/ */
-gwav_t gwav;
-
-/* common  /fpat/ */
-fpat_t fpat;
-
-/* common  /save/ */
-extern save_t save;
+#include "radiation.h"
+#include "shared.h"
 
 /* Radiation pattern data */
-extern rad_pattern_t *rad_pattern;
-
-/* pointer to input file */
-extern FILE *input_fp;
-
-/* Widgets needed for redraws */
-extern GtkWidget
-  *rdpattern_window,
-  *rdpattern_drawingarea;
-extern int rdpattern_pixmap_width, rdpattern_pixmap_height;
-extern GtkWidget *freqplots_drawingarea;
-extern int freqplots_pixmap_width, freqplots_pixmap_height;
-extern GtkWidget *structure_drawingarea;
-extern int structure_pixmap_width, structure_pixmap_height;
-
 /*-----------------------------------------------------------------------*/
 
 /* ffld calculates the far zone radiated electric fields, */
 /* the factor exp(j*k*r)/(r/lamda) not included */
-void ffld( long double thet, long double phi,
-	complex long double *eth, complex long double *eph )
+void ffld( double thet, double phi,
+	complex double *eth, complex double *eph )
 {
   int k, i, ip, jump;
-  long double phx, phy, roz, rozs, thx, thy, thz, rox, roy;
-  long double tthet=0.0l, darg=0.0l, omega, el, sill, top, bot, a;
-  long double too, boo, b, c, d, rr, ri, arg, dr, rfl, rrz;
-  complex long double cix=CPLX_00, ciy=CPLX_00, ciz=CPLX_00, ccx=CPLX_00;
-  complex long double ccy=CPLX_00, ccz=CPLX_00, exa, cdp;
-  complex long double zrsin, rrv=CPLX_00, rrh=CPLX_00, rrv1=CPLX_00;
-  complex long double rrh1=CPLX_00, rrv2=CPLX_00, rrh2=CPLX_00;
-  complex long double tix, tiy, tiz, zscrn, ex=CPLX_00;
-  complex long double ey=CPLX_00, ez=CPLX_00, gx, gy, gz;
+  double phx, phy, roz, rozs, thx, thy, thz, rox, roy;
+  double tthet=0.0, darg=0.0, omega, el, sill, top, bot, a;
+  double too, boo, b, c, d, rr, ri, arg, dr, rfl, rrz;
+  complex double cix=CPLX_00, ciy=CPLX_00, ciz=CPLX_00, ccx=CPLX_00;
+  complex double ccy=CPLX_00, ccz=CPLX_00, exa, cdp;
+  complex double zrsin, rrv=CPLX_00, rrh=CPLX_00, rrv1=CPLX_00;
+  complex double rrh1=CPLX_00, rrv2=CPLX_00, rrh2=CPLX_00;
+  complex double tix, tiy, tiz, zscrn, ex=CPLX_00;
+  complex double ey=CPLX_00, ez=CPLX_00, gx, gy, gz;
 
-  phx=- sinl( phi);
-  phy= cosl( phi);
-  roz= cosl( thet);
+  phx= -sin( phi);
+  phy= cos( phi);
+  roz= cos( thet);
   rozs= roz;
   thx= roz* phy;
-  thy=- roz* phx;
-  thz=- sinl( thet);
-  rox=- thz* phy;
+  thy= -roz* phx;
+  thz= -sin( thet);
+  rox= -thz* phy;
   roy= thz* phx;
 
   jump = FALSE;
@@ -127,29 +91,28 @@ void ffld( long double thet, long double phi,
 		else
 		{
 		  /* for infinite planar ground */
-		  zrsin= csqrtl(1.0l- gnd.zrati* gnd.zrati* thz* thz);
+		  zrsin= csqrt(1.0- gnd.zrati* gnd.zrati* thz* thz);
 		  rrv=-( roz- gnd.zrati* zrsin)/( roz+ gnd.zrati* zrsin);
 		  rrh=( gnd.zrati* roz- zrsin)/( gnd.zrati* roz+ zrsin);
-
 		} /* if( gnd.iperf == 1) */
 
-		/* for the cliff problem, two reflction coefficients calculated */
+		/* for the cliff problem, two reflection coefficients calculated */
 		if( gnd.ifar > 1)
 		{
 		  rrv1= rrv;
 		  rrh1= rrh;
-		  tthet= tanl( thet);
+		  tthet= tan( thet);
 
 		  if( gnd.ifar != 4)
 		  {
-			zrsin= csqrtl(1.0l- gnd.zrati2* gnd.zrati2* thz* thz);
+			zrsin= csqrt(1.0- gnd.zrati2* gnd.zrati2* thz* thz);
 			rrv2=-( roz- gnd.zrati2* zrsin)/( roz+ gnd.zrati2* zrsin);
 			rrh2=( gnd.zrati2* roz- zrsin)/( gnd.zrati2* roz+ zrsin);
-			darg=- TP*2.0l* gnd.ch* roz;
+			darg= -TP*2.0* gnd.ch* roz;
 		  }
 		} /* if( gnd.ifar > 1) */
 
-		roz=- roz;
+		roz= -roz;
 		ccx= cix;
 		ccy= ciy;
 		ccz= ciz;
@@ -163,27 +126,26 @@ void ffld( long double thet, long double phi,
 	  /* loop over structure segments */
 	  for( i = 0; i < data.n; i++ )
 	  {
-		omega=-( rox* data.cab[i] +
-			roy* data.sab[i]+ roz* data.salp[i]);
+		omega=-( rox* data.cab[i] +	roy* data.sab[i]+ roz* data.salp[i]);
 		el= PI* data.si[i];
 		sill= omega* el;
 		top= el+ sill;
 		bot= el- sill;
 
-		if( fabsl( omega) >= 1.0e-7l)
-		  a=2.0l* sinl( sill)/ omega;
+		if( fabs( omega) >= 1.0e-7)
+		  a=2.0* sin( sill)/ omega;
 		else
-		  a=(2.0l- omega* omega* el* el/3.0l)* el;
+		  a=(2.0- omega* omega* el* el/3.0)* el;
 
-		if( fabsl( top) >= 1.0e-7l)
-		  too= sinl( top)/ top;
+		if( fabs( top) >= 1.0e-7)
+		  too= sin( top)/ top;
 		else
-		  too=1.0l- top* top/6.0l;
+		  too=1.0- top* top/6.0;
 
-		if( fabsl( bot) >= 1.0e-7l)
-		  boo= sinl( bot)/ bot;
+		if( fabs( bot) >= 1.0e-7)
+		  boo= sin( bot)/ bot;
 		else
-		  boo=1.0l- bot* bot/6.0l;
+		  boo=1.0- bot* bot/6.0;
 
 		b= el*( boo- too);
 		c= el*( boo+ too);
@@ -194,7 +156,7 @@ void ffld( long double thet, long double phi,
 		if( (k != 1) || (gnd.ifar < 2) )
 		{
 		  /* summation for far field integral */
-		  exa= cmplx( cosl( arg), sinl( arg))* cmplx( rr, ri);
+		  exa= cmplx( cos( arg), sin( arg))* cmplx( rr, ri);
 		  cix= cix+ exa* data.cab[i];
 		  ciy= ciy+ exa* data.sab[i];
 		  ciz= ciz+ exa* data.salp[i];
@@ -206,11 +168,10 @@ void ffld( long double thet, long double phi,
 
 		/* specular point distance */
 		dr= data.z[i]* tthet;
-
 		d= dr* phy+ data.x[i];
 		if( gnd.ifar == 2)
 		{
-		  if(( gnd.cl- d) > 0.0l)
+		  if(( gnd.cl- d) > 0.0)
 		  {
 			rrv= rrv1;
 			rrh= rrh1;
@@ -224,10 +185,10 @@ void ffld( long double thet, long double phi,
 		} /* if( gnd.ifar == 2) */
 		else
 		{
-		  d= sqrtl( d*d + (data.y[i]-dr*phx)*(data.y[i]-dr*phx) );
+		  d= sqrt( d*d + (data.y[i]-dr*phx)*(data.y[i]-dr*phx) );
 		  if( gnd.ifar == 3)
 		  {
-			if(( gnd.cl- d) > 0.0l)
+			if(( gnd.cl- d) > 0.0)
 			{
 			  rrv= rrv1;
 			  rrh= rrh1;
@@ -241,16 +202,16 @@ void ffld( long double thet, long double phi,
 		  } /* if( gnd.ifar == 3) */
 		  else
 		  {
-			if(( gnd.scrwl- d) >= 0.0l)
+			if(( gnd.scrwl- d) >= 0.0)
 			{
 			  /* radial wire ground screen reflection coefficient */
 			  d= d+ gnd.t2;
-			  zscrn= gnd.t1* d* logl( d/ gnd.t2);
+			  zscrn= gnd.t1* d* log( d/ gnd.t2);
 			  zscrn=( zscrn* gnd.zrati)/( ETA* gnd.zrati+ zscrn);
-			  zrsin= csqrtl(1.0l- zscrn* zscrn* thz* thz);
+			  zrsin= csqrt(1.0- zscrn* zscrn* thz* thz);
 			  rrv=( roz+ zscrn* zrsin)/(- roz+ zscrn* zrsin);
 			  rrh=( zscrn* roz+ zrsin)/( zscrn* roz- zrsin);
-			} /* if(( gnd.scrwl- d) < 0.0l) */
+			} /* if(( gnd.scrwl- d) < 0.0) */
 			else
 			{
 			  if( gnd.ifar == 4)
@@ -263,7 +224,7 @@ void ffld( long double thet, long double phi,
 				if( gnd.ifar == 5)
 				  d= dr* phy+ data.x[i];
 
-				if(( gnd.cl- d) > 0.0l)
+				if(( gnd.cl- d) > 0.0)
 				{
 				  rrv= rrv1;
 				  rrh= rrh1;
@@ -273,11 +234,11 @@ void ffld( long double thet, long double phi,
 				  rrv= rrv2;
 				  rrh= rrh2;
 				  arg= arg+ darg;
-				} /* if(( gnd.cl- d) > 0.0l) */
+				} /* if(( gnd.cl- d) > 0.0) */
 
 			  } /* if( gnd.ifar == 4) */
 
-			} /* if(( gnd.scrwl- d) < 0.0l) */
+			} /* if(( gnd.scrwl- d) < 0.0) */
 
 		  } /* if( gnd.ifar == 3) */
 
@@ -285,7 +246,7 @@ void ffld( long double thet, long double phi,
 
 		/* contribution of each image segment modified by */
 		/* reflection coef, for cliff and ground screen problems */
-		exa= cmplx( cosl( arg), sinl( arg))* cmplx( rr, ri);
+		exa= cmplx( cos( arg), sin( arg))* cmplx( rr, ri);
 		tix= exa* data.cab[i];
 		tiy= exa* data.sab[i];
 		tiz= exa* data.salp[i];
@@ -321,8 +282,8 @@ void ffld( long double thet, long double phi,
 	  jump = TRUE;
 	else
 	{
-	  *eth=( cix* thx+ ciy* thy+ ciz* thz)* CONST3;
-	  *eph=( cix* phx+ ciy* phy)* CONST3;
+	  *eth = ( cix * thx + ciy * thy + ciz * thz ) * CONST3;
+	  *eph = ( cix * phx + ciy * phy ) * CONST3;
 	  return;
 	}
 
@@ -337,10 +298,10 @@ void ffld( long double thet, long double phi,
 
   /* electric field components */
   roz= rozs;
-  rfl=-1.0l;
+  rfl=-1.0;
   for( ip = 0; ip < gnd.ksymp; ip++ )
   {
-	rfl=- rfl;
+	rfl= -rfl;
 	rrz= roz* rfl;
 	fflds( rox, roy, rrz, &crnt.cur[data.n], &gx, &gy, &gz);
 
@@ -354,13 +315,13 @@ void ffld( long double thet, long double phi,
 
 	if( gnd.iperf == 1)
 	{
-	  gx=- gx;
-	  gy=- gy;
-	  gz=- gz;
+	  gx= -gx;
+	  gy= -gy;
+	  gz= -gz;
 	}
 	else
 	{
-	  rrv= csqrtl(1.0l- gnd.zrati* gnd.zrati* thz* thz);
+	  rrv= csqrt(1.0- gnd.zrati* gnd.zrati* thz* thz);
 	  rrh= gnd.zrati* roz;
 	  rrh=( rrh- rrv)/( rrh+ rrv);
 	  rrv= gnd.zrati* rrv;
@@ -378,11 +339,12 @@ void ffld( long double thet, long double phi,
 
   } /* for( ip = 0; ip < gnd.ksymp; ip++ ) */
 
-  ex= ex+ cix* CONST3;
-  ey= ey+ ciy* CONST3;
-  ez= ez+ ciz* CONST3;
-  *eth= ex* thx+ ey* thy+ ez* thz;
-  *eph= ex* phx+ ey* phy;
+  ex = ex + cix * CONST3;
+  ey = ey + ciy * CONST3;
+  ez = ez + ciz * CONST3;
+  
+  *eth = ex * thx + ey * thy + ez * thz;
+  *eph = ex * phx + ey * phy;
 
   return;
 }
@@ -391,14 +353,14 @@ void ffld( long double thet, long double phi,
 
 /* calculates the xyz components of the electric */
 /* field due to surface currents */
-void fflds( long double rox, long double roy, long double roz,
-	complex long double *scur, complex long double *ex,
-	complex long double *ey, complex long double *ez )
+void fflds( double rox, double roy, double roz,
+	complex double *scur, complex double *ex,
+	complex double *ey, complex double *ez )
 {
-  long double *xs, *ys, *zs, *s;
+  double *xs, *ys, *zs, *s;
   int j, i, k;
-  long double arg;
-  complex long double ct;
+  double arg;
+  complex double ct;
 
   xs = data.px;
   ys = data.py;
@@ -414,7 +376,7 @@ void fflds( long double rox, long double roy, long double roz,
   {
 	i++;
 	arg= TP*( rox* xs[i]+ roy* ys[i]+ roz* zs[i]);
-	ct= cmplx( cosl( arg)* s[i], sinl( arg)* s[i]);
+	ct= cmplx( cos( arg)* s[i], sin( arg)* s[i]);
 	k=3*j;
 	*ex += scur[k  ]* ct;
 	*ey += scur[k+1]* ct;
@@ -432,45 +394,45 @@ void fflds( long double rox, long double roy, long double roz,
 /*-----------------------------------------------------------------------*/
 
 /* gfld computes the radiated field including ground wave. */
-void gfld( long double rho, long double phi, long double rz,
-	complex long double *eth, complex long double *epi,
-	complex long double *erd, complex long double ux, int ksymp )
+void gfld( double rho, double phi, double rz,
+	complex double *eth, complex double *epi,
+	complex double *erd, complex double ux, int ksymp )
 {
   int i, k;
-  long double b, r, thet, arg, phx, phy, rx, ry;
-  long double dx, dy, dz, rix, riy, rhs, rhp;
-  long double rhx, rhy, calp, cbet, sbet, cph;
-  long double sph, el, rfl, riz, thx, thy, thz;
-  long double rxyz, rnx, rny, rnz, omega, sill;
-  long double top, bot, a, too, boo, c, rr, ri;
-  complex long double cix, ciy, ciz, exa, erv;
-  complex long double ezv, erh, eph, ezh, ex, ey;
+  double b, r, thet, arg, phx, phy, rx, ry;
+  double dx, dy, dz, rix, riy, rhs, rhp;
+  double rhx, rhy, calp, cbet, sbet, cph;
+  double sph, el, rfl, riz, thx, thy, thz;
+  double rxyz, rnx, rny, rnz, omega, sill;
+  double top, bot, a, too, boo, c, rr, ri;
+  complex double cix, ciy, ciz, exa, erv;
+  complex double ezv, erh, eph, ezh, ex, ey;
 
-  r= sqrtl( rho*rho+ rz*rz );
-  if( (ksymp == 1) || (cabs(ux) > .5l) || (r > 1.0e5l) )
+  r= sqrt( rho*rho+ rz*rz );
+  if( (ksymp == 1) || (cabs(ux) > .5) || (r > 1.0e5) )
   {
 	/* computation of space wave only */
-	if( rz >= 1.0e-20l)
-	  thet= atanl( rho/ rz);
+	if( rz >= 1.0e-20)
+	  thet= atan( rho/ rz);
 	else
-	  thet= PI*.5l;
+	  thet= PI*.5;
 
 	ffld( thet, phi, eth, epi);
-	arg=- TP* r;
-	exa= cmplx( cosl( arg), sinl( arg))/ r;
+	arg= -TP* r;
+	exa= cmplx( cos( arg), sin( arg))/ r;
 	*eth= *eth* exa;
 	*epi= *epi* exa;
 	*erd=CPLX_00;
 	return;
-  } /* if( (ksymp == 1) && (cabs(ux) > .5l) && (r > 1.0e5l) ) */
+  } /* if( (ksymp == 1) && (cabs(ux) > .5) && (r > 1.0e5) ) */
 
   /* computation of space and ground waves. */
   gwav.u= ux;
   gwav.u2= gwav.u* gwav.u;
-  phx=- sinl( phi);
-  phy= cosl( phi);
+  phx= -sin( phi);
+  phy= cos( phi);
   rx= rho* phy;
-  ry=- rho* phx;
+  ry= -rho* phx;
   cix=CPLX_00;
   ciy=CPLX_00;
   ciz=CPLX_00;
@@ -484,23 +446,23 @@ void gfld( long double rho, long double phi, long double rz,
 	rix= rx- data.x[i];
 	riy= ry- data.y[i];
 	rhs= rix* rix+ riy* riy;
-	rhp= sqrtl( rhs);
+	rhp= sqrt( rhs);
 
-	if( rhp >= 1.0e-6l)
+	if( rhp >= 1.0e-6)
 	{
 	  rhx= rix/ rhp;
 	  rhy= riy/ rhp;
 	}
 	else
 	{
-	  rhx=1.0l;
-	  rhy=0.0l;
+	  rhx=1.0;
+	  rhy=0.0;
 	}
 
-	calp=1.0l- dz* dz;
-	if( calp >= 1.0e-6l)
+	calp=1.0- dz* dz;
+	if( calp >= 1.0e-6)
 	{
-	  calp= sqrtl( calp);
+	  calp= sqrt( calp);
 	  cbet= dx/ calp;
 	  sbet= dy/ calp;
 	  cph= rhx* cbet+ rhy* sbet;
@@ -513,16 +475,16 @@ void gfld( long double rho, long double phi, long double rz,
 	}
 
 	el= PI* data.si[i];
-	rfl=-1.0l;
+	rfl=-1.0;
 
 	/* integration of (current)*(phase factor)
 	 * over segment and image for constant,
 	 * sine, and cosine current distributions */
 	for( k = 0; k < 2; k++ )
 	{
-	  rfl=- rfl;
+	  rfl= -rfl;
 	  riz= rz- data.z[i]* rfl;
-	  rxyz= sqrtl( rix* rix+ riy* riy+ riz* riz);
+	  rxyz= sqrt( rix* rix+ riy* riy+ riz* riz);
 	  rnx= rix/ rxyz;
 	  rny= riy/ rxyz;
 	  rnz= riz/ rxyz;
@@ -531,20 +493,20 @@ void gfld( long double rho, long double phi, long double rz,
 	  top= el+ sill;
 	  bot= el- sill;
 
-	  if( fabsl( omega) >= 1.0e-7l)
-		a=2.0l* sinl( sill)/ omega;
+	  if( fabs( omega) >= 1.0e-7)
+		a=2.0* sin( sill)/ omega;
 	  else
-		a=(2.0l- omega* omega* el* el/3.0l)* el;
+		a=(2.0- omega* omega* el* el/3.0)* el;
 
-	  if( fabsl( top) >= 1.0e-7l)
-		too= sinl( top)/ top;
+	  if( fabs( top) >= 1.0e-7)
+		too= sin( top)/ top;
 	  else
-		too=1.0l- top* top/6.0l;
+		too=1.0- top* top/6.0;
 
-	  if( fabsl( bot) >= 1.0e-7l)
-		boo= sinl( bot)/ bot;
+	  if( fabs( bot) >= 1.0e-7)
+		boo= sin( bot)/ bot;
 	  else
-		boo=1.0l- bot* bot/6.0l;
+		boo=1.0- bot* bot/6.0;
 
 	  b= el*( boo- too);
 	  c= el*( boo+ too);
@@ -554,7 +516,7 @@ void gfld( long double rho, long double phi, long double rz,
 		b* crnt.bir[i]+ c* crnt.cii[i];
 	  arg= TP*( data.x[i] *
 		  rnx+ data.y[i]* rny+ data.z[i]* rnz* rfl);
-	  exa= cmplx( cosl( arg), sinl( arg))* cmplx( rr, ri)/ TP;
+	  exa= cmplx( cos( arg), sin( arg))* cmplx( rr, ri)/ TP;
 
 	  if( k != 1 )
 	  {
@@ -584,8 +546,8 @@ void gfld( long double rho, long double phi, long double rz,
 
   } /* for( i = 0; i < n; i++ ) */
 
-  arg=- TP* r;
-  exa= cmplx( cosl( arg), sinl( arg));
+  arg= -TP* r;
+  exa= cmplx( cos( arg), sin( arg));
   cix= cix* exa;
   ciy= ciy* exa;
   ciz= ciz* exa;
@@ -593,8 +555,8 @@ void gfld( long double rho, long double phi, long double rz,
   rny= ry/ r;
   rnz= rz/ r;
   thx= rnz* phy;
-  thy=- rnz* phx;
-  thz=- rho/ r;
+  thy= -rnz* phx;
+  thz= -rho/ r;
   *eth= cix* thx+ ciy* thy+ ciz* thz;
   *epi= cix* phx+ ciy* phy;
   *erd= cix* rnx+ ciy* rny+ ciz* rnz;
@@ -605,16 +567,16 @@ void gfld( long double rho, long double phi, long double rz,
 /*-----------------------------------------------------------------------*/
 
 /* compute radiation pattern, gain, normalized gain */
-void rdpat()
+void rdpat(void)
 {
-  int i, kth, kph, isens;
-  long double exrm=0.0l, exra=0.0l, prad, gcon, gcop;
-  long double gmax, pint, tmp1, tmp2, phi, pha, thet;
-  long double tha, erdm=0.0l, erda=0.0l, ethm2, ethm;
-  long double etha, ephm2, ephm, epha, tilta, emajr2, eminr2;
-  long double dfaz, axrat, dfaz2, cdfaz, tstor1=0.0l, tstor2;
-  long double gnmn, stilta, gnmj, gnv, gnh, gtot, tmp3, tmp4, da;
-  complex long double eth, eph, erd;
+  int kth, kph, isens;
+  double  prad, gcon, gcop;
+  double phi, pha, thet;
+  double tha, ethm2, ethm;
+  double etha, ephm2, ephm, epha, tilta, emajr2, eminr2;
+  double dfaz, axrat, dfaz2, cdfaz, tstor1=0.0, tstor2;
+  double gnmn, stilta, gnmj, gnv, gnh, gtot;
+  complex double eth, eph, erd;
   int idx, pol; /* Gain buffer and pol type index */
   double gain;
 
@@ -623,45 +585,34 @@ void rdpat()
   {
 	gnd.cl= fpat.clt/ data.wlam;
 	gnd.ch= fpat.cht/ data.wlam;
-	gnd.zrati2= csqrtl(1.0l/ cmplx(
-		  fpat.epsr2,- fpat.sig2* data.wlam*59.96l));
+	gnd.zrati2= csqrt(1.0/ cmplx(
+		  fpat.epsr2,- fpat.sig2* data.wlam*59.96));
   }
 
   /* Calculate radiation pattern data */
   /*** For applied voltage excitation ***/
   if( (fpat.ixtyp == 0) || (fpat.ixtyp == 5) )
   {
-	gcop= data.wlam* data.wlam* 2.0l* PI/(376.73l* fpat.pinr);
+	gcop= data.wlam* data.wlam* 2.0* PI/(376.73* fpat.pinr);
 	prad= fpat.pinr- fpat.ploss- fpat.pnlr;
 	gcon= gcop;
 	if( fpat.ipd != 0)
 	  gcon *= fpat.pinr/ prad;
   }
-  else
-	/*** For elementary current source ***/
-	if( fpat.ixtyp == 4)
-	{
-	  fpat.pinr=394.510l* calc_data.xpr6*
-		calc_data.xpr6* data.wlam* data.wlam;
-	  gcop= data.wlam* data.wlam*2.0l* PI/(376.73l* fpat.pinr);
-	  prad= fpat.pinr- fpat.ploss- fpat.pnlr;
-	  gcon= gcop;
-	  if( fpat.ipd != 0)
-		gcon= gcon* fpat.pinr/ prad;
-	}
-	else
-	  /*** Incident field source ***/
-	{
-	  prad=0.0l;
-	  gcon=4.0l* PI/(1.0l+ calc_data.xpr6* calc_data.xpr6);
-	  gcop= gcon;
-	}
+  /*** For elementary current source ***/
+  else if( fpat.ixtyp == 4)
+  {
+	fpat.pinr=394.510* calc_data.xpr6*
+	  calc_data.xpr6* data.wlam* data.wlam;
+	gcop= data.wlam* data.wlam*2.0* PI/(376.73* fpat.pinr);
+	prad= fpat.pinr- fpat.ploss- fpat.pnlr;
+	gcon= gcop;
+	if( fpat.ipd != 0)
+	  gcon= gcon* fpat.pinr/ prad;
+  }
+  /*** Incident field source ***/
+  else gcon=4.0* PI/(1.0+ calc_data.xpr6* calc_data.xpr6);
 
-  i = 0;
-  gmax = -1.0E+10l;
-  pint = 0.0l;
-  tmp1 = fpat.dph* TA;
-  tmp2 = .5l* fpat.dth* TA;
   phi  = fpat.phis - fpat.dph;
 
   /*** Save radiation pattern data ***/
@@ -672,10 +623,12 @@ void rdpat()
 	rad_pattern[calc_data.fstep].min_gain[pol] =  10000.0;
 	rad_pattern[calc_data.fstep].max_gain_idx[pol] = 0;
 	rad_pattern[calc_data.fstep].min_gain_idx[pol] = 0;
+	rad_pattern[calc_data.fstep].max_gain_tht[pol] = 0;
+	rad_pattern[calc_data.fstep].max_gain_phi[pol] = 0;
   }
 
   /* Signal new rad pattern data */
-  SetFlag( DRAW_NEWRDPAT );
+  SetFlag( DRAW_NEW_RDPAT );
 
   /* Step over theta and phi angles */
   idx = 0;
@@ -689,12 +642,14 @@ void rdpat()
 	{
 	  thet += fpat.dth;
 
-	  if( (gnd.ksymp == 2) && (thet > 90.01l) && (gnd.ifar != 1) )
+	  if( (gnd.ksymp == 2) && (thet > 90.01) && (gnd.ifar != 1) )
 	  {
 		if( rdpattern_window != NULL )
 		  gtk_widget_destroy( rdpattern_window );
-		stop( "Theta > 90 deg. with ground specified\n"
-			"Please check RP card data and correct", 1 );
+		fprintf( stderr, "xnec2c: rdpat(): Theta > 90 deg with ground specified\n"
+			"Please check RP card data and correct\n" );
+		stop( _("rdpat(): Theta > 90 deg with ground specified\n"\
+			  "Please check RP card data and correct"), ERR_STOP );
 	  }
 
 	  tha= thet* TA;
@@ -704,62 +659,57 @@ void rdpat()
 	  {
 		gfld( fpat.rfld/data.wlam, pha, thet/data.wlam,
 			&eth, &eph, &erd, gnd.zrati, gnd.ksymp);
-		erdm= cabs( erd);
-		erda= cang( erd);
 	  }
 
-	  ethm2= creal( eth* conjl( eth));
-	  ethm= sqrtl( ethm2);
+	  ethm2= creal( eth* conj( eth));
+	  ethm= sqrt( ethm2);
 	  etha= cang( eth);
-	  ephm2= creal( eph* conjl( eph));
-	  ephm= sqrtl( ephm2);
+	  ephm2= creal( eph* conj( eph));
+	  ephm= sqrt( ephm2);
 	  epha= cang( eph);
 
 	  /* elliptical polarization calc. */
 	  if( gnd.ifar != 1)
 	  {
-		if( (ethm2 <= 1.0e-20l) && (ephm2 <= 1.0e-20l) )
+		if( (ethm2 <= 1.0e-20) && (ephm2 <= 1.0e-20) )
 		{
-		  tilta=0.0l;
-		  emajr2=0.0l;
-		  eminr2=0.0l;
-		  axrat=0.0l;
+		  tilta=0.0;
+		  emajr2=0.0;
+		  eminr2=0.0;
+		  axrat=0.0;
 		  isens= 0;
 		}
 		else
 		{
 		  dfaz= epha- etha;
-		  if( epha >= 0.0l)
-			dfaz2= dfaz-360.0l;
+		  if( epha >= 0.0)
+			dfaz2= dfaz-360.0;
 		  else
-			dfaz2= dfaz+360.0l;
+			dfaz2= dfaz+360.0;
 
-		  if( fabsl(dfaz) > fabsl(dfaz2) )
+		  if( fabs(dfaz) > fabs(dfaz2) )
 			dfaz= dfaz2;
 
-		  cdfaz= cosl( dfaz* TA);
+		  cdfaz= cos( dfaz* TA);
 		  tstor1= ethm2- ephm2;
-		  tstor2=2.0l* ephm* ethm* cdfaz;
-		  tilta=.5l* atan2l( tstor2, tstor1);
-		  stilta= sinl( tilta);
+		  tstor2=2.0* ephm* ethm* cdfaz;
+		  tilta=atan2( tstor2, tstor1)/2.0;
+		  stilta= sin( tilta);
 		  tstor1= tstor1* stilta* stilta;
-		  tstor2= tstor2* stilta* cosl( tilta);
-		  emajr2=- tstor1+ tstor2+ ethm2;
+		  tstor2= tstor2* stilta* cos( tilta);
+		  emajr2= -tstor1+ tstor2+ ethm2;
 		  eminr2= tstor1- tstor2+ ephm2;
-		  if( eminr2 < 0.0l)
-			eminr2=0.0l;
+		  if( eminr2 < 0.0)	eminr2=0.0;
 
-		  axrat= sqrtl( eminr2/ emajr2);
-		  tilta= tilta* TD;
-		  if( axrat <= 1.0e-5l)
+		  axrat= sqrt( eminr2/ emajr2);
+		  if( axrat <= 1.0e-5)
 			isens= 1;
+		  else if( dfaz <= 0.0)
+			isens= 2;
 		  else
-			if( dfaz <= 0.0l)
-			  isens= 2;
-			else
-			  isens= 3;
+			isens= 3;
 
-		} /* if( (ethm2 <= 1.0e-20l) && (ephm2 <= 1.0e-20l) ) */
+		} /* if( (ethm2 <= 1.0e-20) && (ephm2 <= 1.0e-20) ) */
 
 		gnmj= db10( gcon* emajr2);
 		gnmn= db10( gcon* eminr2);
@@ -767,92 +717,56 @@ void rdpat()
 		gnh = db10( gcon* ephm2);
 		gtot= db10( gcon* (ethm2+ ephm2) );
 
-		if( fpat.inor > 0)
+		switch( fpat.inor )
 		{
-		  switch( fpat.inor )
-		  {
-			case 1:
-			  tstor1= gnmj;
-			  break;
+		  case 0:
+			tstor1= gtot;
+			break;
 
-			case 2:
-			  tstor1= gnmn;
-			  break;
+		  case 1:
+			tstor1= gnmj;
+			break;
 
-			case 3:
-			  tstor1= gnv;
-			  break;
+		  case 2:
+			tstor1= gnmn;
+			break;
 
-			case 4:
-			  tstor1= gnh;
-			  break;
+		  case 3:
+			tstor1= gnv;
+			break;
 
-			case 5:
-			  tstor1= gtot;
-		  }
+		  case 4:
+			tstor1= gnh;
+			break;
 
-		  rad_pattern[calc_data.fstep].gtot[i]= (double)tstor1;
-		  if( tstor1 > gmax) gmax= tstor1;
-		  i++;
-
-		} /* if( fpat.inor > 0) */
-
-		if( fpat.iavp != 0)
-		{
-		  tstor1= gcop*( ethm2+ ephm2);
-		  tmp3= tha- tmp2;
-		  tmp4= tha+ tmp2;
-
-		  if( kth == 1)
-			tmp3= tha;
-		  else
-			if( kth == fpat.nth)
-			  tmp4= tha;
-
-		  da= fabsl( tmp1*( cosl( tmp3)- cosl( tmp4)));
-		  if( (kph == 1) || (kph == fpat.nph) )
-			da *=.5l;
-		  pint += tstor1* da;
-
-		  if( fpat.iavp == 2)
-			continue;
-
-		} /* if( fpat.iavp != 0) */
-
-		ethm= ethm* data.wlam;
-		ephm= ephm* data.wlam;
-
-		if( fpat.rfld >= 1.0e-20l )
-		{
-		  ethm= ethm* exrm;
-		  etha= etha+ exra;
-		  ephm= ephm* exrm;
-		  epha= epha+ exra;
+		  case 5:
+			tstor1= gtot;
 		}
 
 		/* Save rad pattern gains */
-		rad_pattern[calc_data.fstep].gtot[idx] = (double)gtot;
+		rad_pattern[calc_data.fstep].gtot[idx] = tstor1;
 
 		/* Save axial ratio, tilt and pol sense */
 		if( isens == 2 )
-		  rad_pattern[calc_data.fstep].axrt[idx] = (double)-axrat;
+		  rad_pattern[calc_data.fstep].axrt[idx] = -axrat;
 		else
-		  rad_pattern[calc_data.fstep].axrt[idx] = (double)axrat;
-		rad_pattern[calc_data.fstep].tilt[idx] = (double)(TA * tilta);
+		  rad_pattern[calc_data.fstep].axrt[idx] = axrat;
+		rad_pattern[calc_data.fstep].tilt[idx] = tilta;
 		rad_pattern[calc_data.fstep].sens[idx] = isens;
 
 		/* Find and save max value of gain and direction */
 		for( pol = 0; pol < NUM_POL; pol++ )
 		{
-		  gain = (double)gtot + 10.0 * log10(
-			  Polarization_Factor( pol, calc_data.fstep, idx) );
+		  gain = rad_pattern[calc_data.fstep].gtot[idx] +
+			Polarization_Factor( pol, calc_data.fstep, idx);
+		  if( gain < -999.99 ) gain = -999.99;
 
 		  /* Find and save max value of gain and direction */
 		  if( rad_pattern[calc_data.fstep].max_gain[pol] < gain )
 		  {
 			rad_pattern[calc_data.fstep].max_gain[pol]     = gain;
-			rad_pattern[calc_data.fstep].max_gain_tht[pol] = (double)thet;
-			rad_pattern[calc_data.fstep].max_gain_phi[pol] = (double)phi;
+			rad_pattern[calc_data.fstep].max_gain_tht[pol] = thet;
+			rad_pattern[calc_data.fstep].max_gain_phi[pol] = phi;
 			rad_pattern[calc_data.fstep].max_gain_idx[pol] = idx;
 		  }
 
@@ -867,11 +781,9 @@ void rdpat()
 
 		idx++;
 		continue;
-
 	  } /* if( gnd.ifar != 1) */
 
 	} /* for( kth = 1; kth <= fpat.nth; kth++ ) */
-
   } /* for( kph = 1; kph <= fpat.nph; kph++ ) */
 
   return;
