@@ -1,6 +1,5 @@
 /*
  *  xnec2c - GTK2-based version of nec2c, the C translation of NEC2
- *  Copyright (C) 2003-2006 N. Kyriazis <neoklis<at>mailspeed.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -25,95 +24,10 @@
  */
 
 #include "xnec2c.h"
-#include "fork.h"
-#include "support.h"
-#include <wait.h>
-
-/* pointers to input */
-extern FILE *input_fp;
-
-/* common  /cmb/ */
-complex long double *cm = NULL;
-
-/* common  /crnt/ */
-extern crnt_t crnt;
-
-/* Geometry data (common /data/) */
-data_t data;
-
-/* common  /gwav/ */
-extern gwav_t gwav;
-
-/* common  /segj/ */
-extern segj_t segj;
-
-/* common  /vsorc/ */
-extern vsorc_t vsorc;
-
-/* common  /zload/ */
-extern zload_t zload;
-
-/* common  /save/ */
-save_t save;
-
-/* common  /smat/ */
-extern smat_t smat;
-
-/* common  /matpar/ */
-extern matpar_t matpar;
-
-/* common  /netcx/ */
-extern netcx_t netcx;
-
-/* common  /fpat/ */
-extern fpat_t fpat;
-
-/* common  /gnd/ */
-extern gnd_t gnd;
-
-/*common  /ggrid/ */
-extern ggrid_t ggrid;
-
-/* Input and output file name */
-extern char infile[];
-
-/* Data needed for execution and calculations */
-calc_data_t calc_data;
-
-/* Plots drawingarea */
-extern GtkWidget *freqplots_drawingarea;
-extern int freqplots_pixmap_width, freqplots_pixmap_height;
-
-/* Radiation top window & main window */
-extern GtkWidget *rdpattern_window;
-extern GtkWidget *main_window;
+#include "shared.h"
 
 /* Left-overs from fortran code :-( */
-long double tmp1, tmp2, tmp3, tmp4, tmp5, tmp6;
-
-/* Radiation pattern data buffer */
-extern rad_pattern_t *rad_pattern;
-
-/* Near E/H field data */
-extern near_field_t near_field;
-
-/* Impeadance data */
-extern impedance_data_t impedance_data;
-
-/* Freq loop idle callback tag */
-extern int floop_tag;
-
-/* Radiation pattern freq spinbutton */
-extern GtkSpinButton *rdpattern_frequency;
-
-/* Main window freq spinbutton */
-extern GtkSpinButton *mainwin_frequency;
-
-/* Forked process data */
-extern forkpc_t **forkpc;
-extern gboolean FORKED;
-extern int nchild;
-extern char *comnd[];
+static double tmp1, tmp2, tmp3, tmp4, tmp5, tmp6;
 
 /*-----------------------------------------------------------------------*/
 
@@ -124,7 +38,7 @@ extern char *comnd[];
   void
 Frequency_Scale_Geometry()
 {
-  long double fr, fr2;
+  double fr;
   int idx;
 
   /* Calculate wavelength */
@@ -146,7 +60,7 @@ Frequency_Scale_Geometry()
 
   if( data.m != 0)
   {
-	fr2= fr* fr;
+	double fr2= fr* fr;
 	for( idx = 0; idx < data.m; idx++ )
 	{
 	  int j;
@@ -186,10 +100,10 @@ Structure_Impedance_Loading( void )
  *
  * Calculates ground parameters (antenna environment)
  */
-  int
+  void
 Ground_Parameters( void )
 {
-  complex long double epsc;
+  complex double epsc;
 
   if( gnd.ksymp != 1)
   {
@@ -197,11 +111,11 @@ Ground_Parameters( void )
 
 	if( gnd.iperf != 1)
 	{
-	  if( save.sig < 0.0l )
-		save.sig = -save.sig / (59.96l * data.wlam);
+	  if( save.sig < 0.0 )
+		save.sig = -save.sig / (59.96 * data.wlam);
 
-	  epsc = cmplx( save.epsr, -save.sig * data.wlam * 59.96l );
-	  gnd.zrati = 1.0l / csqrtl( epsc);
+	  epsc = cmplx( save.epsr, -save.sig * data.wlam * 59.96 );
+	  gnd.zrati = 1.0 / csqrt( epsc);
 	  gwav.u = gnd.zrati;
 	  gwav.u2 = gwav.u * gwav.u;
 
@@ -209,31 +123,37 @@ Ground_Parameters( void )
 	  {
 		gnd.scrwl = save.scrwlt / data.wlam;
 		gnd.scrwr = save.scrwrt / data.wlam;
-		gnd.t1 = CPLX_01 * 2367.067l/ (long double)gnd.nradl;
-		gnd.t2 = gnd.scrwr * (long double)gnd.nradl;
-
+		gnd.t1 = CPLX_01 * 2367.067/ (double)gnd.nradl;
+		gnd.t2 = gnd.scrwr * (double)gnd.nradl;
 	  } /* if( gnd.nradl > 0 ) */
 
 	  if( gnd.iperf == 2)
 	  {
 		somnec( save.epsr, save.sig, calc_data.fmhz );
-		gnd.frati =( epsc - 1.0l) / ( epsc + 1.0l);
-		if( cabsl(( ggrid.epscf - epsc) / epsc) >= 1.0e-3l )
+		gnd.frati =( epsc - 1.0) / ( epsc + 1.0);
+		if( cabs(( ggrid.epscf - epsc) / epsc) >= 1.0e-3 )
 		{
 		  fprintf( stderr,
-			  "xnec2c: error in ground parameters\n"
-			  "complex dielectric constant from file: %12.5LE%+12.5LEj\n"
-			  "                            requested: %12.5LE%+12.5LEj\n",
-			  creall(ggrid.epscf), cimagl(ggrid.epscf),
-			  creall(epsc), cimagl(epsc) );
-		  stop( "Error in ground parameters", 1 );
+			  "xnec2c: Ground_Parameters(): error in ground parameters\n"
+			  "complex dielectric constant from file: %12.5E%+12.5Ej\n"
+			  "                            requested: %12.5E%+12.5Ej\n",
+			  creal(ggrid.epscf), cimag(ggrid.epscf),
+			  creal(epsc), cimag(epsc) );
+		  stop( _("Ground_Parameters():"\
+				"Error in ground parameters"), ERR_STOP );
 		}
 	  } /* if( gnd.iperf != 2) */
 	} /* if( gnd.iperf != 1) */
+	else
+	{
+	  gnd.scrwl = 0.0;
+	  gnd.scrwr = 0.0;
+	  gnd.t1 = 0.0;
+	  gnd.t2 = 0.0;
+	}
   } /* if( gnd.ksymp != 1) */
 
-  return(0);
-
+  return;
 } /* Ground_Parameters() */
 
 /*-----------------------------------------------------------------------*/
@@ -245,16 +165,13 @@ Ground_Parameters( void )
   void
 Set_Interaction_Matrix( void )
 {
-  size_t iresrv;
-
   /* Memory allocation for symmetry array */
   smat.nop = netcx.neq/netcx.npeq;
-  iresrv = smat.nop * smat.nop;
-  mem_realloc( (void *)&smat.ssx,
-	  iresrv * sizeof( complex long double), "in xnec2c.c" );
+  size_t mreq = (size_t)(smat.nop * smat.nop) * sizeof( complex double);
+  mem_realloc( (void **)&smat.ssx, mreq, "in xnec2c.c" );
 
   /* irngf is not used (NGF function not implemented) */
-  iresrv = data.np2m * (data.np+2*data.mp);
+  int iresrv = data.np2m * (data.np + 2 * data.mp);
   if( matpar.imat == 0)
 	fblock( netcx.npeq, netcx.neq, iresrv, data.ipsym);
 
@@ -309,14 +226,12 @@ Set_Excitation( void )
   void
 Set_Network_Data( void )
 {
-  int i, j, itmp1, itmp2, itmp3;
-
-
   if( netcx.nonet != 0 )
   {
+	int i, j, itmp1, itmp2, itmp3;
+
 	itmp3=0;
 	itmp1= netcx.ntyp[0];
-
 	for( i = 0; i < 2; i++ )
 	{
 	  if( itmp1 == 3) itmp1=2;
@@ -326,19 +241,18 @@ Set_Network_Data( void )
 		itmp2= netcx.ntyp[j];
 
 		if( (itmp2/itmp1) != 1 ) itmp3 = itmp2;
-		else
-		  if( (itmp2 >= 2) && (netcx.x11i[j] <= 0.0l) )
-		  {
-			long double xx, yy, zz;
-			int idx4, idx5;
+		else if( (itmp2 >= 2) && (netcx.x11i[j] <= 0.0) )
+		{
+		  double xx, yy, zz;
+		  int idx4, idx5;
 
-			idx4 = netcx.iseg1[j]-1;
-			idx5 = netcx.iseg2[j]-1;
-			xx = data.x[idx5]- data.x[idx4];
-			yy = data.y[idx5]- data.y[idx4];
-			zz = data.z[idx5]- data.z[idx4];
-			netcx.x11i[j] = data.wlam* sqrtl( xx*xx + yy*yy + zz*zz );
-		  }
+		  idx4 = netcx.iseg1[j]-1;
+		  idx5 = netcx.iseg2[j]-1;
+		  xx = data.x[idx5]- data.x[idx4];
+		  yy = data.y[idx5]- data.y[idx4];
+		  zz = data.z[idx5]- data.z[idx4];
+		  netcx.x11i[j] = data.wlam* sqrt( xx*xx + yy*yy + zz*zz );
+		}
 
 	  } /* for( j = 0; j < netcx.nonet; j++) */
 
@@ -357,16 +271,16 @@ Set_Network_Data( void )
   /* Save impedance data for normalization */
   if( ((calc_data.nfrq > 1) && isFlagSet(FREQ_LOOP_RUNNING)) || CHILD )
   {
-	impedance_data.zreal[calc_data.fstep] = (double)creall( netcx.zped);
-	impedance_data.zimag[calc_data.fstep] = (double)cimagl( netcx.zped);
-	impedance_data.zmagn[calc_data.fstep] = (double)cabsl( netcx.zped);
+	impedance_data.zreal[calc_data.fstep] = (double)creal( netcx.zped);
+	impedance_data.zimag[calc_data.fstep] = (double)cimag( netcx.zped);
+	impedance_data.zmagn[calc_data.fstep] = (double)cabs( netcx.zped);
 	impedance_data.zphase[calc_data.fstep]= (double)cang( netcx.zped);
 
 	if( (calc_data.iped == 1) &&
-		((long double)impedance_data.zmagn[calc_data.fstep] >
+		((double)impedance_data.zmagn[calc_data.fstep] >
 		 calc_data.zpnorm) )
 	  calc_data.zpnorm =
-		(long double)impedance_data.zmagn[calc_data.fstep];
+		(double)impedance_data.zmagn[calc_data.fstep];
   }
 
 } /* Set_Network_Data() */
@@ -381,25 +295,25 @@ Set_Network_Data( void )
 Power_Loss( void )
 {
   int i;
-  long double cmg;
-  complex long double curi;
+  double cmg;
+  complex double curi;
 
 
   /* No wire/segments in structure */
   if( data.n == 0) return;
 
-  fpat.ploss = 0.0l;
+  fpat.ploss = 0.0;
   /* Loop over all wire segs */
   for( i = 0; i < data.n; i++ )
   {
 	/* Calculate segment current (mag/phase) */
 	curi= crnt.cur[i]* data.wlam;
-	cmg= cabsl( curi);
+	cmg= cabs( curi);
 
 	/* Calculate power loss in segment */
 	if( (zload.nload != 0) &&
-		(fabsl(creall(zload.zarray[i])) >= 1.0e-20l) )
-	  fpat.ploss += 0.5l* cmg* cmg* creall( zload.zarray[i])* data.si[i];
+		(fabs(creal(zload.zarray[i])) >= 1.0e-20) )
+	  fpat.ploss += 0.5* cmg* cmg* creal( zload.zarray[i])* data.si[i];
 
   } /* for( i = 0; i < n; i++ ) */
 
@@ -456,8 +370,7 @@ New_Frequency( void )
 {
   /* Abort if freq has not really changed, as when changing
    * between current or charge density structure coloring */
-  if( (save.last_freq == calc_data.fmhz) ||
-	  isFlagClear(ENABLE_EXCITN) )
+  if( (save.last_freq == calc_data.fmhz) || isFlagClear(ENABLE_EXCITN) )
 	return;
   save.last_freq = calc_data.fmhz;
 
@@ -502,17 +415,17 @@ static gboolean retval;	/* Function's return value */
  * requested, dividing the job between child processes if forked
  */
   gboolean
-Frequency_Loop( gpointer user_data )
+Frequency_Loop( gpointer udata )
 {
   /* Value of frequency and step num in the loop */
-  static long double freq;
+  static double freq;
 
   /* Current freq step, saved steps
    * index, num of busy processes */
-  static int fstep, nbusy;
+  static int fstep, num_busy_procs;
 
-  int idx, nch = 0;
-  size_t cnt;
+  int idx, job_num = 0;
+  size_t len;
   char *buff;				/* Used to pass on structure poiners */
   fd_set read_fds;			/* Read file descriptors for select() */
 
@@ -539,16 +452,16 @@ Frequency_Loop( gpointer user_data )
 	  save.fstep[idx] = 0;
 
 	/* Clear "last-used-frequency" buffer */
-	save.last_freq = 0.0l;
+	save.last_freq = 0.0;
 
 	/* Zero num of busy processes */
-	nbusy = 0;
+	num_busy_procs = 0;
 
 	/* Signal global freq step "illegal" */
 	calc_data.fstep = -1;
 
 	/* Inherited from NEC2 */
-	if( calc_data.zpnorm > 0.0l )
+	if( calc_data.zpnorm > 0.0 )
 	  calc_data.iped = 2;
 
 	/* Continue gtk_main idle callbacks */
@@ -558,8 +471,10 @@ Frequency_Loop( gpointer user_data )
   } /* isFlagSet(INIT_FREQ_LOOP) */
 
   /* Repeat freq stepping over number of child processes
-   * if forked. calc_data.nfork = 1 for non-forked runs */
-  for( idx = 0; idx < calc_data.nfork; idx++ )
+   * if forked. calc_data.num_jobs = 1 for non-forked runs.
+   * If not forked (no multi-threading), following block will
+   * execute only once, since only one instance is running */
+  for( idx = 0; idx < calc_data.num_jobs; idx++ )
   {
 	/* Up frequency step count */
 	fstep++;
@@ -599,28 +514,28 @@ Frequency_Loop( gpointer user_data )
 	if( FORKED )
 	{
 	  /* Look for an idle process */
-	  for( nch = 0; nch < calc_data.nfork; nch++ )
+	  for( job_num = 0; job_num < calc_data.num_jobs; job_num++ )
 	  {
 		/* If an idle process is found, give it a job and
 		 * then step the frequency loop by breaking out */
-		if( ! forkpc[nch]->busy )
+		if( ! forked_proc_data[job_num]->busy )
 		{
 		  /* Signal and count busy processes */
-		  forkpc[nch]->busy  = 1;
-		  forkpc[nch]->fstep = fstep;
-		  nbusy++;
+		  forked_proc_data[job_num]->busy  = TRUE;
+		  forked_proc_data[job_num]->fstep = fstep;
+		  num_busy_procs++;
 
 		  /* Tell process to calculate freq dependent data */
-		  cnt = strlen( comnd[FRQDATA] );
-		  Write_Pipe( nch, comnd[FRQDATA], cnt, TRUE );
+		  len = strlen( fork_commands[FRQDATA] );
+		  Write_Pipe( job_num, fork_commands[FRQDATA], (ssize_t)len, TRUE );
 
 		  /* When it responds, give it next frequency */
 		  buff = (char *)&freq;
-		  cnt = sizeof( long double );
-		  Write_Pipe( nch, buff, cnt, TRUE );
+		  len = sizeof( double );
+		  Write_Pipe( job_num, buff, (ssize_t)len, TRUE );
 		  break;
 		}
-	  } /* for( nch = 0; nch < calc_data.nfork; nch++ ) */
+	  } /* for( job_num = 0; job_num < calc_data.num_jobs; job_num++ ) */
 
 	} /* if( FORKED ) */
 	else /* Calculate freq dependent data (no fork) */
@@ -633,66 +548,68 @@ Frequency_Loop( gpointer user_data )
 	}
 
 	/* All idle processes are given a job */
-	if( nbusy >= calc_data.nfork ) break;
+	if( num_busy_procs >= calc_data.num_jobs )
+	  break;
 
-  } /* for( idx = 0; idx < calc_data.nfork; idx++ ) */
+  } /* for( idx = 0; idx < calc_data.num_jobs; idx++ ) */
 
   /* Receive results from forked children */
-  if( FORKED ) do
-  {
-	int n = 0;
-
-	/* Set read fd's to watch for child writes */
-	FD_ZERO( &read_fds );
-	for( idx = 0; idx < calc_data.nfork; idx++ )
+  if( FORKED && num_busy_procs )
+	do
 	{
-	  FD_SET( forkpc[idx]->ch2p_pipe[READ], &read_fds );
-	  if( n < forkpc[idx]->ch2p_pipe[READ] )
-		n = forkpc[idx]->ch2p_pipe[READ];
-	}
+	  int n = 0;
 
-	/* Wait for data from finished child processes */
-	if( select( n+1, &read_fds, NULL, NULL, NULL ) == -1 )
-	{
-	  perror( "xnec2c: select()" );
-	  exit(0);
-	}
-
-	/* Check for finished child processes */
-	for( idx = 0; idx < nchild; idx++ )
-	{
-	  if( FD_ISSET(forkpc[idx]->ch2p_pipe[READ], &read_fds) )
+	  /* Set read fd's to watch for child writes */
+	  FD_ZERO( &read_fds );
+	  for( idx = 0; idx < calc_data.num_jobs; idx++ )
 	  {
-		 /* Read data from finished child process */
-		Get_Freq_Data( idx, forkpc[idx]->fstep );
-
-		/* Mark freq step in list of processed steps */
-		save.fstep[forkpc[idx]->fstep] = 1;
-
-		/* Mark finished child process as ready for next job */
-		forkpc[idx]->busy = 0;
-
-		/* Count down number of busy processes */
-		nbusy--;
+		FD_SET( forked_proc_data[idx]->child2pnt_pipe[READ], &read_fds );
+		if( n < forked_proc_data[idx]->child2pnt_pipe[READ] )
+		  n = forked_proc_data[idx]->child2pnt_pipe[READ];
 	  }
-	} /* for( idx = 0; idx < nchild; idx++ ) */
 
-	/* Find highest freq step that has no steps below it
-	 * that have not been processed by a child process */
-	for( idx = 0; idx < calc_data.nfrq; idx++ )
-	  if( save.fstep[idx] )
-		calc_data.fstep = idx;
-	  else
-		break;
-  }
-  while( !retval && nbusy ); /* Loop terminated and busy children */
+	  /* Wait for data from finished child processes */
+	  if( select( n+1, &read_fds, NULL, NULL, NULL ) == -1 )
+	  {
+		perror( "xnec2c: select()" );
+		_exit(0);
+	  }
+
+	  /* Check for finished child processes */
+	  for( idx = 0; idx < num_child_procs; idx++ )
+	  {
+		if( FD_ISSET(forked_proc_data[idx]->child2pnt_pipe[READ], &read_fds) )
+		{
+		  /* Read data from finished child process */
+		  Get_Freq_Data( idx, forked_proc_data[idx]->fstep );
+
+		  /* Mark freq step in list of processed steps */
+		  save.fstep[forked_proc_data[idx]->fstep] = 1;
+
+		  /* Mark finished child process as ready for next job */
+		  forked_proc_data[idx]->busy = FALSE;
+
+		  /* Count down number of busy processes */
+		  num_busy_procs--;
+		}
+	  } /* for( idx = 0; idx < num_child_procs; idx++ ) */
+
+	  /* Find highest freq step that has no steps below it
+	   * that have not been processed by a child process */
+	  for( idx = 0; idx < calc_data.nfrq; idx++ )
+		if( save.fstep[idx] ) calc_data.fstep = idx;
+		else break;
+
+	} /* do */
+	/* Loop terminated and busy children */
+	while( !retval && num_busy_procs );
 
   /* Return if freq step 0 not ready yet */
   if( calc_data.fstep < 0 ) return( retval );
 
   /* Set frequency and step to global variables */
   calc_data.lastf = calc_data.fstep;
-  calc_data.fmhz = (long double)save.freq[calc_data.fstep];
+  calc_data.fmhz = (double)save.freq[calc_data.fstep];
 
   /* Trigger a redraw of plots drawingarea */
   Plot_Frequency_Data();
@@ -700,12 +617,21 @@ Frequency_Loop( gpointer user_data )
   /* Set frequency spinbuttons */
   gtk_spin_button_set_value(
 	  mainwin_frequency, (gdouble)calc_data.fmhz );
+
   if( isFlagSet(DRAW_ENABLED) )
 	gtk_spin_button_set_value(
 		rdpattern_frequency, (gdouble)calc_data.fmhz );
 
+  if( isFlagSet(PLOT_ENABLED) )
+  {
+	char txt[10];
+	snprintf( txt, sizeof(txt), "%10.3f", (gdouble)calc_data.fmhz );
+	gtk_entry_set_text( GTK_ENTRY(
+		  lookup_widget(freqplots_window, "freqplots_fmhz_entry")), txt );
+  }
+
   /* Change flags at exit if loop is done */
-  if( !retval && !nbusy )
+  if( !retval && !num_busy_procs )
   {
 	ClearFlag( FREQ_LOOP_RUNNING );
 	SetFlag( FREQ_LOOP_DONE );
@@ -731,8 +657,7 @@ Start_Frequency_Loop( void )
 	floop_tag = g_idle_add( Frequency_Loop, NULL );
 	return( TRUE );
   }
-  else
-	return( FALSE );
+  else return( FALSE );
 
 } /* Start_Frequency_Loop() */
 
